@@ -17,7 +17,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-/* $Id: class.boaddressbook.inc.php,v 1.32 2006/09/09 11:50:11 skwashd Exp $ */
+/* $Id: class.boaddressbook.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
 
 	class boaddressbook
 	{
@@ -102,15 +102,15 @@
 		{
 			/* _debug_array($GLOBALS['HTTP_POST_VARS']); */
 			/* Might change this to '' at the end---> */
-			$_start		= get_var('start', array('GET','POST'));
-			$_query		= get_var('query', array('GET','POST'));
-			$_qfield	= get_var('qfield', array('GET','POST'));
-			$_limit		= get_var('limit', array('GET', 'POST'));
-			$_sort		= get_var('sort', array('GET','POST'));
-			$_order		= get_var('order', array('GET','POST'));
-			$_filter	= get_var('filter', array('GET','POST'));
-			$_cat_id	= get_var('cat_id', array('GET','POST'));
-			$_fcat_id	= get_var('fcat_id', array('GET','POST'));
+			$_start		= phpgw::get_var('start');
+			$_query		= phpgw::get_var('query');
+			$_qfield	= phpgw::get_var('qfield');
+			$_limit		= phpgw::get_var('limit');
+			$_sort		= phpgw::get_var('sort');
+			$_order		= phpgw::get_var('order');
+			$_filter	= phpgw::get_var('filter');
+			$_cat_id	= phpgw::get_var('cat_id');
+			$_fcat_id	= phpgw::get_var('fcat_id');
 
 			if(!empty($_start) || ($_start == '0') || ($_start == 0))
 			{
@@ -731,7 +731,7 @@
 		{
 			if(!is_array($_FILES['uploadedfile']) || ($_FILES['uploadedfile']['error'] != UPLOAD_ERR_OK))
 			{
-				Header('Location: ' . $GLOBALS['phpgw']->link('/index.php','menuaction=addressbook.uivcard.in&action=GetFile'));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction' => 'addressbook.uivcard.in', 'action' => 'GetFile'));
 			}
 			else
 			{
@@ -762,7 +762,7 @@
 				/* Delete the temp file. */
 				unlink($filename);
 				unlink($filename . '.info');
-				Header('Location: ' . $GLOBALS['phpgw']->link('/index.php','menuaction=addressbook.uiaddressbook.view_person&ab_id=' . $ab_id));
+				Header('Location: ' . $GLOBALS['phpgw']->link('/index.php',array('menuaction' => 'addressbook.uiaddressbook.view_person', 'ab_id' => $ab_id)));
 				exit();
 			}
 		}
