@@ -12,7 +12,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: index.php,v 1.124 2006/03/21 13:42:51 sigurdne Exp $ */
+	/* $Id: index.php 18358 2007-11-27 04:43:37Z skwashd $ */
 	$GLOBALS['phpgw_info'] = array();
 
 	$GLOBALS['phpgw_info']['flags'] = array(
@@ -25,10 +25,8 @@
 	$parms = Array(
 		       'menuaction'=> 'addressbook.uiaddressbook.index',
 		       'section' => 'Persons',
-		       'cat_id' => get_var('cat_id')
+		       'cat_id' => phpgw::get_var('cat_id')
 		       );
 
 	$GLOBALS['phpgw']->redirect_link('/index.php',$parms);
-//	Header('Location: '.$GLOBALS['phpgw']->link('/index.php',$parms));
-//	$GLOBALS['phpgw']->common->phpgw_footer();
 ?>
