@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package admin
 	* @subpackage custom fields and functions
- 	* @version $Id: class.ui_custom.inc.php,v 1.6 2006/11/19 12:53:47 sigurdne Exp $
+ 	* @version $Id: class.ui_custom.inc.php 18358 2007-11-27 04:43:37Z skwashd $
 	*/
 
 	/**
@@ -28,22 +28,16 @@
 
 		var $public_functions = array
 		(
-			'delete' 		=> True,
-			'list_attribute'	=> True,
-			'edit_attrib' 		=> True,
-			'list_custom_function'	=>True,
+			'delete' 				=> True,
+			'list_attribute'		=> True,
+			'edit_attrib' 			=> True,
+			'list_custom_function'	=> True,
 			'edit_custom_function'	=> True
 		);
 
 		function ui_custom()
 		{
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-			$this->currentapp			= $GLOBALS['phpgw_info']['flags']['currentapp'];
-			$this->nextmatchs			= CreateObject('phpgwapi.nextmatchs');
-			$this->account				= $GLOBALS['phpgw_info']['user']['account_id'];
 			$this->bo					= CreateObject('admin.bo_custom',True);
-			$this->bolocation			= CreateObject('preferences.boadmin_acl');
-			$this->bolocation->acl_app 	= $this->bo->appname;
 
 			$this->start				= $this->bo->start;
 			$this->query				= $this->bo->query;
@@ -52,6 +46,13 @@
 			$this->appname				= $this->bo->appname;
 			$this->location				= $this->bo->location;
 			$this->allrows				= $this->bo->allrows;
+
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
+			$this->currentapp			= $GLOBALS['phpgw_info']['flags']['currentapp'];
+			$this->nextmatchs			= CreateObject('phpgwapi.nextmatchs');
+			$this->account				= $GLOBALS['phpgw_info']['user']['account_id'];
+			$this->bolocation			= CreateObject('preferences.boadmin_acl');
+			$this->bolocation->acl_app 	= $this->appname;
 		}
 
 		function save_sessiondata()
@@ -74,8 +75,8 @@
 		{
 			$appname	= $this->appname;
 			$location	= $this->location;
-			$id			= get_var('id',array('POST','GET'));
-			$resort		= get_var('resort',array('POST','GET'));
+			$id			= phpgw::get_var('id', 'int');
+			$resort		= phpgw::get_var('resort');
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array(
 								'custom',
@@ -84,11 +85,11 @@
 
 			if($resort)
 			{
-				$this->bo->resort_attrib($id,$resort);
+				$this->bo->resort_attrib($id, $resort);
 			}
-			$attrib_list = $this->bo->get_attribs($appname,$location);
+			$attrib_list = $this->bo->get_attribs($appname, $location);
 
-			if (isset($attrib_list) AND is_array($attrib_list))
+			if ( is_array($attrib_list))
 			{
 				foreach($attrib_list as $entry)
 				{
@@ -217,20 +218,23 @@
 
 		function edit_attrib()
 		{
-			$appname	= get_var('appname',array('POST','GET'));
-			$location	= get_var('location',array('POST','GET'));
-			$id			= get_var('id',array('POST','GET'));
-			$values		= get_var('values',array('POST'));
-			if(!$values)
-			{
-				$values=array();
-			}
+			$appname	= $this->appname;
+			$location	= $this->location;
+			$id			= phpgw::get_var('id', 'int');
+			$values		= phpgw::get_var('values', 'string', 'POST', array());
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('custom'));
 
-			if ($location)
+			if ( !isset($values['location']) )
 			{
-				$values['location'] = $location;
+				if ( $location )
+				{
+					$values['location'] = $location;
+				}
+				else
+				{
+					$values['location'] = '';
+				}
 			}
 			
 			if (isset($values['save']) && $values['save'])
@@ -297,6 +301,8 @@
 					{
 						$id=$receipt['id'];
 					}
+					$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'admin.ui_custom.edit_attrib', 'appname' => $values['appname'], 'location' => $values['location'], 'id' => $id));
+
 				}
 				else
 				{
@@ -416,7 +422,16 @@
 				'lang_location_statustext'			=> lang('Select submodule'),
 				'select_name_location'				=> 'values[location]',
 
-				'location_list'						=> $this->bolocation->select_location('select',(isset($values['location'])?$values['location']:''),False,True)
+				'location_list'						=> $this->bolocation->select_location('select',(isset($values['location'])?$values['location']:''),False,True),
+
+				'value_disabled'					=> isset($values['disabled']) ? $values['disabled'] : '',
+				'lang_disabled'						=> lang('disabled'),
+				'lang_disabled_statustext'			=> lang('This attribute turn up as disabled in the form'),
+
+				'value_helpmsg'						=> isset($values['helpmsg']) ? $values['helpmsg'] : '',
+				'lang_helpmsg'						=> lang('help message'),
+				'lang_helpmsg_statustext'			=> lang('Enables help message for this attribute'),
+				'value_location'					=> isset($values['location']) ? $values['location'] : ''
 			);
 //_debug_array($values);
 
@@ -430,8 +445,8 @@
 		{
 			$appname	= $this->appname;
 			$location	= $this->location;
-			$id		= get_var('id',array('POST','GET'));
-			$resort		= get_var('resort',array('POST','GET'));
+			$id			= phpgw::get_var('id', 'int');
+			$resort		= phpgw::get_var('resort');
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array(
 								'custom',
@@ -443,7 +458,7 @@
 				$this->bo->resort_custom_function($id,$resort);
 			}
 			$custom_function_list = $this->bo->read_custom_function($appname,$location);
-
+			$content = array();
 			if (isset($custom_function_list) AND is_array($custom_function_list))
 			{
 				foreach($custom_function_list as $entry)
@@ -568,25 +583,29 @@
 
 		function edit_custom_function()
 		{
-			$appname	= get_var('appname',array('POST','GET'));
-			$location	= get_var('location',array('POST','GET'));
-			$id			= get_var('id',array('POST','GET'));
-			$values		= get_var('values',array('POST'));
+			$GLOBALS['phpgw_info']['flags']['menu_selection'] .= '::list_functions';
+			$appname	= $this->appname;
+			$location	= $this->location;
+			$id			= phpgw::get_var('id', 'int');
+			$values		= phpgw::get_var('values', 'string', 'POST');
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('custom'));
 
-			if ($values['save'])
+			if (isset($values['save']) && $values['save'])
 			{
-				if($id)
+				if(isset($id) && $id)
 				{
 					$values['id']=$id;
 					$action='edit';
 				}
+				else
+				{
+					$action='add';
+				}
 
 				$values['appname']=$appname;
 				$values['location']=$location;
 
-
 				if (!$values['appname'])
 				{
 					$receipt['error'][] = array('msg'=>lang('entity type not chosen!'));
@@ -597,10 +616,13 @@
 					$receipt['error'][] = array('msg'=>lang('custom function file not chosen!'));
 				}
 
-
-				if (!$receipt['error'])
+				if(!$values['location'] || !$values['appname'])
+				{
+				 	$receipt['error'][] = array('msg' => lang('location or appname is missing'));
+				}
+	
+				if (!isset($receipt['error']) || !$receipt['error'])
 				{
-
 					$receipt = $this->bo->save_custom_function($values,$action);
 
 					if(!$id)
@@ -618,8 +640,8 @@
 			if ($id)
 			{
 				$values = $this->bo->read_single_custom_function($appname,$location,$id);
-				$type_name=$values['type_name'];
-				$function_msg = lang('edit custom function'). ' ' . lang($type_name);
+				$type_name=$values['custom_function_file'];
+				$function_msg = lang('edit custom function'). ': ' . $type_name;
 				$action='edit';
 			}
 			else
@@ -660,7 +682,7 @@
 
 				'lang_descr'						=> lang('descr'),
 				'lang_descr_custom_functiontext'	=> lang('Enter a descr for the custom function'),
-				'value_descr'						=> $values['descr'],
+				'value_descr'						=> isset($values['descr']) ? $values['descr']:'',
 
 				'lang_done_custom_functiontext'		=> lang('Back to the list'),
 				'lang_save_custom_functiontext'		=> lang('Save the custom function'),
@@ -668,9 +690,9 @@
 				'lang_custom_function'				=> lang('custom function'),
 				'lang_custom_function_statustext'	=> lang('Select a custom function'),
 				'lang_no_custom_function'			=> lang('No custom function'),
-				'custom_function_list'				=> $this->bo->select_custom_function($values['custom_function_file'],$appname),
+				'custom_function_list'				=> $this->bo->select_custom_function(isset($values['custom_function_file'])?$values['custom_function_file']:'',$appname),
 
-				'value_active'						=> $values['active'],
+				'value_active'						=> isset($values['active'])?$values['active']:'',
 				'lang_active'						=> lang('Active'),
 				'lang_active_statustext'			=> lang('check to activate custom function'),
 			);
@@ -682,21 +704,20 @@
 
 		function delete()
 		{
-			$appname				= get_var('appname',array('POST','GET'));
-			$location				= get_var('location',array('POST','GET'));
-			$attrib_id				= get_var('attrib_id',array('POST','GET'));
-			$custom_function_id		= get_var('custom_function_id',array('POST','GET'));
-			$confirm				= get_var('confirm',array('POST'));
+			$appname				= phpgw::get_var('appname');
+			$location				= phpgw::get_var('location');
+			$attrib_id				= phpgw::get_var('attrib_id', 'int');
+			$custom_function_id		= phpgw::get_var('custom_function_id', 'int');
+			$confirm				= phpgw::get_var('confirm', 'bool', 'POST');
 
-			if($attrib_id):
+			if ( $attrib_id )
 			{
 				$function='list_attribute';
 			}
-			elseif($custom_function_id):
+			else if($custom_function_id)
 			{
 				$function='list_custom_function';
 			}
-			endif;
 
 			$link_data = array
 			(
@@ -715,10 +736,10 @@
 				'custom_function_id' 	=> $custom_function_id
 			);
 
-			if (get_var('confirm',array('POST')))
+			if ( $confirm )
 			{
 				$this->bo->delete($location,$appname,$attrib_id,$custom_function_id);
-				$GLOBALS['phpgw']->redirect_link('/index.php',$link_data);
+				$GLOBALS['phpgw']->redirect_link('/index.php', $link_data);
 			}
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('app_delete'));
