@@ -11,7 +11,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: class.holidaycalc.inc.php,v 1.9 2006/08/31 10:50:45 skwashd Exp $ */
+  /* $Id: class.holidaycalc.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
 
 	if ( !isset($GLOBALS['phpgw_info']['user']['preferences']['common']['country'])
 		|| strlen($GLOBALS['phpgw_info']['user']['preferences']['common']['country']) <> 2 )
@@ -23,8 +23,8 @@
 		$rule = $GLOBALS['phpgw_info']['user']['preferences']['common']['country'];
 	}
 
-	$calc_include = PHPGW_INCLUDE_ROOT.'/calendar/inc/class.holidaycalc_'.$rule.'.inc.php';
-	if(@file_exists($calc_include))
+	$calc_include = PHPGW_INCLUDE_ROOT . "/calendar/inc/class.holidaycalc_{$rule}.inc.php";
+	if ( file_exists($calc_include) )
 	{
 		include_once($calc_include);
 	}
@@ -32,4 +32,3 @@
 	{
 		include_once(PHPGW_INCLUDE_ROOT.'/calendar/inc/class.holidaycalc_US.inc.php');
 	}
-?>
