@@ -12,18 +12,20 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: class.socalendar_sql.inc.php,v 1.47 2006/12/08 11:37:54 sigurdne Exp $ */
+  /* $Id: class.socalendar_sql.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
 
-class socalendar_ extends socalendar__
+phpgw::import_class('phpgwapi.datetime');
+
+class calendar_socalendar_ extends calendar_socalendar__
 {
 	var $deleted_events = array();
 	
 	var $cal_event;
 	var $today = array('raw','day','month','year','full','dow','dm','bd');
 
-	function socalendar_()
+	function __construct()
 	{
-		$this->socalendar__();
+		parent::__construct();
 		
 		if ( !isset($GLOBALS['phpgw']->asyncservice)
 			|| !is_object($GLOBALS['phpgw']->asyncservice))
@@ -236,13 +238,13 @@ class socalendar_ extends socalendar__
 			// But until then, do it this way...
 		//Legacy Support (New)
 
-			$datetime = $GLOBALS['phpgw']->datetime->localdates($this->stream->f('datetime'));
+			$datetime = phpgwapi_datetime::localdates($this->stream->f('datetime'));
 			$this->set_start($datetime['year'],$datetime['month'],$datetime['day'],$datetime['hour'],$datetime['minute'],$datetime['second']);
 
-			$datetime = $GLOBALS['phpgw']->datetime->localdates($this->stream->f('mdatetime'));
+			$datetime = phpgwapi_datetime::localdates($this->stream->f('mdatetime'));
 			$this->set_date('modtime',$datetime['year'],$datetime['month'],$datetime['day'],$datetime['hour'],$datetime['minute'],$datetime['second']);
 
-			$datetime = $GLOBALS['phpgw']->datetime->localdates($this->stream->f('edatetime'));
+			$datetime = phpgw_datetime::localdates($this->stream->f('edatetime'));
 			$this->set_end($datetime['year'],$datetime['month'],$datetime['day'],$datetime['hour'],$datetime['minute'],$datetime['second']);
 
 		//Legacy Support
@@ -266,7 +268,7 @@ class socalendar_ extends socalendar__
 				$enddate = $this->stream->f('recur_enddate');
 				if($enddate != 0 && $enddate != Null)
 				{
-					$datetime = $GLOBALS['phpgw']->datetime->localdates($enddate);
+					$datetime = phpgwapi_datetime::localdates($enddate);
 					$this->add_attribute('recur_enddate',$datetime['year'],'year');
 					$this->add_attribute('recur_enddate',$datetime['month'],'month');
 					$this->add_attribute('recur_enddate',$datetime['day'],'mday');
@@ -637,9 +639,11 @@ class socalendar_ extends socalendar__
 			$event['id'] = $this->stream->get_last_insert_id('phpgw_cal','cal_id');
 		}
 
-		$date = $this->maketime($event['start']) - $GLOBALS['phpgw']->datetime->tz_offset;
-		$enddate = $this->maketime($event['end']) - $GLOBALS['phpgw']->datetime->tz_offset;
-		$today = time() - $GLOBALS['phpgw']->datetime->tz_offset;
+		$user_timezone = phpgwapi_datetime::user_timezone();
+
+		$date = $this->maketime($event['start']) - $user_timezone;
+		$enddate = $this->maketime($event['end']) - $user_timezone;
+		$today = time() - $user_timezone;
 
 		if($event['recur_type'] != MCAL_RECUR_NONE)
 		{
@@ -685,7 +689,7 @@ class socalendar_ extends socalendar__
 		{
 			if($event['recur_enddate']['month'] != 0 && $event['recur_enddate']['mday'] != 0 && $event['recur_enddate']['year'] != 0)
 			{
-				$end = $this->maketime($event['recur_enddate']) - $GLOBALS['phpgw']->datetime->tz_offset;
+				$end = $this->maketime($event['recur_enddate']) - $user_timezone;
 			}
 			else
 			{
