@@ -12,28 +12,25 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-	/* $Id: index.php,v 1.51 2006/11/10 13:34:30 sigurdne Exp $ */
+	/* $Id: index.php 18358 2007-11-27 04:43:37Z skwashd $ */
 
-	$GLOBALS['phpgw_info']['flags'] = Array
-		(
-			'currentapp'	=> 'calendar',
-			'noheader'	=> True,
-			'nonavbar'	=> True,
-			'noappheader'	=> True,
-			'noappfooter'	=> True,
-			'nofooter'	=> True
-		);
+	$GLOBALS['phpgw_info']['flags'] = array
+	(
+		'currentapp'	=> 'calendar',
+		'noheader'		=> true,
+		'nonavbar'		=> true,
+		'noappheader'	=> true,
+		'noappfooter'	=> true,
+		'nofooter'		=> true
+	);
 	include('../header.inc.php');
 
-	if ( !isset($GLOBALS['phpgw']->datetime) || !is_object($GLOBALS['phpgw']->datetime) )
-	{
-		$GLOBALS['phpgw']->datetime = CreateObject('phpgwapi.datetimefunctions');
-	}
+	phpgw::import_class('phpgwapi.datetime');
 	
 	$cal = createObject('calendar.uicalendar');
 	$cal->index(array
-		(
+	(
 			'menuaction'	=> 'calendar.uicalendar.index',
-			'date'		=> date('Ymd',$GLOBALS['phpgw']->datetime->users_localtime)
-		));
+			'date'		=> date('Ymd', phpgwapi_datetime::user_localtime() )
+	));
 ?>
