@@ -8,10 +8,10 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package demo
 	* @subpackage core
- 	* @version $Id: hook_settings.inc.php,v 1.2 2006/12/27 11:04:41 sigurdne Exp $
+ 	* @version $Id: hook_settings.inc.php 18358 2007-11-27 04:43:37Z skwashd $
 	*/
 
-	$this->currentapp			= $GLOBALS['phpgw_info']['flags']['currentapp'];
+	//$this->currentapp			= $GLOBALS['phpgw_info']['flags']['currentapp'];
 
 	$yes_and_no = array(
 		'True' => 'Yes',
