@@ -11,7 +11,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your    *
 	* option) any later version.                                                *
 	\***************************************************************************/
-	/* $Id: class.uifelamimail.inc.php,v 1.14 2007/02/20 10:27:37 sigurdne Exp $ */
+	/* $Id: class.uifelamimail.inc.php 18314 2007-10-11 13:31:04Z skwashd $ */
 
 	class uifelamimail
 	{
@@ -35,76 +35,76 @@
 		{
 			global $phpgw, $phpgw_info;
 			
-			if(isset($GLOBALS['HTTP_POST_VARS']["mark_unread_x"])) 
-				$GLOBALS['HTTP_POST_VARS']["mark_unread"] = "true";
-			if(isset($GLOBALS['HTTP_POST_VARS']["mark_read_x"])) 
-				$GLOBALS['HTTP_POST_VARS']["mark_read"] = "true";
-			if(isset($GLOBALS['HTTP_POST_VARS']["mark_unflagged_x"])) 
-				$GLOBALS['HTTP_POST_VARS']["mark_unflagged"] = "true";
-			if(isset($GLOBALS['HTTP_POST_VARS']["mark_flagged_x"])) 
-				$GLOBALS['HTTP_POST_VARS']["mark_flagged"] = "true";
-			if(isset($GLOBALS['HTTP_POST_VARS']["mark_deleted_x"])) 
-				$GLOBALS['HTTP_POST_VARS']["mark_deleted"] = "true";
+			if(isset($_POST["mark_unread_x"])) 
+				$_POST["mark_unread"] = "true";
+			if(isset($_POST["mark_read_x"])) 
+				$_POST["mark_read"] = "true";
+			if(isset($_POST["mark_unflagged_x"])) 
+				$_POST["mark_unflagged"] = "true";
+			if(isset($_POST["mark_flagged_x"])) 
+				$_POST["mark_flagged"] = "true";
+			if(isset($_POST["mark_deleted_x"])) 
+				$_POST["mark_deleted"] = "true";
 
 			$this->bofelamimail		= CreateObject('felamimail.bofelamimail');
 			$this->bofilter		= CreateObject('felamimail.bofilter');
 			
 			
-			if(isset($GLOBALS['HTTP_POST_VARS']["mailbox"]) && 
-				$GLOBALS['HTTP_GET_VARS']["menuaction"] == "felamimail.uifelamimail.handleButtons" &&
-				empty($GLOBALS['HTTP_POST_VARS']["mark_unread"]) &&
-				empty($GLOBALS['HTTP_POST_VARS']["mark_read"]) &&
-				empty($GLOBALS['HTTP_POST_VARS']["mark_unflagged"]) &&
-				empty($GLOBALS['HTTP_POST_VARS']["mark_flagged"]) &&
-				empty($GLOBALS['HTTP_POST_VARS']["mark_deleted"]))
+			if(isset($_POST["mailbox"]) && 
+				$_GET["menuaction"] == "felamimail.uifelamimail.handleButtons" &&
+				empty($_POST["mark_unread"]) &&
+				empty($_POST["mark_read"]) &&
+				empty($_POST["mark_unflagged"]) &&
+				empty($_POST["mark_flagged"]) &&
+				empty($_POST["mark_deleted"]))
 			{
-				if ($GLOBALS['HTTP_POST_VARS']["folderAction"] == "changeFolder")
+				if ($_POST["folderAction"] == "changeFolder")
 				{
 					// change folder
-					$this->bofelamimail->sessionData['mailbox']	= $GLOBALS['HTTP_POST_VARS']["mailbox"];
+					$this->bofelamimail->sessionData['mailbox']	= $_POST["mailbox"];
 					$this->bofelamimail->sessionData['startMessage']= 1;
 					$this->bofelamimail->sessionData['sort']	= 6;
 					$this->bofelamimail->sessionData['activeFilter']= -1;
 				}
-				elseif($GLOBALS['HTTP_POST_VARS']["folderAction"] == "moveMessage")
+				elseif($_POST["folderAction"] == "moveMessage")
 				{
 					//print "move messages<br>";
-					$this->bofelamimail->sessionData['mailbox'] 	= urldecode($GLOBALS['HTTP_POST_VARS']["oldMailbox"]);
+					$this->bofelamimail->sessionData['mailbox'] 	= urldecode($_POST["oldMailbox"]);
 					$this->bofelamimail->sessionData['startMessage']= 1;
-					if (is_array($GLOBALS['HTTP_POST_VARS']["msg"]))
+					if (is_array($_POST["msg"]))
 					{
 						// we need to initialize the classes first
 						$this->moveNeeded = "1";
 					}
 				}
 			}
-			elseif(isset($GLOBALS['HTTP_POST_VARS']["mailbox"]) &&
-				$GLOBALS['HTTP_GET_VARS']["menuaction"] == "felamimail.uifelamimail.handleButtons" &&
-				!empty($GLOBALS['HTTP_POST_VARS']["mark_deleted"]))
+			elseif(isset($_POST["mailbox"]) &&
+				$_GET["menuaction"] == "felamimail.uifelamimail.handleButtons" &&
+				!empty($_POST["mark_deleted"]))
 			{
 				// delete messages
 				$this->bofelamimail->sessionData['startMessage']= 1;
 			}
-			elseif(isset($GLOBALS['HTTP_GET_VARS']["menuaction"]) && $GLOBALS['HTTP_GET_VARS']["menuaction"] == "felamimail.uifelamimail.deleteMessage")
+			elseif(isset($_GET["menuaction"]) && $_GET["menuaction"] == "felamimail.uifelamimail.deleteMessage")
 			{
 				// delete 1 message from the mail reading window
 				$this->bofelamimail->sessionData['startMessage']= 1;
 			}
-			elseif(isset($GLOBALS['HTTP_POST_VARS']["filter"]) || isset($GLOBALS['HTTP_GET_VARS']["filter"]))
+			elseif(isset($_POST["filter"]) || isset($_GET["filter"]))
 			{
 				// new search filter defined, lets start with message 1
 				$this->bofelamimail->sessionData['startMessage']= 1;
 			}
 
 			// navigate for and back
-			if(isset($GLOBALS['HTTP_GET_VARS']["startMessage"]))
+			if(isset($_GET["startMessage"]))
 			{
-				$this->bofelamimail->sessionData['startMessage'] = $GLOBALS['HTTP_GET_VARS']["startMessage"];
+				$this->bofelamimail->sessionData['startMessage'] = $_GET["startMessage"];
 			}
 			// change sorting
-			if(isset($GLOBALS['HTTP_GET_VARS']["sort"]))
+			if(isset($_GET["sort"]))
 			{
-				$this->bofelamimail->sessionData['sort'] = $GLOBALS['HTTP_GET_VARS']["sort"];
+				$this->bofelamimail->sessionData['sort'] = $_GET["sort"];
 			}
 			$this->bofelamimail->saveSessionData();
 			
@@ -131,8 +131,8 @@
 
 		function addVcard()
 		{
-			$messageID 	= $GLOBALS['HTTP_GET_VARS']['messageID'];
-			$partID 	= $GLOBALS['HTTP_GET_VARS']['partID'];
+			$messageID 	= $_GET['messageID'];
+			$partID 	= $_GET['partID'];
 			$attachment = $this->bofelamimail->getAttachment($messageID,$partID);
 			
 			$tmpfname = tempnam ($GLOBALS['phpgw_info']['server']['temp_dir'], "phpgw_");
@@ -163,15 +163,15 @@
 
 		function changeFilter()
 		{
-			if(isset($GLOBALS['HTTP_POST_VARS']["filter"]))
+			if(isset($_POST["filter"]))
 			{
-				$data['quickSearch']	= $GLOBALS['HTTP_POST_VARS']["quickSearch"];
-				$data['filter']		= $GLOBALS['HTTP_POST_VARS']["filter"];
+				$data['quickSearch']	= $_POST["quickSearch"];
+				$data['filter']		= $_POST["filter"];
 				$this->bofilter->updateFilter($data);
 			}
-			elseif(isset($GLOBALS['HTTP_GET_VARS']["filter"]))
+			elseif(isset($_GET["filter"]))
 			{
-				$data['filter']		= $GLOBALS['HTTP_GET_VARS']["filter"];
+				$data['filter']		= $_GET["filter"];
 				$this->bofilter->updateFilter($data);
 			}
 			$this->viewMainScreen();
@@ -185,7 +185,7 @@
 
 		function deleteMessage()
 		{
-			$message[] = $GLOBALS['HTTP_GET_VARS']["message"];
+			$message[] = $_GET["message"];
 
 			$this->bofelamimail->deleteMessages($message);
 
@@ -205,43 +205,43 @@
 		{
 			if($this->moveNeeded == "1")
 			{
-				$this->bofelamimail->moveMessages($GLOBALS['HTTP_POST_VARS']["mailbox"],
-									$GLOBALS['HTTP_POST_VARS']["msg"]);
+				$this->bofelamimail->moveMessages($_POST["mailbox"],
+									$_POST["msg"]);
 			}
 			
-			elseif(!empty($GLOBALS['HTTP_POST_VARS']["mark_deleted"])
-				&& isset($GLOBALS['HTTP_POST_VARS']["msg"])
-				&& is_array($GLOBALS['HTTP_POST_VARS']["msg"]))
+			elseif(!empty($_POST["mark_deleted"])
+				&& isset($_POST["msg"])
+				&& is_array($_POST["msg"]))
 			{
-				$this->bofelamimail->deleteMessages($GLOBALS['HTTP_POST_VARS']["msg"]);
+				$this->bofelamimail->deleteMessages($_POST["msg"]);
 			}
 			
-			elseif(!empty($GLOBALS['HTTP_POST_VARS']["mark_unread"])
-				&& isset($GLOBALS['HTTP_POST_VARS']["msg"])
-				&& is_array($GLOBALS['HTTP_POST_VARS']["msg"]))
+			elseif(!empty($_POST["mark_unread"])
+				&& isset($_POST["msg"])
+				&& is_array($_POST["msg"]))
 			{
-				$this->bofelamimail->flagMessages("unread",$GLOBALS['HTTP_POST_VARS']["msg"]);
+				$this->bofelamimail->flagMessages("unread",$_POST["msg"]);
 			}
 			
-			elseif(!empty($GLOBALS['HTTP_POST_VARS']["mark_read"])
-				&& isset($GLOBALS['HTTP_POST_VARS']["msg"])
-				&& is_array($GLOBALS['HTTP_POST_VARS']["msg"]))
+			elseif(!empty($_POST["mark_read"])
+				&& isset($_POST["msg"])
+				&& is_array($_POST["msg"]))
 			{
-				$this->bofelamimail->flagMessages("read",$GLOBALS['HTTP_POST_VARS']["msg"]);
+				$this->bofelamimail->flagMessages("read",$_POST["msg"]);
 			}
 			
-			elseif(!empty($GLOBALS['HTTP_POST_VARS']["mark_unflagged"])
-				&& isset($GLOBALS['HTTP_POST_VARS']["msg"])
-				&& is_array($GLOBALS['HTTP_POST_VARS']["msg"]))
+			elseif(!empty($_POST["mark_unflagged"])
+				&& isset($_POST["msg"])
+				&& is_array($_POST["msg"]))
 			{
-				$this->bofelamimail->flagMessages("unflagged",$GLOBALS['HTTP_POST_VARS']["msg"]);
+				$this->bofelamimail->flagMessages("unflagged",$_POST["msg"]);
 			}
 			
-			elseif(!empty($GLOBALS['HTTP_POST_VARS']["mark_flagged"])
-				&& isset($GLOBALS['HTTP_POST_VARS']["msg"])
-				&& is_array($GLOBALS['HTTP_POST_VARS']["msg"]))
+			elseif(!empty($_POST["mark_flagged"])
+				&& isset($_POST["msg"])
+				&& is_array($_POST["msg"]))
 			{
-				$this->bofelamimail->flagMessages("flagged",$GLOBALS['HTTP_POST_VARS']["msg"]);
+				$this->bofelamimail->flagMessages("flagged",$_POST["msg"]);
 			}
 			
 
@@ -349,7 +349,7 @@
 			(
 				'menuaction'	=> 'felamimail.uifelamimail.viewMainScreen'
 			);
-			$this->t->set_var('refresh_url',$GLOBALS['phpgw']->link('/index.php',$linkData));
+			$this->t->set_var('refresh_url', $GLOBALS['phpgw']->link('/index.php',$linkData));
 			
 			
 			// set the default values for the sort links (sort by url)
@@ -357,7 +357,7 @@
 			(
 				'menuaction'	=> 'felamimail.uifelamimail.viewMainScreen',
 				'startMessage'	=> 1,
-				'sort'		=> "2"
+				'sort'			=> 2
 			);
 			$this->t->set_var('url_sort_from',$GLOBALS['phpgw']->link('/index.php',$linkData));
 		
@@ -366,7 +366,7 @@
 			(
 				'menuaction'	=> 'felamimail.uifelamimail.viewMainScreen',
 				'startMessage'	=> 1,
-				'sort'		=> "0"
+				'sort'			=> 0
 			);
 			$this->t->set_var('url_sort_date',$GLOBALS['phpgw']->link('/index.php',$linkData));
 		
@@ -375,19 +375,25 @@
 			(
 				'menuaction'	=> 'felamimail.uifelamimail.viewMainScreen',
 				'startMessage'	=> 1,
-				'sort'		=> "4"
+				'sort'			=> 4
 			);
 			$this->t->set_var('url_sort_subject',$GLOBALS['phpgw']->link('/index.php',$linkData));
 			
 			// create the filter ui
 			$filterList = $bofilter->getFilterList();
 			$activeFilter = $bofilter->getActiveFilter();
+			
 			$filterUI = '';
 			// -1 == no filter selected
 			if($activeFilter == -1)
-				$filterUI .= "<option value=\"-1\" selected>".lang('no filter')."</option>";
+			{
+				$filterUI .= '<option value="-1" selected>' . lang('no filter') . '</option>';
+			}
 			else
-				$filterUI .= "<option value=\"-1\">".lang('no filter')."</option>";
+			{
+				$filterUI .= '<option value="-1">' . lang('no filter') . '</option>';
+			}
+
 			while(list($key,$value) = @each($filterList))
 			{
 				$selected="";
@@ -400,37 +406,36 @@
 				$this->t->set_var('quicksearch',(isset($filterList[0]['subject'])?$filterList[0]['subject']:''));
 			
 			// create the urls for sorting
-			switch($this->sort)
+			switch((int) $this->sort)
 			{
-				case "0":
+				case 2:
 					$linkData = array
 					(
 						'menuaction'	=> 'felamimail.uifelamimail.viewMainScreen',
 						'startMessage'	=> 1,
-						'sort'		=> "1"
+						'sort'			=> 3
 					);
-					$this->t->set_var('url_sort_date',$GLOBALS['phpgw']->link('/index.php',$linkData));
-					
+					$this->t->set_var('url_sort_from', $GLOBALS['phpgw']->link('/index.php',$linkData));
 					break;
-				case "2":
+
+				case 4:
 					$linkData = array
 					(
 						'menuaction'	=> 'felamimail.uifelamimail.viewMainScreen',
 						'startMessage'	=> 1,
-						'sort'		=> "3"
+						'sort'			=> 5
 					);
-					$this->t->set_var('url_sort_from',$GLOBALS['phpgw']->link('/index.php',$linkData));
-					
+					$this->t->set_var('url_sort_subject', $GLOBALS['phpgw']->link('/index.php',$linkData));
 					break;
-				case "4":
+
+				case 0:
 					$linkData = array
 					(
 						'menuaction'	=> 'felamimail.uifelamimail.viewMainScreen',
 						'startMessage'	=> 1,
-						'sort'		=> "5"
+						'sort'			=> 1
 					);
-					$this->t->set_var('url_sort_subject',$GLOBALS['phpgw']->link('/index.php',$linkData));
-					
+					$this->t->set_var('url_sort_date', $GLOBALS['phpgw']->link('/index.php',$linkData));
 					break;
 			}
 
@@ -448,9 +453,10 @@
 				// create the listing of subjects
 				$maxSubjectLength = 75;
 				$maxAddressLength = 30;
-				for($i=0; $i<count($headers['header']); $i++)
+				$cnt_headers = count($headers['header']);
+				for($i=0; $i < $cnt_headers; ++$i)
 				{
-					if (!empty($headers['header'][$i]['subject']))
+					if (!empty($headers['header'][$i]['sender_name']))
 					{
 						$headers['header'][$i]['sender_name'] = htmlentities($headers['header'][$i]['sender_name'],ENT_COMPAT,'UTF-8');	
 					}
@@ -499,11 +505,8 @@
 						if (!empty($headers['header'][$i]['sender_name']))
 						{
 							$sender_name	= $headers['header'][$i]['sender_name'];
-							$full_address	= 
-								$headers['header'][$i]['sender_name'].
-								" <".
-								$headers['header'][$i]['sender_address'].
-								">";
+							$full_address	= "{$headers['header'][$i]['sender_name']}"
+								. "&lt;{$headers['header'][$i]['sender_address']}&gt;";
 						}
 						else
 						{
@@ -519,7 +522,7 @@
 					$this->t->set_var('sender_name',$sender_name);
 					$this->t->set_var('full_address',$full_address);
 				
-					if(isset($GLOBALS['HTTP_GET_VARS']["select_all"]) && $GLOBALS['HTTP_GET_VARS']["select_all"] == "select_all")
+					if(isset($_GET["select_all"]) && $_GET["select_all"] == "select_all")
 					{
 						$this->t->set_var('row_selected',"checked");
 					}
@@ -528,13 +531,34 @@
 					$this->t->set_var('message_uid',$headers['header'][$i]['uid']);
 					$this->t->set_var('date',$headers['header'][$i]['date']);
 					$this->t->set_var('size',$this->show_readable_size($headers['header'][$i]['size']));
-					$flags = "";
-					if(!empty($headers['header'][$i]['recent'])) $flags .= "R";
-					if(!empty($headers['header'][$i]['flagged'])) $flags .= "F";
-					if(!empty($headers['header'][$i]['answered'])) $flags .= "A";
-					if(!empty($headers['header'][$i]['deleted'])) $flags .= "D";
-					if(!empty($headers['header'][$i]['seen'])) $flags .= "S";
-					#$this->t->set_var('flags',$flags);	
+
+					$flags = '';
+					if(!empty($headers['header'][$i]['recent']))
+					{
+						$flags .= "R";
+					}
+
+					if(!empty($headers['header'][$i]['flagged']))
+					{
+						$flags .= "F";
+					}
+					
+					if(!empty($headers['header'][$i]['answered']))
+					{
+						$flags .= "A";
+					}
+
+					if(!empty($headers['header'][$i]['deleted']))
+					{
+						$flags .= "D";
+					}
+
+					if(!empty($headers['header'][$i]['seen']))
+					{
+						$flags .= "S";
+					}
+
+					$this->t->set_var('flags',$flags);	
 
 #					$linkData = array
 #					(
@@ -570,10 +594,10 @@
 					$this->t->set_var('url_add_to_addressbook',$GLOBALS['phpgw']->link('/index.php',$linkData));
 					
 					$this->t->set_var('phpgw_images',PHPGW_IMAGES);
-					$this->t->set_var('row_css_class','header_row_'.$flags);
+					$this->t->set_var('row_css_class', ($i % 2 ? 'row_on' : 'row_off') . " header_row_{$flags}");
 					switch($flags)
 					{
-						case "":
+						case '':
 							$this->t->set_var('imageName','unread_small.png');
 							$this->t->set_var('row_text',lang('new'));
 							break;
@@ -624,7 +648,7 @@
 			$this->t->set_var('maxMessages',isset($i)?$i:0);
 
 			//Fix this:  move into next if-block
-			if(isset($GLOBALS['HTTP_GET_VARS']["select_all"]) && $GLOBALS['HTTP_GET_VARS']["select_all"] == "select_all")
+			if(isset($_GET["select_all"]) && $_GET["select_all"] == "select_all")
 			{
 				$this->t->set_var('checkedCounter',$i);
 			}
@@ -634,7 +658,7 @@
 			}
 			
 			// set the select all/nothing link
-			if(isset($GLOBALS['HTTP_GET_VARS']["select_all"]) && $GLOBALS['HTTP_GET_VARS']["select_all"] == "select_all")
+			if(isset($_GET["select_all"]) && $_GET["select_all"] == "select_all")
 			{
 				// link to unselect all messages
 				$linkData = array
@@ -816,9 +840,6 @@
 		{
 			global $phpgw_info;			
 
-			$this->t->set_var('bg_01',$phpgw_info["theme"]["bg01"]);
-			$this->t->set_var('bg_02',$phpgw_info["theme"]["bg02"]);
-
 			$this->t->set_var('lang_compose',lang('compose'));
 			$this->t->set_var('lang_edit_filter',lang('edit filter'));
 			$this->t->set_var('lang_move_selected_to',lang('move selected to'));
