@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
 	* @subpackage admin
- 	* @version $Id: class.uiadmin.inc.php,v 1.6 2006/12/27 10:38:35 sigurdne Exp $
+ 	* @version $Id: class.uiadmin.inc.php 18358 2007-11-27 04:43:37Z skwashd $
 	*/
 
 	/**
@@ -41,12 +41,12 @@
 		function hrm_uiadmin()
 		{
 			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-			$this->currentapp			= $GLOBALS['phpgw_info']['flags']['currentapp'];
+		//	$this->currentapp			= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->nextmatchs			= CreateObject('phpgwapi.nextmatchs');
 			$this->account				= $GLOBALS['phpgw_info']['user']['account_id'];
 
-			$this->bo					= CreateObject($this->currentapp.'.boadmin',true);
-			$this->bocommon				= CreateObject($this->currentapp.'.bocommon');
+			$this->bo					= CreateObject('hrm.boadmin',true);
+			$this->bocommon				= CreateObject('hrm.bocommon');
 
 			$this->acl_app				= $this->bo->acl_app;
 			$this->start				= $this->bo->start;
@@ -83,9 +83,9 @@
 			$GLOBALS['phpgw']->xslttpl->add_file(array('admin','nextmatchs',
 										'search_field'));
 
-			$values 	= get_var('values',array('POST'));
-			$r_processed	= get_var('processed',array('POST'));
-			$set_permission = get_var('set_permission',array('POST'));
+			$values 	= phpgw::get_var('values');
+			$r_processed	= phpgw::get_var('processed');
+			$set_permission = phpgw::get_var('set_permission', 'bool');
 
 			if($set_permission)
 			{
@@ -184,7 +184,7 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiadmin.aclprefs',
+				'menuaction'	=> 'hrm.uiadmin.aclprefs',
 						'sort'				=>$this->sort,
 						'order'				=>$this->order,
 						'cat_id'			=>$this->cat_id,
@@ -219,7 +219,7 @@
 				'record_limit'					=> $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'],
 				'num_records'					=> $num_records,
 				'all_records'					=> $this->bo->total_records,
-				'link_url'					=> $GLOBALS['phpgw']->link('/index.php','menuaction='.$this->currentapp.'.uiadmin.aclprefs'),
+				'link_url'					=> $GLOBALS['phpgw']->link('/index.php','menuaction='.'hrm.uiadmin.aclprefs'),
 				'img_path'					=> $GLOBALS['phpgw']->common->get_image_path('phpgwapi','default'),
 
 				'lang_groups'					=> lang('groups'),
@@ -256,7 +256,7 @@
 			$function_msg					= lang('set grants');
 			$owner_name = $GLOBALS['phpgw']->accounts->id2name($GLOBALS['phpgw']->accounts->account_id);		// get owner name for title
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg . ': ' . $owner_name;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('hrm') . ' - ' . $appname . ': ' . $function_msg . ': ' . $owner_name;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('list_permission' => $data));
 			$this->save_sessiondata();
 		}
@@ -267,10 +267,10 @@
 			$GLOBALS['phpgw']->xslttpl->add_file(array('admin','nextmatchs',
 										'search_field'));
 
-			$values 		= get_var('values',array('POST'));
-			$r_processed	= get_var('processed',array('POST'));
+			$values 		= phpgw::get_var('values');
+			$r_processed	= phpgw::get_var('processed');
 
-			$set_permission = get_var('set_permission',array('POST'));
+			$set_permission = phpgw::get_var('set_permission', 'bool');
 
 			if($set_permission)
 			{
@@ -377,7 +377,7 @@
 											'sort'	=> $this->sort,
 											'var'	=>	'account_lid',
 											'order'	=>	$this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uiadmin.list_acl',
+											'extra'	=> array('menuaction'	=> 'hrm.uiadmin.list_acl',
 																	'cat_id'	=>$this->cat_id,
 																	'query'		=>$this->query,
 																	'module'		=> $this->location,
@@ -388,7 +388,7 @@
 											'sort'	=>	$this->sort,
 											'var'	=>	'account_lastname',
 											'order'	=>	$this->order,
-											'extra'	=>	array('menuaction'	=> $this->currentapp.'.uiadmin.list_acl',
+											'extra'	=>	array('menuaction'	=> 'hrm.uiadmin.list_acl',
 																	'cat_id'	=>$this->cat_id,
 																	'query'		=>$this->query,
 																	'module'		=> $this->location,
@@ -399,7 +399,7 @@
 											'sort'	=>	$this->sort,
 											'var'	=>	'account_firstname',
 											'order'	=>	$this->order,
-											'extra'	=>	array('menuaction'	=> $this->currentapp.'.uiadmin.list_acl',
+											'extra'	=>	array('menuaction'	=> 'hrm.uiadmin.list_acl',
 																	'cat_id'	=>$this->cat_id,
 																	'query'		=>$this->query,
 																	'module'		=> $this->location,
@@ -417,7 +417,7 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiadmin.list_acl',
+				'menuaction'	=> 'hrm.uiadmin.list_acl',
 						'sort'			=>$this->sort,
 						'order'			=>$this->order,
 						'cat_id'		=>$this->cat_id,
@@ -493,7 +493,7 @@
 			$appname						= lang('permission');
 			$function_msg					= lang('set permission');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('hrm') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('list_permission' => $data));
 			$this->save_sessiondata();
 		}
@@ -502,7 +502,7 @@
 		{
 			$GLOBALS['phpgw']->xslttpl->add_file(array('admin'));
 
-			$values		= get_var('values',array('POST'));
+			$values		= phpgw::get_var('values');
 
 			if ($values['save'])
 			{
@@ -511,22 +511,22 @@
 
 				if ($values['old_email'] != $values['email'])
 				{
-					$GLOBALS['phpgw']->preferences->add($this->currentapp,"email",$values['email'],'user');
+					$GLOBALS['phpgw']->preferences->add('hrm',"email",$values['email'],'user');
 					$receipt['message'][] = array('msg' => lang('Users email is updated'));
 				}
 				if ($values['old_phone'] != $values['phone'])
 				{
-					$GLOBALS['phpgw']->preferences->add($this->currentapp,"cellphone",$values['phone'],'user');
+					$GLOBALS['phpgw']->preferences->add('hrm',"cellphone",$values['phone'],'user');
 					$receipt['message'][] = array('msg' => lang('Users phone is updated'));
 				}
 				if ($values['old_approval_from'] != $values['approval_from'])
 				{
-					$GLOBALS['phpgw']->preferences->add($this->currentapp,"approval_from",$values['approval_from'],'user');
+					$GLOBALS['phpgw']->preferences->add('hrm',"approval_from",$values['approval_from'],'user');
 					$receipt['message'][] = array('msg' => lang('Approval from is updated'));
 				}
 				if ($values['old_default_vendor_category'] != $values['default_vendor_category'])
 				{
-					$GLOBALS['phpgw']->preferences->add($this->currentapp,"default_vendor_category",$values['default_vendor_category'],'user');
+					$GLOBALS['phpgw']->preferences->add('hrm',"default_vendor_category",$values['default_vendor_category'],'user');
 					$receipt['message'][] = array('msg' => lang('default vendor category is updated'));
 				}
 				$GLOBALS['phpgw']->preferences->save_repository();
@@ -534,7 +534,7 @@
 
 			if($this->filter)
 			{
-				$prefs = $this->bocommon->create_preferences($this->currentapp,$this->filter);
+				$prefs = $this->bocommon->create_preferences('hrm',$this->filter);
 			}
 
 			$cats		= CreateObject('phpgwapi.categories');
@@ -547,7 +547,7 @@
 			$data = array
 			(
 				'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'form_action'					=> $GLOBALS['phpgw']->link('/index.php','menuaction='.$this->currentapp.'.uiadmin.contact_info'),
+				'form_action'					=> $GLOBALS['phpgw']->link('/index.php','menuaction='.'hrm.uiadmin.contact_info'),
 				'done_action'					=> $GLOBALS['phpgw']->link('/admin/index.php'),
 				'lang_submit'					=> lang('submit'),
 				'lang_save'						=> lang('Edit'),
@@ -591,7 +591,7 @@
 			$appname							= lang('User contact info');
 			$function_msg						= lang('edit info');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('hrm') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('contact_info' => $data));
 			$this->save_sessiondata();
 		}
