@@ -8,7 +8,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package hrm
 	* @subpackage user
- 	* @version $Id: class.uiuser.inc.php,v 1.29 2006/12/28 04:55:30 skwashd Exp $
+ 	* @version $Id: class.uiuser.inc.php 18358 2007-11-27 04:43:37Z skwashd $
 	*/
 
 	/**
@@ -24,33 +24,32 @@
 		var $sort;
 		var $order;
 		var $sub;
-		var $currentapp;
+		var $currentapp = 'hrm';
 
 		var $public_functions = array
 		(
-			'index'  => True,
-			'view'   => True,
-			'training'=> True,
-			'edit'   => True,
-			'delete' => True,
-			'view_cv' => True
+			'index'		=> true,
+			'view'		=> true,
+			'training'	=> true,
+			'edit'		=> true,
+			'delete'	=> true,
+			'view_cv'	=> true
 		);
 
 		function hrm_uiuser()
 		{
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-			$this->currentapp			= $GLOBALS['phpgw_info']['flags']['currentapp'];
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = true;
 			$this->nextmatchs			= CreateObject('phpgwapi.nextmatchs');
 			$this->account				= $GLOBALS['phpgw_info']['user']['account_id'];
-			$this->bo				= CreateObject($this->currentapp.'.bouser',False);
-			$this->bocommon				= CreateObject($this->currentapp.'.bocommon');
-			$this->bocategory			= CreateObject($this->currentapp.'.bocategory');
-			$this->menu				= CreateObject($this->currentapp.'.menu');
+			$this->bo					= CreateObject('hrm.bouser',False);
+			$this->bocommon				= CreateObject('hrm.bocommon');
+			$this->bocategory			= CreateObject('hrm.bocategory');
+			$this->menu					= CreateObject('hrm.menu');
 			$this->menu->sub			='user';
 			$this->grants 				= $this->bo->grants;
 			$this->start				= $this->bo->start;
 			$this->query				= $this->bo->query;
-			$this->sort				= $this->bo->sort;
+			$this->sort					= $this->bo->sort;
 			$this->order				= $this->bo->order;
 			$this->allrows				= $this->bo->allrows;
 		}
@@ -77,32 +76,36 @@
 
 			$account_info = $this->bo->read();
 
-			while (is_array($account_info) && list(,$entry) = each($account_info))
+			$content = array();
+			foreach ( $account_info as $entry )
 			{
 				if($entry['grants'])
 				{
-					$link_training		= $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> $this->currentapp.'.uiuser.training', 'user_id'=> $entry['account_id']));
-					$text_training		= lang('training');
-					$lang_training_user_text = lang('Training profile');
+					$link_training				= $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'hrm.uiuser.training', 'user_id'=> $entry['account_id']));
+					$text_training				= lang('training');
+					$lang_training_user_text	= lang('Training profile');
+				}
+				else
+				{
+					$link_training				= '';
+					$text_training				= '';
+					$lang_training_user_text	= '';
 				}
 
 				$content[] = array
 				(
 					'first_name'				=> $entry['account_firstname'],
-					'last_name'				=> $entry['account_lastname'],
-//					'link_edit'				=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> $this->currentapp.'.uiuser.training', 'user_id'=> $entry['account_id'])),
+					'last_name'					=> $entry['account_lastname'],
+//					'link_edit'					=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'hrm.uiuser.training', 'user_id'=> $entry['account_id'])),
 					'link_training'				=> $link_training,
-					'link_view'				=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> $this->currentapp.'.uiuser.view' ,' user_id'=> $entry['account_id'])),
-					'lang_view_user_text'			=> lang('view the user'),
-					'lang_training_user_text'		=> $lang_training_user_text,
-					'lang_edit_user_text'			=> lang('edit the user'),
-					'text_view'				=> lang('view'),
-					'text_edit'				=> lang('edit'),
+					'link_view'					=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'hrm.uiuser.view' ,' user_id'=> $entry['account_id'])),
+					'lang_view_user_text'		=> lang('view the user'),
+					'lang_training_user_text'	=> $lang_training_user_text,
+					'lang_edit_user_text'		=> lang('edit the user'),
+					'text_view'					=> lang('view'),
+					'text_edit'					=> lang('edit'),
 					'text_training'				=> $text_training
 				);
-				unset ($link_training);
-				unset ($text_training);
-				unset ($lang_training_user_text);
 			}
 
 //_debug_array($content);
@@ -114,11 +117,8 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'account_lastname',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'		=> $this->currentapp.'.uiuser.index',
+											'extra'	=> array('menuaction'		=> 'hrm.uiuser.index',
 														'query'		=> $this->query,
-														'district_id'	=> $this->district_id,
-														'entity_id'	=> $this->entity_id,
-														'cat_id'	=> $this->cat_id,
 														'allrows' 	=> $this->allrows)
 										)),
 				'lang_last_name'	=> lang('Last name'),
@@ -127,17 +127,14 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'account_firstname',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'		=> $this->currentapp.'.uiuser.index',
+											'extra'	=> array('menuaction'		=> 'hrm.uiuser.index',
 														'query'		=> $this->query,
-														'district_id'	=> $this->district_id,
-														'entity_id'	=> $this->entity_id,
-														'cat_id'	=> $this->cat_id,
 														'allrows'	=> $this->allrows)
 										)),
 				'lang_first_name'	=> lang('First name'),
 				'lang_training'		=> lang('training'),
-				'lang_edit'		=> lang('edit'),
-				'lang_view'		=> lang('view'),
+				'lang_edit'			=> lang('edit'),
+				'lang_view'			=> lang('view'),
 			);
 
 			if(!$this->allrows)
@@ -151,44 +148,40 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiuser.index',
-				'sort'		=> $this->sort,
-				'order'		=> $this->order,
-				'cat_id'	=> $this->cat_id,
-				'filter'	=> $this->filter,
-				'query'		=> $this->query
+				'menuaction'	=> 'hrm.uiuser.index',
+				'sort'			=> $this->sort,
+				'order'			=> $this->order,
+				'query'			=> $this->query
 			);
 
-			$msgbox_data = $this->bocommon->msgbox_data($receipt);
-
 			$data = array
 			(
-				'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'links'						=> $links,
-				'allow_allrows'					=> True,
-				'allrows'					=> $this->allrows,
-				'start_record'					=> $this->start,
-				'record_limit'					=> $record_limit,
-				'num_records'					=> count($account_info),
-				'all_records'					=> $this->bo->total_records,
-				'link_url'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'img_path'					=> $GLOBALS['phpgw']->common->get_image_path('phpgwapi','default'),
-				'lang_searchfield_categorytext'			=> lang('Enter the search string. To show all entries, empty this field and press the SUBMIT button again'),
-				'lang_searchbutton_categorytext'		=> lang('Submit the search string'),
-				'query'						=> $this->query,
-				'lang_search'					=> lang('search'),
-				'table_header'					=> $table_header,
-				'values'					=> $content
+				'links'								=> $links,
+				'allow_allrows'						=> True,
+				'allrows'							=> $this->allrows,
+				'start_record'						=> $this->start,
+				'record_limit'						=> $record_limit,
+				'num_records'						=> count($account_info),
+				'all_records'						=> $this->bo->total_records,
+				'link_url'							=> $GLOBALS['phpgw']->link('/index.php',$link_data),
+				'img_path'							=> $GLOBALS['phpgw']->common->get_image_path('phpgwapi','default'),
+				'lang_searchfield_categorytext'		=> lang('Enter the search string. To show all entries, empty this field and press the SUBMIT button again'),
+				'lang_searchbutton_categorytext'	=> lang('Submit the search string'),
+				'query'								=> $this->query,
+				'lang_search'						=> lang('search'),
+				'table_header'						=> $table_header,
+				'values'							=> $content
 			);
 
 			$appname	= lang('user');
 			$function_msg	= lang('list user');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('hrm') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('list' => $data));
 			$this->save_sessiondata();
 		}
 
+		// FIXME this really belongs in the bo layer
 		function get_user_data($user_id)
 		{
 			$account = CreateObject('phpgwapi.accounts',$user_id,'u');
@@ -196,7 +189,8 @@
 			$membership = $account->membership($user_id);
 			$contacts = CreateObject('phpgwapi.contacts');
 
-			$qcols = array(
+			$qcols = array
+			(
 				'n_given'    => 'n_given',
 				'n_family'   => 'n_family',
 				'tel_work'   => 'tel_work',
@@ -212,7 +206,7 @@
 			$this->boaddressbook  = CreateObject('addressbook.boaddressbook');
 			$comms = $this->boaddressbook->get_comm_contact_data($fields[0]['contact_id']);
 
-			if(is_array($comms))
+			if(is_array($comms) && isset($comms[$fields[0]['contact_id']]) )
 			{
 				$fields[0]['tel_work'] = $comms[$fields[0]['contact_id']]['work phone'];			
 				$fields[0]['tel_home'] = $comms[$fields[0]['contact_id']]['home phone'];
@@ -223,11 +217,13 @@
 			if(!$account_info['person_id'])
 			{
 				$sfields = rawurlencode(serialize($fields[0]));
-				$contact_link   = $GLOBALS['phpgw']->link('/index.php',array(
-											'menuaction'	=> 'addressbook.uiaddressbook.add_person',
-											'entry'		=> $sfields,
-											)
-									);
+				$contact_link   = $GLOBALS['phpgw']->link('/index.php', 
+					array
+					(
+						'menuaction'	=> 'addressbook.uiaddressbook.add_person',
+						'entry'			=> $sfields,
+					)
+				);
 			}
 			else
 			{
@@ -242,9 +238,10 @@
 
 			$prefs_user = $this->bocommon->create_preferences('email',$user_id);
 
+			$email_work = '';
 			if($fields[0]['email'] || $prefs_user['address'])
 			{
-				if($prefs_user['address'])
+				if(isset($prefs_user['address']) && $prefs_user['address'])
 				{
 					$email_work = $prefs_user['address'];
 				}
@@ -254,20 +251,22 @@
 				}
 			}
 
+			$email_home = '';
 			if($fields[0]['email_home'])
 			{
 				$email_home = $fields[0]['email_home'];
 			}
 
-			$qcols_extra = array(
+			$qcols_extra = array
+			(
 				array('name' =>lang('first name'), 'type' => 'link', 'link_value' =>$contact_link),
 				array('name' =>lang('last name'), 'type' => 'text'),
 				array('name' =>lang('work phone'), 'type' => 'text'),
 				array('name' =>lang('home phone'), 'type' => 'text'),
 				array('name' =>lang('cellular phone'), 'type' => 'text'),
 				array('name' =>lang('title'), 'type' => 'text'),
-				array('name' =>lang('work email'), 'type' => 'mail', 'link_value' =>$email_work),
-				array('name' =>lang('home email'), 'type' => 'mail', 'link_value' =>$email_home),
+				array('name' =>lang('work email'), 'type' => 'mail', 'link_value' => $email_work),
+				array('name' =>lang('home email'), 'type' => 'mail', 'link_value' => $email_home),
 			);
 
 			if(is_array($fields))
@@ -279,7 +278,7 @@
 					$user_values[$j]['value'] = $fields[0][$qcols[$i]];
 					$user_values[$j]['name'] = $qcols_extra[$i]['name'];
 					$user_values[$j]['type'] = $qcols_extra[$i]['type'];
-					$user_values[$j]['link_value'] = $qcols_extra[$i]['link_value'];
+					$user_values[$j]['link_value'] = isset($qcols_extra[$i]['link_value']) ? $qcols_extra[$i]['link_value'] : '';
 					$j++;
 				}
 			}
@@ -289,7 +288,7 @@
 
 		function training()
 		{
-			$user_id	= get_var('user_id',array('POST','GET'));
+			$user_id	= phpgw::get_var('user_id', 'int');
   
 			if (!$this->grants[$user_id])
 			{
@@ -313,7 +312,8 @@
 
 			$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 
-			while (is_array($training) && list(,$entry) = each($training))
+			$content = array();
+			foreach ( $training as $entry )
 			{
 				if($entry['start_date'])
 				{
@@ -326,13 +326,13 @@
 
 				if($this->bocommon->check_perms($this->grants[$user_id], PHPGW_ACL_EDIT))
 				{
-					$link_edit	= $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> $this->currentapp.'.uiuser.edit', 'user_id'=> $user_id, 'training_id'=> $entry['training_id']));
+					$link_edit	= $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'hrm.uiuser.edit', 'user_id'=> $user_id, 'training_id'=> $entry['training_id']));
 					$text_edit	= lang('edit');
 					$lang_edit_text	= lang('edit training item');
 				}
 				if($this->bocommon->check_perms($this->grants[$user_id], PHPGW_ACL_DELETE))
 				{
-					$link_delete		= $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> $this->currentapp.'.uiuser.delete', 'user_id'=> $user_id, 'training_id'=> $entry['training_id']));
+					$link_delete		= $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'hrm.uiuser.delete', 'user_id'=> $user_id, 'training_id'=> $entry['training_id']));
 					$text_delete		= lang('delete');
 					$lang_delete_text	= lang('delete training item');
 				}
@@ -345,7 +345,7 @@
 					'end_date'		=> $entry['end_date'],
 					'category'		=> $entry['category'],
 					'link_edit'		=> $link_edit,
-					'link_view'		=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> $this->currentapp.'.uiuser.view', 'user_id'=> $user_id, 'training_id'=> $entry['training_id'])),
+					'link_view'		=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'hrm.uiuser.view', 'user_id'=> $user_id, 'training_id'=> $entry['training_id'])),
 					'link_delete'		=> $link_delete,
 					'lang_view_text'	=> lang('view training item'),
 					'lang_edit_text'	=> $lang_edit_text,
@@ -370,10 +370,10 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'phpgw_hrm_training_place.name',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uiuser.training',
+											'extra'	=> array('menuaction'	=> 'hrm.uiuser.training',
 														'user_id'	=> $user_id,
 														'query'		=> $this->query,
-														'cat_id'	=> $this->cat_id,
+												//		'cat_id'	=> $this->cat_id,
 														'allrows' 	=> $this->allrows)
 										)),
 				'sort_start_date'	=> $this->nextmatchs->show_sort_order(array
@@ -381,10 +381,10 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'start_date',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'		=> $this->currentapp.'.uiuser.training',
+											'extra'	=> array('menuaction'		=> 'hrm.uiuser.training',
 														'user_id'	=> $user_id,
 														'query'		=> $this->query,
-														'cat_id'	=> $this->cat_id,
+												//		'cat_id'	=> $this->cat_id,
 														'allrows' 	=> $this->allrows)
 										)),
 				'lang_place'		=> lang('place'),
@@ -393,49 +393,49 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'phpgw_hrm_training.title',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uiuser.training',
+											'extra'	=> array('menuaction'	=> 'hrm.uiuser.training',
 														'user_id'	=> $user_id,
 														'query'		=> $this->query,
-														'cat_id'	=> $this->cat_id,
+												//		'cat_id'	=> $this->cat_id,
 														'allrows' 	=> $this->allrows)
 										)),
 				'lang_category'		=> lang('category'),
 				'lang_title'		=> lang('training'),
 				'lang_start_date'	=> lang('start date'),
 				'lang_end_date'		=> lang('end date'),
-				'lang_view'		=> lang('view'),
-				'lang_edit'		=> lang('edit'),
+				'lang_view'			=> lang('view'),
+				'lang_edit'			=> lang('edit'),
 				'lang_delete'		=> lang('delete'),
 			);
 
 			$function_msg = lang('list training');
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiuser.edit',
+				'menuaction'	=> 'hrm.uiuser.edit',
 				'user_id'	=> $user_id
 			);
 
 			if($this->bocommon->check_perms($this->grants[$user_id], PHPGW_ACL_ADD))
 			{
-				$add_action	= $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> $this->currentapp.'.uiuser.edit', 'user_id'=> $user_id));
+				$add_action	= $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'hrm.uiuser.edit', 'user_id'=> $user_id));
 				$lang_add	= lang('add');
 			}
 			
 			$table_add[] = array
 			(
-				'lang_add'			=> $lang_add,
+				'lang_add'					=> $lang_add,
 				'lang_add_training_text'	=> lang('add a training item'),
-				'add_action'			=> $add_action,
-				'lang_done'			=> lang('done'),
+				'add_action'				=> $add_action,
+				'lang_done'					=> lang('done'),
 				'lang_done_training_text'	=> lang('back to user list'),
-				'done_action'			=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> $this->currentapp.'.uiuser.index'))
+				'done_action'				=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'hrm.uiuser.index'))
 			);
 
 			$msgbox_data = $this->bocommon->msgbox_data($receipt);
 
 			$link_cv_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiuser.view_cv',
+				'menuaction'	=> 'hrm.uiuser.view_cv',
 				'user_id'	=> $user_id,
 				'order'		=> $this->order,
 				'sort'		=> $this->sort
@@ -444,42 +444,42 @@
 
 			$data = array
 			(
-				'link_cv'				=> $GLOBALS['phpgw']->link('/index.php',$link_cv_data),
-				'lang_cv_statustext'			=> lang('A printout version of the CV'),
-				'text_cv'				=> 'CV',
-				'table_header_training'			=> $table_header,
+				'link_cv'					=> $GLOBALS['phpgw']->link('/index.php',$link_cv_data),
+				'lang_cv_statustext'		=> lang('A printout version of the CV'),
+				'text_cv'					=> 'CV',
+				'table_header_training'		=> $table_header,
 				'values_training'			=> $content,
-				'table_add'				=> $table_add,
+				'table_add'					=> $table_add,
 				'user_values'				=> $user_values,
 				'msgbox_data'				=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
 				'form_action'				=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'done_action'				=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> $this->currentapp.'.uiuser.index')),
-				'lang_id'				=> lang('training ID'),
+				'done_action'				=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'hrm.uiuser.index')),
+				'lang_id'					=> lang('training ID'),
 				'lang_descr'				=> lang('Descr'),
-				'lang_save'				=> lang('save'),
+				'lang_save'					=> lang('save'),
 				'lang_cancel'				=> lang('cancel'),
-				'value_id'				=> $user_id,
-				'lang_id_status_text'			=> lang('Enter the training ID'),
-				'lang_descr_status_text'		=> lang('Enter a description the training'),
-				'lang_done_status_text'			=> lang('Back to the list'),
-				'lang_save_status_text'			=> lang('Save the training'),
-				'type_id'				=> $training['type_id'],
-				'value_descr'				=> $training['descr'],
+				'value_id'					=> $user_id,
+				'lang_id_status_text'		=> lang('Enter the training ID'),
+				'lang_descr_status_text'	=> lang('Enter a description the training'),
+				'lang_done_status_text'		=> lang('Back to the list'),
+				'lang_save_status_text'		=> lang('Save the training'),
+				'type_id'					=> isset($training['type_id'])?$training['type_id']:'',
+				'value_descr'				=> isset($training['descr'])?$training['descr']:'',
 				'lang_apply'				=> lang('apply'),
-				'lang_apply_status_text'		=> lang('Apply the values'),
+				'lang_apply_status_text'	=> lang('Apply the values'),
 			);
 
 			$appname					= lang('Training');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('hrm') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('training' => $data));
 		}
 
 		function edit()
 		{
-			$training_id	= get_var('training_id',array('POST','GET'));
-			$user_id	= get_var('user_id',array('POST','GET'));
-			$values		= get_var('values',array('POST'));
+			$training_id	= phpgw::get_var('training_id', 'int');
+			$user_id	= phpgw::get_var('user_id', 'int');
+			$values		= phpgw::get_var('values');
 
 			if(!$training_id)
 			{
@@ -500,14 +500,15 @@
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('user'));
 
+			$receipt = array();
 			if (is_array($values))
 			{
-				$values['place_id']= get_var('place_id',array('POST'));
+				$values['place_id']= phpgw::get_var('place_id', 'int', 'POST');
 				$values['user_id']= $user_id;
 
-				if ($values['save'] || $values['apply'])
+				if ((isset($values['save']) && $values['save']) || (isset($values['apply']) && $values['apply']))
 				{
-					if(!$values['cat_id'])
+					if(!isset($values['cat_id']) || !$values['cat_id'])
 					{
 						$receipt['error'][]=array('msg'=>lang('Please select a category !'));
 					}
@@ -551,20 +552,20 @@
 						if ($values['save'])
 						{
 							$GLOBALS['phpgw']->session->appsession('session_data','hrm_training_receipt',$receipt);
-							$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction'=> $this->currentapp.'.uiuser.training', 'user_id'=> $user_id));
+							$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction'=> 'hrm.uiuser.training', 'user_id'=> $user_id));
 						}
 					}
 				}
 				else
 				{
-					$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction'=> $this->currentapp.'.uiuser.training', 'user_id'=> $user_id));
+					$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction'=> 'hrm.uiuser.training', 'user_id'=> $user_id));
 				}
 			}
 
 
 			if ($training_id)
 			{
-				if(!$receipt['error'])
+				if(!isset($receipt['error']) || !$receipt['error'])
 				{
 					$values = $this->bo->read_single_training($training_id);
 				}
@@ -580,7 +581,7 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiuser.edit',
+				'menuaction'	=> 'hrm.uiuser.edit',
 				'training_id'	=> $training_id,
 				'user_id' 	=> $user_id
 			);
@@ -620,43 +621,43 @@
 
 			$data = array
 			(
-				'value_descr'				=> $values['descr'],
-				'value_title'				=> $values['title'],
-				'value_start_date'			=> $values['start_date'],
-				'value_end_date'			=> $values['end_date'],
-				'value_entry_date'			=> $values['entry_date'],
-				'value_reference'			=> $values['reference'],
-				'value_new_place_name'			=> $values['new_place_name'],
-				'value_new_place_address'		=> $values['new_place_address'],
-				'value_new_place_zip'			=> $values['new_place_zip'],
-				'value_new_place_town'			=> $values['new_place_town'],
-				'value_new_place_remark'		=> $values['new_place_remark'],
+				'value_descr'					=> isset($values['descr']) ? $values['descr'] : '',
+				'value_title'					=> isset($values['title']) ? $values['title'] : '',
+				'value_start_date'				=> isset($values['start_date']) ? $values['start_date'] : '',
+				'value_end_date'				=> isset($values['end_date']) ? $values['end_date'] : '',
+				'value_entry_date'				=> isset($values['entry_date']) ? $values['entry_date'] : '',
+				'value_reference'				=> isset($values['reference']) ? $values['reference'] : '',
+				'value_new_place_name'			=> isset($values['new_place_name']) ? $values['new_place_name'] : '',
+				'value_new_place_address'		=> isset($values['new_place_address']) ? $values['new_place_address'] : '',
+				'value_new_place_zip'			=> isset($values['new_place_zip']) ? $values['new_place_zip'] : '',
+				'value_new_place_town'			=> isset($values['new_place_town']) ? $values['new_place_town'] : '',
+				'value_new_place_remark'		=> isset($values['new_place_remark']) ? $values['new_place_remark'] : '',
 
-				'img_cal'				=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
+				'img_cal'						=> $GLOBALS['phpgw']->common->image('phpgwapi','cal'),
 				'lang_date_selector'			=> lang('date selector'),
-				'lang_start_date'			=> lang('start date'),
-				'lang_end_date'				=> lang('end date'),
+				'lang_start_date'				=> lang('start date'),
+				'lang_end_date'					=> lang('end date'),
 				'lang_start_date_title'			=> lang('select start date'),
 				'lang_end_date_title'			=> lang('select end date'),
-				'lang_start_date_status_text'		=> lang('Select the start date for your training'),
+				'lang_start_date_status_text'	=> lang('Select the start date for your training'),
 				'lang_end_date_status_text'		=> lang('Select the end date for your training'),
-				'lang_select_date'			=> lang('select date'),
+				'lang_select_date'				=> lang('select date'),
 
-				'lang_reference'			=> lang('reference'),
+				'lang_reference'				=> lang('reference'),
 
-				'lang_entry_date'			=> lang('Entry date'),
-				'lang_title'				=> lang('training'),
+				'lang_entry_date'				=> lang('Entry date'),
+				'lang_title'					=> lang('training'),
 				'lang_title_status_text'		=> lang('Title of the training item'),
-				'lang_skill'				=> lang('Skill'),
+				'lang_skill'					=> lang('Skill'),
 				'lang_skill_status_text'		=> lang('Select your skill'),
-				'skill_list'				=> $this->bocategory->select_category_list('skill_level',$values['skill']),
-				'lang_no_skill'				=> lang('select a skill'),
+				'skill_list'					=> $this->bocategory->select_category_list('skill_level',$values['skill']),
+				'lang_no_skill'					=> lang('select a skill'),
 
-				'place_list'				=> $this->bo->select_place_list($values['place_id']),
-				'lang_place'				=> lang('place'),
-				'lang_new_place'			=> lang('new place'),
+				'place_list'					=> $this->bo->select_place_list($values['place_id']),
+				'lang_place'					=> lang('place'),
+				'lang_new_place'				=> lang('new place'),
 				'lang_place_status_text'		=> lang('Select a place'),
-				'lang_new_place_status_text'		=> lang('Enter a new place'),
+				'lang_new_place_status_text'	=> lang('Enter a new place'),
 				'lang_no_place'					=> lang('select a place'),
 
 				'lang_new_place_name'			=> lang('name'),
@@ -665,38 +666,38 @@
 				'lang_new_place_town'			=> lang('town'),
 				'lang_new_place_remark'			=> lang('remark'),
 
-				'msgbox_data'				=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'form_action'				=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'lang_id'				=> lang('training ID'),
-				'lang_descr'				=> lang('Descr'),
-				'lang_save'				=> lang('save'),
-				'lang_cancel'				=> lang('cancel'),
-				'value_id'				=> $training_id,
+				'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
+				'form_action'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
+				'lang_id'						=> lang('training ID'),
+				'lang_descr'					=> lang('Descr'),
+				'lang_save'						=> lang('save'),
+				'lang_cancel'					=> lang('cancel'),
+				'value_id'						=> $training_id,
 				'lang_id_status_text'			=> lang('Enter the training ID'),
 				'lang_descr_status_text'		=> lang('Enter a description the training'),
 				'lang_done_status_text'			=> lang('Back to the list'),
 				'lang_save_status_text'			=> lang('Save the training'),
-				'lang_apply'				=> lang('apply'),
+				'lang_apply'					=> lang('apply'),
 				'lang_apply_status_text'		=> lang('Apply the values'),
 
-				'lang_category'				=> lang('category'),
-//				'cat_list'				=> $this->bo->select_category_list('select',$values['cat_id']),
-				'cat_list'				=> $this->bocategory->select_category_list('training',$values['cat_id']),
-				'lang_no_cat'				=> lang('no category'),
+				'lang_category'					=> lang('category'),
+//				'cat_list'						=> $this->bo->select_category_list('select',$values['cat_id']),
+				'cat_list'						=> $this->bocategory->select_category_list('training',$values['cat_id']),
+				'lang_no_cat'					=> lang('no category'),
 				'lang_cat_status_text'			=> lang('Select the category the building belongs to. To do not use a category select NO CATEGORY'),
-				'select_name'				=> 'values[cat_id]',
+				'select_name'					=> 'values[cat_id]',
 			);
 
 			$appname					= lang('Training');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('hrm') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('edit' => $data));
 		}
 
 		function view()
 		{
-			$training_id		= get_var('training_id',array('POST','GET'));
-			$user_id	= get_var('user_id',array('POST','GET'));
+			$training_id		= phpgw::get_var('training_id', 'int');
+			$user_id	= phpgw::get_var('user_id', 'int');
 
 			if(!$this->bocommon->check_perms($this->grants[$user_id], PHPGW_ACL_READ))
 			{				
@@ -750,7 +751,7 @@
 				'lang_new_place_status_text'		=> lang('Enter a new place'),
 				'lang_no_place'				=> lang('select a place'),
 
-				'form_action'				=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> $this->currentapp.'.uiuser.training', 'user_id'=> $user_id)),
+				'form_action'				=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'hrm.uiuser.training', 'user_id'=> $user_id)),
 				'lang_id'				=> lang('training ID'),
 				'lang_descr'				=> lang('Descr'),
 				'lang_save'				=> lang('save'),
@@ -774,29 +775,29 @@
 
 			$appname	= lang('Training');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('hrm') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('view' => $data));
 		}
 
 		function delete()
 		{
-			$training_id		= get_var('training_id',array('POST','GET'));
-			$user_id	= get_var('user_id',array('POST','GET'));
+			$training_id		= phpgw::get_var('training_id', 'int');
+			$user_id	= phpgw::get_var('user_id', 'int');
 
 			if(!$this->bocommon->check_perms($this->grants[$user_id], PHPGW_ACL_DELETE))
 			{
 				$this->bocommon->no_access($links);
 				return;
 			}
-			$confirm = get_var('confirm',array('POST'));
+			$confirm = phpgw::get_var('confirm', 'bool', 'POST');
 
 			$link_data = array
 			(
-				'menuaction' => $this->currentapp.'.uiuser.training',
+				'menuaction' => 'hrm.uiuser.training',
 				'user_id' => $user_id
 			);
 
-			if (get_var('confirm',array('POST')))
+			if (phpgw::get_var('confirm', 'bool', 'POST'))
 			{
 				$this->bo->delete_training($user_id,$training_id);
 				$GLOBALS['phpgw']->redirect_link('/index.php',$link_data);
@@ -807,7 +808,7 @@
 			$data = array
 			(
 				'done_action'			=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'delete_action'			=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> $this->currentapp.'.uiuser.delete', 'user_id'=> $user_id, 'training_id'=> $training_id)),
+				'delete_action'			=> $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'hrm.uiuser.delete', 'user_id'=> $user_id, 'training_id'=> $training_id)),
 				'lang_confirm_msg'		=> lang('do you really want to delete this entry'),
 				'lang_yes'			=> lang('yes'),
 				'lang_yes_categorytext'		=> lang('Delete the entry'),
@@ -818,13 +819,13 @@
 			$appname	= lang('Training');
 			$function_msg	= lang('delete');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('hrm') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('delete' => $data));
 		}
 
 		function view_cv()
 		{
-			$user_id	= get_var('user_id',array('POST','GET'));
+			$user_id	= phpgw::get_var('user_id', 'int');
 
 			if(!$this->bocommon->check_perms($this->grants[$user_id], PHPGW_ACL_READ))
 			{
@@ -832,9 +833,9 @@
 				return;
 			}
 
-			$GLOBALS['phpgw_info']['flags'][noheader] = True;
-			$GLOBALS['phpgw_info']['flags'][nofooter] = True;
-			$GLOBALS['phpgw_info']['flags']['xslt_app'] = False;
+			$GLOBALS['phpgw_info']['flags']['noheader'] = true;
+			$GLOBALS['phpgw_info']['flags']['nofooter'] = true;
+			$GLOBALS['phpgw_info']['flags']['xslt_app'] = false;
 
 			if($user_id)
 			{
@@ -876,7 +877,7 @@
 			//error_reporting(7);
 			//error_reporting(E_ALL);
 			set_time_limit(1800);
-			$pdf -> ezSetMargins(50,70,50,50);
+			$pdf -> ezSetMargins(90,70,50,50);
 			$pdf->selectFont(PHPGW_API_INC . '/pdf/fonts/Helvetica.afm');
 
 			// put a line top and bottom on all the pages
@@ -902,7 +903,6 @@
 			$pdf->addObject($all,'all');
 			$pdf->ezStartPageNumbers(500,28,10,'right','{PAGENUM} ' . lang('of') . ' {TOTALPAGENUM}',1);
 
-			$pdf->ezSetDy(-50);
 			$pdf->ezTable($content_heading,'','',
 							array('xPos'=>220,'xOrientation'=>'right','width'=>300,0,'shaded'=>0,'fontSize' => 10,'showLines'=> 0,'titleFontSize' => 12,'outerLineThickness'=>0,'showHeadings'=>0
 							,'cols'=>array('text'=>array('justification'=>'left','width'=>100),
