@@ -237,7 +237,7 @@
 		}
 		else
 		{
-			$forward = get_var('phpgw_forward', array('GET', 'POST'), 0);
+			$forward = phpgw::get_var('phpgw_forward');
 			if($forward)
 			{
 				$extra_vars['phpgw_forward'] =  $forward;
@@ -361,7 +361,7 @@
 	$tmpl->set_var('bg_color',(isset($GLOBALS['phpgw_info']['server']['login_bg_color']) && $GLOBALS['phpgw_info']['server']['login_bg_color']?$GLOBALS['phpgw_info']['server']['login_bg_color']:'FFFFFF'));
 	$tmpl->set_var('bg_color_title',(isset($GLOBALS['phpgw_info']['server']['login_bg_color_title']) && $GLOBALS['phpgw_info']['server']['login_bg_color_title']?$GLOBALS['phpgw_info']['server']['login_bg_color_title']:'486591'));
 	$tmpl->set_var('logo_url',(isset($GLOBALS['phpgw_info']['server']['login_logo_url']) && $GLOBALS['phpgw_info']['server']['login_logo_url']?$GLOBALS['phpgw_info']['server']['login_logo_url']:'www.phpgroupware.org'));
-	$tmpl->set_var('logo_file',(isset($GLOBALS['phpgw_info']['server']['login_logo_file']) && $GLOBALS['phpgw_info']['server']['login_logo_file']?$GLOBALS['phpgw_info']['server']['login_logo_file']:'logo.gif'));
+	$tmpl->set_var('logo_file',(isset($GLOBALS['phpgw_info']['server']['login_logo_file']) && $GLOBALS['phpgw_info']['server']['login_logo_file']?$GLOBALS['phpgw_info']['server']['login_logo_file']:'logo.png'));
 	$tmpl->set_var('logo_title',(isset($GLOBALS['phpgw_info']['server']['login_logo_title']) && $GLOBALS['phpgw_info']['server']['login_logo_title']?$GLOBALS['phpgw_info']['server']['login_logo_title']:'phpGroupWare --&gt; home'));
 	$tmpl->set_var('autocomplete', (isset($GLOBALS['phpgw_info']['server']['autocomplete_login']) && $GLOBALS['phpgw_info']['server']['autocomplete_login'] ? 'autocomplete="off"' : ''));
 
