@@ -11,7 +11,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage accounts
-	* @version $Id: class.accounts_ldap.inc.php,v 1.1 2007/02/06 12:42:21 sigurdne Exp $
+	* @version $Id: class.accounts_ldap.inc.php 18358 2007-11-27 04:43:37Z skwashd $
 	*/
 
 	/**
@@ -67,7 +67,7 @@
 		*/
 		var $fallback_apps = array('addressbook', 'calendar', 'email', 'notes', 'todo');
 
-		function accounts_ldap($account_id = null, $account_type = null)
+		function __construct($account_id = null, $account_type = null)
 		{
 			$this->ds = $GLOBALS['phpgw']->common->ldapConnect();
 			$this->user_context  = $GLOBALS['phpgw_info']['server']['ldap_context'];
@@ -258,7 +258,7 @@
 					return $sortedlist;
 				}
 			}
-			return false;
+			return array();
 		}
 		
 		/**
@@ -466,7 +466,7 @@
 		* Convert an id into its corresponding account or group name
 		*
 		* @param integer $id Account or group id
-		* @return string|boolean Name of the account or the group when found othwerwise false
+		* @return string Name of the account or the group when found othwerwise empty string
 		*/
 		function id2name($id)
 		{
