@@ -8,7 +8,7 @@
  * @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
  * @package phpgwapi
  * @subpackage gui
- * @version $Id: class.Template.inc.php,v 1.2 2007/02/06 12:42:17 sigurdne Exp $
+ * @version $Id: class.Template.inc.php 17222 2006-09-25 06:28:32Z skwashd $
  * @internal Based on phplib
  *
  */
@@ -858,7 +858,7 @@ class Template
 			$new_filename = $filename;
 		}
 
-	/*	if (!file_exists($new_filename))
+		if (!file_exists($new_filename))
 		{
 			if ( $attempt == 1)
 			{
@@ -870,111 +870,9 @@ class Template
 				$new_filename = $this->filename(str_replace($root.'/','',$new_filename), $new_root, 1);
 			}
 		}
-	*/
-		if (!file_exists($new_filename))
-		{
-			if($attempt == 1)
-			{
-				$this->halt("filename: file $new_filename does not exist.");
-			}
-			else
-			{
-				if(file_exists(substr($root, 0, (strlen($root) - strlen($GLOBALS['phpgw_info']['server']['template_set']))) . 'default' .SEP. $filename))
-				{
-					$new_root = substr($root, 0, (strlen($root) - strlen($GLOBALS['phpgw_info']['server']['template_set']))) . SEP . 'default';
-				}
-				else
-				{
-					$new_root = substr($root, 0, (strlen($root) - strlen($GLOBALS['phpgw_info']['server']['template_set']))) . SEP . 'base';					
-				}
-				
-				$new_filename = $this->filename(str_replace($root . SEP,'',$new_filename),$new_root,1);
-			}
-		}
-
 		return $new_filename;
 	}
 
-		function filename_test($filename, $root='', $time=1)
-		{
-			if($root=='')
-			{
-				$root=$this->root;
-			}
-
-			if (substr($filename, 0, 1) != '/' && substr($filename, 1, 1) != ':')
-			{
-				$new_filename = $root.'/'.$filename;
-			}
-			else
-			{
-				$new_filename = $filename;
-			}
-
-				echo 'root: '.$root.'<br>'."\n".'Filename: '.$filename.'<br>'."\n".'New Filename: '.$new_filename.'<br>'."\n".'time: '.$time.'<br>'."\n";
-			if (!file_exists($new_filename))
-			{
-				switch($time)
-				{
-					case 2:
-						$new_root = substr($root, 0, (strlen($root) - strlen($GLOBALS['phpgw_info']['server']['template_set']))) . 'default';						
-					_debug_array($root);
-					_debug_array($new_root);
-					//	$new_root = str_replace($GLOBALS['phpgw_info']['server']['template_set'],'base',PHPGW_APP_TPL);
-						$filename = basename($new_filename);
-					_debug_array($filename);
-						$this->filename($filename,$new_root,3);
-						break;
-					case 3:
-					//	$new_root = substr($root, 0, (strlen($root) - strlen($GLOBALS['phpgw_info']['server']['template_set']))) . 'base';
-						$new_root = str_replace('default','base',$root);
-					_debug_array($new_root);
-						$filename = basename($new_filename);
-						$this->filename($filename,$new_root,4);
-						break;
-					case 4:
-						$new_root = PHPGW_SERVER_ROOT . '/phpgwapi/templates/' . $GLOBALS['phpgw_info']['server']['template_set'];
-						$filename = basename($new_filename);
-						$this->filename($filename,$new_root,5);
-						break;
-					case 5:
-						$new_root = PHPGW_SERVER_ROOT . '/phpgwapi/templates/base';
-						$filename = basename($new_filename);
-						$this->filename($filename,$new_root,6);
-						break;
-					case 6:
-						$new_root = PHPGW_SERVER_ROOT . '/phpgwapi/templates/default';
-						$filename = basename($new_filename);
-						$this->filename($filename,$new_root,7);
-						break;
-					case 7:
-						$new_root = PHPGW_SERVER_ROOT . SEP . $GLOBALS['phpgw_info']['flags']['currentapp'] . '/templates/base';
-						$filename = basename($new_filename);
-						$this->filename($filename,$new_root,8);
-						break;
-					case 8:
-						$new_root = PHPGW_SERVER_ROOT . SEP . $GLOBALS['phpgw_info']['flags']['currentapp'] . '/templates/default';
-						$filename = basename($new_filename);
-						$this->filename($filename,$new_root,9);
-					//	return true;
-						break;
-					case 9:
-						$this->filename($filename,$root,10);
-						break;
-					case 10:
-						$this->halt("filename: file $new_filename does not exist.");
-						break;
-					default:
-						$this->filename($filename,$root,2);
-					//	break;
-				}
-			}
-			else
-			{
-				return $new_filename;
-			}
-		}
-
 	/******************************************************************************
 	 * This function will construct a regexp for a given variable name with any
 	 * special chars quoted.
