@@ -7,7 +7,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.applications.inc.php,v 1.3 2007/03/19 22:15:17 sigurdne Exp $
+	* @version $Id: class.applications.inc.php 18358 2007-11-27 04:43:37Z skwashd $
 	*/
 
 	/**
@@ -280,61 +280,24 @@
 		/**
 		* Populate array with a list of installed apps
 		*/
-		function read_installed_apps_()
+		function read_installed_apps()
 		{
-			$apps = $this->db->adodb->GetAssoc('select * from phpgw_applications where app_enabled != 0 order by app_order asc');
+			$apps = (array) $this->db->adodb->GetAssoc('select * from phpgw_applications where app_enabled != 0 order by app_order asc');
 			foreach($apps as $key => $value)
 			{
-				/* re-enable the code if it is really needed
-				if (@is_array($GLOBALS['phpgw_info']['user']['preferences']) && 
-					($t = lang($app_name)) != $app_name.'*')
-				{
-					$title = $t;
-				}
-				*/
-
 				$GLOBALS['phpgw_info']['apps'][$value['app_name']] = array
 				(
 					'title'   => $value['app_name'],
 					'name'    => $value['app_name'],
 					'enabled' => true,
 					'status'  => $value['app_enabled'],
-					'id'      => intval($value['app_id']),
-					'order'   => intval($value['app_order']),
+					'id'      => (int) $value['app_id'],
+					'order'   => (int) $value['app_order'],
 					'version' => $value['app_version']
 				);
 			}
 		}
 
-		function read_installed_apps()
-		{
-			$db = clone($this->db); // conflicts with the db-object in translation
-			$db->query('select * from phpgw_applications where app_enabled != 0 order by app_order asc',__LINE__,__FILE__);
-			if($db->num_rows())
-			{
-				while ($db->next_record())
-				{
-					$title = $app_name = $db->f('app_name');
-
-					if (@is_array($GLOBALS['phpgw_info']['user']['preferences']) && 
-					    ($t = lang($app_name)) != $app_name.'*')
-					{
-						$title = $t;
-					}
-					$GLOBALS['phpgw_info']['apps'][$db->f('app_name')] = Array(
-						'title'   => $title,
-						'name'    => $db->f('app_name'),
-						'enabled' => True,
-						'status'  => $db->f('app_enabled'),
-						'id'      => intval($db->f('app_id')),
-						'order'   => intval($db->f('app_order')),
-						'version' => $db->f('app_version')
-					);
-				}
-			}
-			unset($db);
-		}
-
 		/**
 		* Test if an application is enabled
 		*
