@@ -8,23 +8,32 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage utilities
-	* @version $Id: class.common.inc.php,v 1.7 2007/04/08 17:42:28 sigurdne Exp $
+	* @version $Id: class.common.inc.php 18358 2007-11-27 04:43:37Z skwashd $
 	*/
 
+	/**
+	* Import required classes
+	*/
+	phpgw::import_class('phpgwapi.datetime');
+
 	/**
 	* Commononly used functions
 	*
 	* @package phpgwapi
 	* @subpackage utilities
 	*/
-	class common
+	class phpgwapi_common
 	{
 		/**
 		* An array with debugging info from the API
 		* @var array Debugging info from the API
 		*/
 		var $debug_info;
-		var $found_files;
+
+		/**
+		* @var array $output array to be converted by XSLT
+		*/
+		public $output = array();
 
 		/**
 		* This function compares for major versions only
@@ -34,10 +43,10 @@
 		* @param boolean $debug Debug flag
 		* @return integer 1 when str2 is newest (bigger version number) than str1
 		*/
-		function cmp_version($str1,$str2,$debug=False)
+		public function cmp_version($str1,$str2,$debug=False)
 		{
-			ereg("([0-9]+)\.([0-9]+)\.([0-9]+)[a-zA-Z]*([0-9]*)",$str1,$regs);
-			ereg("([0-9]+)\.([0-9]+)\.([0-9]+)[a-zA-Z]*([0-9]*)",$str2,$regs2);
+			preg_match("/([0-9]+)\.([0-9]+)\.([0-9]+)[a-z]*([0-9]*)/i", $str1, $regs);
+			preg_match("/([0-9]+)\.([0-9]+)\.([0-9]+)[a-z]*([0-9]*)/i", $str2, $regs2);
 			if($debug) { echo "<br />$regs[0] - $regs2[0]"; }
 
 			for($i=1;$i<5;++$i)
@@ -66,10 +75,10 @@
 		* @param boolean $debug Debug flag
 		* @return integer 1 when str2 is newest (bigger version number) than str1
 		*/
-		function cmp_version_long($str1,$str2,$debug=False)
+		public function cmp_version_long($str1,$str2,$debug=False)
 		{
-			ereg("([0-9]+)\.([0-9]+)\.([0-9]+)[a-zA-Z]*([0-9]*)\.([0-9]*)",$str1,$regs);
-			ereg("([0-9]+)\.([0-9]+)\.([0-9]+)[a-zA-Z]*([0-9]*)\.([0-9]*)",$str2,$regs2);
+			preg_match("/([0-9]+)\.([0-9]+)\.([0-9]+)[a-z]*([0-9]*)\.([0-9]*)/i", $str1, $regs);
+			preg_match("/([0-9]+)\.([0-9]+)\.([0-9]+)[a-z]*([0-9]*)\.([0-9]*)/i", $str2, $regs2);
 			if($debug) { echo "<br />$regs[0] - $regs2[0]"; }
 
 			for($i=1;$i<6;++$i)
@@ -103,7 +112,7 @@
 		* @return string SQL where clause
 		* @deprecated Use ACL class instead
 		*/
-		function sql_search($table, $owner=0 )
+		public function sql_search($table, $owner=0 )
 		{
 			echo 'common::sql_search() is a deprecated function - use ACL class instead';
 			if (!$owner)
@@ -128,10 +137,10 @@
 		*
 		* @return array List of installed languages
 		*/
-		function getInstalledLanguages()
+		public function getInstalledLanguages()
 		{
 			$GLOBALS['phpgw']->db->query('select distinct lang from phpgw_lang');
-			while (@$GLOBALS['phpgw']->db->next_record()) 
+			while ($GLOBALS['phpgw']->db->next_record()) 
 			{
 				$installedLanguages[$GLOBALS['phpgw']->db->f('lang')] = $GLOBALS['phpgw']->db->f('lang');
 			}
@@ -145,10 +154,10 @@
 		* Uses HTTP_ACCEPT_LANGUAGE (from the users browser) to find out which languages are installed
 		* @return string Users preferred language (two character ISO code)
 		*/
-		function getPreferredLanguage()
+		public function getPreferredLanguage()
 		{
 			// create a array of languages the user is accepting
-			$userLanguages = explode(',',$_SERVER['HTTP_ACCEPT_LANGUAGE']);
+			$userLanguages = explode(',', phpgw::get_var('HTTP_ACCEPT_LANGUAGE', 'string', 'SERVER'));
 			$supportedLanguages = $this->getInstalledLanguages();
 
 			// find usersupported language
@@ -183,7 +192,7 @@
 		* @param string $passwd LDAP password
 		* @return resource LDAP link identifier
 		*/
-		function ldapConnect($host = '', $dn = '', $passwd = '')
+		public function ldapConnect($host = '', $dn = '', $passwd = '')
 		{
 			if (! $host)
 			{
@@ -252,7 +261,7 @@
 		* @internal There may need to be some cleanup before hand
 		* @param boolean $call_footer When true then call footer else exit
 		*/
-		function phpgw_exit($call_footer = False)
+		public function phpgw_exit($call_footer = False)
 		{
 			if (!defined('PHPGW_EXIT'))
 			{
@@ -266,19 +275,23 @@
 			exit;
 		}
 
-		function phpgw_final()
+		/**
+		* Do some cleaning up before we exit
+		*
+		* @internal called by register_shutdown_function()
+		*/
+		public function phpgw_final()
 		{
-			if (!defined('PHPGW_FINAL'))
+			static $final_called = null;
+			if ( is_null($final_called) )
 			{
-				define('PHPGW_FINAL',True);
-
 				// call the asyncservice check_run function if it is not explicitly set to cron-only
-				//
 				if (!isset($GLOBALS['phpgw_info']['server']['asyncservice']) || !$GLOBALS['phpgw_info']['server']['asyncservice'] )
 				{
-					ExecMethod('phpgwapi.asyncservice.check_run','fallback');
+					ExecMethod('phpgwapi.asyncservice.check_run', 'fallback');
 				}
 				$GLOBALS['phpgw']->db->disconnect();
+				$final_called = true;
 			}
 		}
 
@@ -286,12 +299,11 @@
 		* Get random string of size $size
 		*
 		* @param integer $size Size of random string to return
-		* @return string STring with random generated characters and numbers
+		* @return string randomly generated characters
 		*/
-		function randomstring($size)
+		public function randomstring($size = 20)
 		{
 			$s = '';
-			srand((double)microtime()*1000000);
 			$random_char = array('0','1','2','3','4','5','6','7','8','9','a','b','c','d','e','f',
 				'g','h','i','j','k','l','m','n','o','p','q','r','s','t','u','v',
 				'w','x','y','z','A','B','C','D','E','F','G','H','I','J','K','L',
@@ -299,17 +311,11 @@
 
 			for ($i=0; $i<$size; ++$i)
 			{
-				$s .= $random_char[rand(1,61)];
+				$s .= $random_char[mt_rand(1,61)];
 			}
 			return $s;
 		}
 
-
-		function filesystem_separator()
-		{
-			return filesystem_separator();
-		}
-
 		/**
 		* This is used for reporting errors in a nice format
 		*
@@ -317,7 +323,7 @@
 		* @param string $text Heading error text
 		* @return string HTML table with error messages or empty string when there is no error/s
 		*/
-		function error_list($errors, $text='Error')
+		public function error_list($errors, $text='Error')
 		{
 			if (! is_array($errors))
 			{
@@ -342,11 +348,11 @@
 		* @param array $extravars URL parameter
 		* @deprecated use ACL instead
 		*/
-		function check_owner($record, $link, $label, $extravars = array())
+		public function check_owner($record, $link, $label, $extravars = array())
 		{
 			echo 'check_owner() is a depreciated function - use ACL class instead <br>';
 			$s = '<a href="' . $GLOBALS['phpgw']->link($link,$extravars) . '"> ' . lang($label) . ' </a>';
-			if (ereg('^[0-9]+$',$record))
+			if ( preg_match('/^[0-9]+$/',$record))
 			{
 				if ($record != $GLOBALS['phpgw_info']['user']['account_id'])
 				{
@@ -372,7 +378,7 @@
 		* @param string $lastname Lastname
 		* @return Fullname
 		*/
-		function display_fullname($lid = '', $firstname = '', $lastname = '')
+		public function display_fullname($lid = '', $firstname = '', $lastname = '')
 		{
 			if (! $lid && ! $firstname && ! $lastname)
 			{
@@ -423,7 +429,7 @@
 		* @param array menu data
 		* @returns array menu data
 		*/
-		function display_mainscreen($appname, $file)
+		public function display_mainscreen($appname, $file)
 		{
 			if(is_array($file))
 			{
@@ -460,7 +466,7 @@
 		* @param integer $accountid Account id
 		* @return string Users fullname
 		*/
-		function grab_owner_name($accountid = '')
+		public function grab_owner_name($accountid = '')
 		{
 			$GLOBALS['phpgw']->accounts->get_account_name($accountid,$lid,$fname,$lname);
 			return $this->display_fullname($lid,$fname,$lname);
@@ -470,118 +476,33 @@
 		* Create tabs
 		*
 		* @param array $tabs With ($id,$tab) pairs
-		* @param integer $selected Id of selected tab
-		* @param string $fontsize Optional font size
+		* @param integer $selection array key of selected tab
 		* @param boolean $lang When true use translation otherwise use given label
-		* @param boolean $no_image Do not use an image for the tabs
 		* @return string HTML output string
 		*/
-		function create_tabs($tabs, $selected, $fontsize = '', $lang = False, $no_image = True)
+		public function create_tabs($tabs, $selection, $lang = false)
 		{
-			if($no_image)
-			{
-				$output_text = "<table style=\"{padding: 0px; border-collapse: collapse; width: 100%;}\">\n\t<tr>\n";
-//				$output_text = "<table style=\"{padding: 0px; width: 100%;}\">\n\t<tr>\n";
-				foreach($tabs as $id => $tab)
-				{
-					$output_text .= "\t\t" . '<th class="';
-					$output_text .= ($id != $selected ? 'in' : '');
-					$output_text .= 'activetab">';
-					$output_text .= '<a href="' . $tab['link'] . '">';
-					$output_text .= ($lang ? lang($tab['label']) : $tab['label']);
-					$output_text .= "</a></th>\n";
-//					$output_text .= "<th style=\"border-bottom: 1px solid #000000; \">&nbsp;</th>\n";
-				}
-				$output_text .= "\t\t" . '<th class="tablast">&nbsp;</th>' . "\n"; 
-				$output_text .= "\t</tr>\n</table>\n";
-				return $output_text;
-			}
-			
-			$output_text = '<table border="0" cellspacing="0" cellpadding="0"><tr>';
+			$output = <<<HTML
+			<div class="yui-navset">
+				<ul class="yui-nav">
 
-			/* This is a php3 workaround */
-			if(PHPGW_IMAGES_DIR == 'PHPGW_IMAGES_DIR')
+HTML;
+			foreach($tabs as $id => $tab)
 			{
-				$ir = ExecMethod('phpgwapi.phpgw.common.get_image_path', 'phpgwapi');
-			}
-			else
-			{
-				$ir = PHPGW_IMAGES_DIR;
-			}
+				$selected = $id == $selection ? ' class="selected"' : '';
+				$label = $lang ? lang($tab['label']) : $tab['label'];
+				$output .= <<<HTML
+					<li{$selected}><a href="{$tab['link']}"><em>{$label}</em></a></li>
 
-			if ($fontsize)
-			{
-				$fs  = '<font size="' . $fontsize . '">';
-				$fse = '</font>';
+HTML;
 			}
+			$output .= <<<HTML
+				</ul>
+			</div>
 
-			$i = 1;
-			if( !is_array($tabs) )
-			{
-				$tabs = array();
-			}
-			foreach($tabs as $tabs)
-			{
-				if ($tab[0] == $selected)
-				{
-					if ($i == 1)
-					{
-						$output_text .= '<td align="right"><img src="' . $ir . '/tabs-start1.gif" /></td>';
-					}
+HTML;
+			return $output;
 
-					$output_text .= '<td nowrap="nowrap" align="left" background="' . $ir . '/tabs-bg1.gif">&nbsp;<strong><a href="'
-						. $tab[1]['link'] . '" class="tablink">' . $fs . $tab[1]['label']
-						. $fse . '</a></strong>&nbsp;</td>';
-					if ($i == count($tabs))
-					{
-						$output_text .= '<td align="left"><img src="' . $ir . '/tabs-end1.gif" /></td>';
-					}
-					else
-					{
-						$output_text .= '<td align="left"><img src="' . $ir . '/tabs-sepr.gif" /></td>';
-					}
-				}
-				else
-				{
-					if ($i == 1)
-					{
-						$output_text .= '<td align="right"><img src="' . $ir . '/tabs-start0.gif" /></td>';
-					}
-					$output_text .= '<td nowrap="nowrap" align="left" background="' . $ir . '/tabs-bg0.gif">&nbsp;<strong><a href="'
-						. $tab[1]['link'] . '" class="tablink">' . $fs . $tab[1]['label'] . $fse
-						. '</a></strong>&nbsp;</td>';
-					if (($i + 1) == $selected)
-					{
-						$output_text .= '<td align="left"><img src="' . $ir . '/tabs-sepl.gif" /></td>';
-					}
-					elseif ($i == $selected || $i != count($tabs))
-					{
-						$output_text .= '<td align="left"><img src="' . $ir . '/tabs-sepm.gif" /></td>';
-					}
-					elseif ($i == count($tabs))
-					{
-						if ($i == $selected)
-						{
-							$output_text .= '<td align="left"><img src="' . $ir . '/tabs-end1.gif" /></td>';
-						}
-						else
-						{
-							$output_text .= '<td align="left"><img src="' . $ir . '/tabs-end0.gif" /></td>';
-						}
-					}
-					else
-					{
-						if ($i != count($tabs))
-						{
-							$output_text .= '<td align="left"><img src="' . $ir . '/tabs-sepr.gif" /></td>';
-						}
-					}
-				}
-				++$i;
-				$output_text .= "\n";
-			}
-			$output_text .= "</table>\n";
-			return $output_text;
 		}
 
 		/**
@@ -590,7 +511,7 @@
 		* @param string $appname Name of application defaults to $GLOBALS['phpgw_info']['flags']['currentapp']
 		* @return string|boolean Application directory or false
 		*/
-		function get_app_dir($appname = '')
+		public function get_app_dir($appname = '')
 		{
 			if ($appname == '')
 			{
@@ -624,7 +545,7 @@
 		* @param string $appname Name of application, defaults to $GLOBALS['phpgw_info']['flags']['currentapp']
 		* @return string|boolean Include directory or false
 		*/
-		function get_inc_dir($appname = '')
+		public function get_inc_dir($appname = '')
 		{
 			if (! $appname)
 			{
@@ -658,22 +579,30 @@
 		* Themes can either be css files like in HEAD (if the template has a css-directory) or ordinary .14 themes-files
 		* @return array List with available themes
 		*/
-		function list_themes()
+		public static function list_themes()
 		{
-			$tpl_dir = $this->get_tpl_dir('phpgwapi');
+			$tpl_dir = self::get_tpl_dir('phpgwapi');
+
+			$css_dir = "$tpl_dir/css";
+
 			$list = array();
-			if ($dh = @opendir($tpl_dir . SEP . 'css'))
+			if ( !is_dir($css_dir) )
+			{
+				return $list;
+			}
+
+			if ( $dh = opendir($css_dir) )
 			{
 				while ($file = readdir($dh))
 				{
-					if (eregi("\.css$",$file) && $file != 'base.css' && $file != 'login.css')
+					if (preg_match('/^[a-z0-9\-_]+\.css$/', $file) && $file != 'base.css' && $file != 'login.css')
 					{
-						$list[] = substr($file,0,strpos($file,'.'));
+						$list[] = substr($file, 0, strpos($file, '.') );
 					}
 				}
 				closedir($dh);
 			}
-			reset ($list);
+			sort($list);
 			return $list;
 		}
 
@@ -682,22 +611,24 @@
 		*
 		* @return array Alphabetically sorted list of available templates
 		*/
-		function list_templates()
+		public static function list_templates()
 		{
+			$ignore_list = array('.', '..', 'CVS', '.svn', 'default', 'phpgw_website', 'base');
+
+			$list = array();
+
 			$d = dir(PHPGW_SERVER_ROOT . '/phpgwapi/templates');
 			while ($entry=$d->read())
 			{
-				if ($entry != 'CVS' && $entry != '.' && $entry != '..' 
-					&& $entry != 'phpgw_website' && $entry != 'default'
-					&& $entry != 'base'
-					&& is_dir(PHPGW_SERVER_ROOT . '/phpgwapi/templates/' . $entry))
+				if ( !in_array($entry, $ignore_list)
+					&& is_dir(PHPGW_SERVER_ROOT . "/phpgwapi/templates/{$entry}"))
 				{
 					$list[$entry]['name'] = $entry;
-					$f = PHPGW_SERVER_ROOT . '/phpgwapi/templates/' . $entry . '/details.inc.php';
+					$f = PHPGW_SERVER_ROOT . "/phpgwapi/templates/{$entry}/details.inc.php";
 					if (file_exists ($f))
 					{
 						include($f);
-						$list[$entry]['title'] = 'Use '.$GLOBALS['phpgw_info']['template'][$entry]['title'].'interface';
+						$list[$entry]['title'] = "Use {$GLOBALS['phpgw_info']['template'][$entry]['title']}interface";
 					}
 					else
 					{
@@ -716,7 +647,7 @@
 		* @param string $appname application name optional can be derived from $GLOBALS['phpgw_info']['flags']['currentapp'];
 		* @param string? $layout optional can force the template set to a specific layout
 		*/
-		function get_tpl_dir($appname = '',$layout = '')
+		public function get_tpl_dir($appname = '',$layout = '')
 		{
 			if (! $appname)
 			{
@@ -747,35 +678,25 @@
 			elseif (@$GLOBALS['phpgw_info']['server']['template_set'] == 'user_choice' ||
 				!isset($GLOBALS['phpgw_info']['server']['template_set']))
 			{
-				$GLOBALS['phpgw_info']['server']['template_set'] = 'default';
+				$GLOBALS['phpgw_info']['server']['template_set'] = 'base';
 			}
 
-			$tpldir         = PHPGW_SERVER_ROOT . '/' . $appname . '/templates/' . $GLOBALS['phpgw_info']['server']['template_set'];
-			$tpldir_default = PHPGW_SERVER_ROOT . '/' . $appname . '/templates/default';
-			$tpldir_base = PHPGW_SERVER_ROOT . '/' . $appname . '/templates/base';
+			$tpldir         = PHPGW_SERVER_ROOT . "/{$appname}/templates/{$GLOBALS['phpgw_info']['server']['template_set']}";
+			$tpldir_default = PHPGW_SERVER_ROOT . "/{$appname}/templates/base";
 
-	/*		if ($layout == 'default')
-			{
-				$tpldir = $tpldir_default;
-			}
-	*/
 			if ($layout)
 			{
 				$tpldir = $tpldir_default = PHPGW_SERVER_ROOT . "/{$appname}/templates/{$layout}";
 			}
 
-			if (@is_dir($tpldir))
+			if (is_dir($tpldir))
 			{
 				return $tpldir;
 			}
-			elseif (@is_dir($tpldir_default))
+			elseif (is_dir($tpldir_default))
 			{
 				return $tpldir_default;
 			}
-			elseif (@is_dir($tpldir_base))
-			{
-				return $tpldir_base;
-			}
 			else
 			{
 				return False;
@@ -789,7 +710,7 @@
 		* @return boolean True when it is an image directory, otherwise false.
 		* @internal This is just a workaround for idots, better to use find_image, which has a fallback on a per image basis to the default dir
 		*/
-		function is_image_dir($dir)
+		public function is_image_dir($dir)
 		{
 			if (!@is_dir($dir))
 			{
@@ -800,7 +721,7 @@
 				while ($f = readdir($d))
 				{
 					$ext = strtolower(strrchr($f,'.'));
-					if (($ext == '.gif' || $ext == '.png') && strstr($f,'navbar') === False)
+					if ( $ext == '.png' && strstr($f,'navbar') === False)
 					{
 						return True;
 					}
@@ -815,7 +736,7 @@
 		* @param string $appname Application name, defaults to $GLOBALS['phpgw_info']['flags']['currentapp']
 		* @return string|boolean Image directory of given application or false
 		*/
-		function get_image_dir($appname = '')
+		public function get_image_dir($appname = '')
 		{
 			if ($appname == '')
 			{
@@ -828,20 +749,15 @@
 
 			$imagedir			= PHPGW_SERVER_ROOT . '/' . $appname . '/templates/' . $GLOBALS['phpgw_info']['server']['template_set'] . '/images';
 			$imagedir_default	= PHPGW_SERVER_ROOT . '/' . $appname . '/templates/base/images';
-			$imagedir_olddefault = PHPGW_SERVER_ROOT . '/' . $appname . '/templates/default/images';
 
-			if ($this->is_image_dir($imagedir))
+			if ($this->is_image_dir ($imagedir))
 			{
 				return $imagedir;
 			}
-			elseif ($this->is_image_dir($imagedir_default))
+			elseif ($this->is_image_dir ($imagedir_default))
 			{
 				return $imagedir_default;
 			}
-			elseif ($this->is_image_dir($imagedir_olddefault))
-			{
-				return $imagedir_olddefault;
-			}
 			else
 			{
 				return False;
@@ -854,7 +770,7 @@
 		* @param string $appname Appication name, defaults to $GLOBALS['phpgw_info']['flags']['currentapp']
 		* @return string|boolean Image directory path of given application or false
 		*/
-		function get_image_path($appname = '')
+		public function get_image_path($appname = '')
 		{
 			if ($appname == '')
 			{
@@ -868,106 +784,86 @@
 
 			$imagedir			= PHPGW_SERVER_ROOT . '/'.$appname.'/templates/'.$GLOBALS['phpgw_info']['server']['template_set'].'/images';
 			$imagedir_default	= PHPGW_SERVER_ROOT . '/'.$appname.'/templates/base/images';
-			$imagedir_olddefault = PHPGW_SERVER_ROOT . '/'.$appname.'/templates/default/images';
 
 			if ($this->is_image_dir($imagedir))
 			{
 				return $GLOBALS['phpgw_info']['server']['webserver_url'].'/'.$appname.'/templates/'.$GLOBALS['phpgw_info']['server']['template_set'].'/images';
 			}
-			elseif ($this->is_image_dir($imagedir_default))
+			elseif ($this->is_image_dir ($imagedir_default))
 			{
 				return $GLOBALS['phpgw_info']['server']['webserver_url'].'/'.$appname.'/templates/base/images';
 			}
-			elseif ($this->is_image_dir($imagedir_olddefault))
-			{
-				return $GLOBALS['phpgw_info']['server']['webserver_url'].'/'.$appname.'/templates/default/images';
-			}
 			else
 			{
 				return False;
 			}
 		}
 
-		function find_image($appname,$image)
+		/**
+		* Find an image
+		*
+		* @internal caches look ups for faster response times on subsequent searches
+		* @param string $module the module to check first for the image
+		* @param string $image the image to look for - without the extension, this is added during the checks
+		* @return string the URL pointing to the image
+		*/
+		public static function find_image($module, $image)
 		{
-			if ( !(isset($this->found_files[$appname]) && is_array($this->found_files[$appname]) ) )
+			static $found_files = null;
+			if ( !isset($found_files[$module]) || is_array($found_files[$module]) )
 			{
-				$imagedir_olddefault    = "/{$appname}/templates/default/images";
-				$imagedir_default	= "/{$appname}/templates/base/images";
-				$imagedir = "/{$appname}/templates/{$GLOBALS['phpgw_info']['user']['preferences']['common']['template_set']}/images";
+				$paths = array
+				(
+					"/{$module}/templates/base/images",
+					"/{$module}/templates/{$GLOBALS['phpgw_info']['user']['preferences']['common']['template_set']}/images"
+				);
 
-				if (@is_dir(PHPGW_INCLUDE_ROOT.$imagedir_olddefault))
+				foreach ( $paths as $path )
 				{
-					$d = dir(PHPGW_INCLUDE_ROOT.$imagedir_olddefault);
-					while (false != ($entry = $d->read()))
+					if ( is_dir(PHPGW_INCLUDE_ROOT . $path) )
 					{
-						if ($entry != '.' && $entry != '..')
+						$d = dir(PHPGW_INCLUDE_ROOT . $path);
+						while (false != ($entry = $d->read()))
 						{
-							$this->found_files[$appname][$entry] = $imagedir_olddefault;
+							if ($entry == '.' || $entry == '..')
+							{
+								continue;
+							}
+							$found_files[$module][$entry] = $path;
 						}
+						$d->close();
 					}
-					$d->close();
-				}
-
-				if (@is_dir(PHPGW_INCLUDE_ROOT.$imagedir_default))
-				{
-					$d = dir(PHPGW_INCLUDE_ROOT.$imagedir_default);
-					while (false != ($entry = $d->read()))
-					{
-						if ($entry != '.' && $entry != '..')
-						{
-							$this->found_files[$appname][$entry] = $imagedir_default;
-						}
-					}
-					$d->close();
-				}
-
-				if (@is_dir(PHPGW_INCLUDE_ROOT.$imagedir))
-				{
-					$d = dir(PHPGW_INCLUDE_ROOT.$imagedir);
-					while (false != ($entry = $d->read()))
-					{
-						if ($entry != '.' && $entry != '..')
-						{
-							$this->found_files[$appname][$entry] = $imagedir;
-						}
-					}
-					$d->close();
 				}
 			}
 
-			if(isset($this->found_files[$appname]["{$image}.png"]))
+			$exts = array('.png', '.jpg', '');
+			foreach ( array($module, 'phpgwapi') as $module )
 			{
-				$imgfile = $GLOBALS['phpgw_info']['server']['webserver_url'].$this->found_files[$appname][$image.'.png'].'/'.$image.'.png';
+				if ( !isset($found_files[$module]) )
+				{
+					continue;
+				}
+				foreach ( $exts as $ext )
+				{
+					if ( isset($found_files[$module]["{$image}{$ext}"]) )
+					{
+						return "{$GLOBALS['phpgw_info']['server']['webserver_url']}{$found_files[$module]["{$image}{$ext}"]}/{$image}{$ext}";
+					}
+				}
 			}
-			elseif(isset($this->found_files[$appname]["{$image}.jpg"]))
-			{
-				$imgfile = $GLOBALS['phpgw_info']['server']['webserver_url'].$this->found_files[$appname][$image.'.jpg'].'/'.$image.'.jpg';
-			}
-			elseif(isset($this->found_files[$appname][$image]))
-			{
-				$imgfile = $GLOBALS['phpgw_info']['server']['webserver_url'].$this->found_files[$appname][$image].'/'.$image;
-			}
-			elseif(isset($this->found_files['phpgwapi']["{$image}.png"]))
-			{
-				$imgfile = $GLOBALS['phpgw_info']['server']['webserver_url'].$this->found_files['phpgwapi'][$image.'.png'].'/'.$image.'.png';
-			}
-			elseif(isset($this->found_files['phpgwapi']["{$image}.jpg"]))
-			{
-				$imgfile = $GLOBALS['phpgw_info']['server']['webserver_url'].$this->found_files['phpgwapi'][$image.'.jpg'].'/'.$image.'.jpg';
-			}
-			elseif(isset($this->found_files['phpgwapi'][$image]))
-			{
-				$imgfile = $GLOBALS['phpgw_info']['server']['webserver_url'].$this->found_files['phpgwapi'][$image].'/'.$image;
-			}
-			else
-			{
-				$imgfile = '';
-			}
-			return $imgfile;
+			return '';
 		}
 
-		function image($appname, $image='', $ext='', $use_lang=True)
+		/**
+		* Find an individual image
+		*
+		* @param string $module the module the image is for
+		* @param string $image the image to search for
+		* @param string $ext the filename extension of the image - should usually be an empty string
+		* @param bool $use_lang use a translated verison of the image
+		* @return string URL to image
+		*/
+		public static function image($module, $image = '', $ext = '', $use_lang = true)
 		{
 			if (!is_array($image))
 			{
@@ -980,46 +876,48 @@
 
 			if ($use_lang)
 			{
-				while (list(,$img) = each($image))
+				foreach ( $image as $img )
 				{
 					$lang_images[] = $img . '_' . $GLOBALS['phpgw_info']['user']['preferences']['common']['lang'];
 					$lang_images[] = $img;
 				}
 				$image = $lang_images;
 			}
-			
-			$image_found = false;
-			while (!$image_found && (list(,$img) = each($image)))
+
+			foreach ( $image as $img )
 			{
-				if(isset($this->found_files[$appname][$img.$ext]))
+				$image_found = self::find_image($module, $img.$ext); 
+				if ( $image_found )
 				{
-					$image_found = "{$GLOBALS['phpgw_info']['server']['webserver_url']}{$this->found_files[$appname][$img.$ext]}/{$img}{$ext}";
-				}
-				else
-				{
-					$image_found = $this->find_image($appname, $img.$ext);
+					return $image_found;
 				}
 			}
-			//echo "image: {" . print_r($image, true) . " image_found: {$image_found}<br />\n";
-			return $image_found;
+			return '';
 		}
 
-		function image_on($appname,$image,$extension='_on')
+		/**
+		* Find an individual "mouse over" image
+		*
+		* @param string $module the module the image is for
+		* @param string $image the image to search for
+		* @param string $ext the extension used to indicate a "mouse ob" image
+		* @return string URL to image
+		*/
+		public function image_on($appname, $image, $extension = '_on')
 		{
 			$with_extension = $this->image($appname,$image,$extension);
-			$without_extension = $this->image($appname,$image);
-			if($with_extension != '')
+			if ( $with_extension )
 			{
 				return $with_extension;
 			}
-			elseif($without_extension != '')
+			
+			$without_extension = $this->image($appname,$image);
+			if ( $without_extension )
 			{
 				return $without_extension;
 			}
-			else
-			{
-				return '';
-			}
+
+			return '';
 		}
 
 		function navbar()
@@ -1117,7 +1015,7 @@
 		/**
 		* Load header.inc.php for an application
 		*/
-		function app_header()
+		public function app_header()
 		{
 			if (file_exists(PHPGW_APP_INC . '/header.inc.php'))
 			{
@@ -1128,7 +1026,7 @@
 		/**
 		* Load the phpgw header
 		*/
-		function phpgw_header($navbar = False)
+		public function phpgw_header($navbar = False)
 		{
 			include(PHPGW_INCLUDE_ROOT . '/phpgwapi/templates/' . $GLOBALS['phpgw_info']['server']['template_set'] . '/head.inc.php');
 			$this->navbar(False);
@@ -1145,12 +1043,15 @@
 			}
 		}
 
-		function phpgw_footer()
+		/**
+		* Render the page footer
+		*/
+		public function phpgw_footer()
 		{
-			if (!defined('PHPGW_FOOTER'))
+			static $footer_rendered = false;
+			if ( !$footer_rendered )
 			{
-				define('PHPGW_FOOTER',True);
-
+				$footer_rendered = true;
 				/* used for xslt apps without xslt framework */
 				if ( isset($GLOBALS['phpgw_info']['flags']['xslt_app'])
 					&& $GLOBALS['phpgw_info']['flags']['xslt_app'] )
@@ -1158,7 +1059,8 @@
 					$GLOBALS['phpgw']->xslttpl->pparse();
 				}
 
-				if (!isset($GLOBALS['phpgw_info']['flags']['nofooter']) || !$GLOBALS['phpgw_info']['flags']['nofooter'])
+				if ( !isset($GLOBALS['phpgw_info']['flags']['nofooter']) 
+					|| !$GLOBALS['phpgw_info']['flags']['nofooter'] )
 				{
 					include(PHPGW_API_INC . '/footer.inc.php');
 				}
@@ -1175,7 +1077,7 @@
 		* @author Dave Hall skwashd at phpgroupware.org
 		* @return string Template including CSS definitions
 		*/
-		function get_css()
+		public function get_css()
 		{
 			$all_css = '';
 			if( isset($GLOBALS['phpgw']->css) && is_object($GLOBALS['phpgw']->css) )
@@ -1214,7 +1116,7 @@
 		* Backwards compatibility method
 		* @see get_javascript
 		*/
-		function get_java_script()
+		public function get_java_script()
 		{
 			return $this->get_javascript();
 		}
@@ -1229,7 +1131,7 @@
 		* @author Dave Hall skwashd at phpgroupware.org
 		* @return string The JavaScript code to include
 		*/
-		function get_javascript()
+		public function get_javascript()
 		{
 			$js = '';
 			if( isset($GLOBALS['phpgw']->js) && is_object($GLOBALS['phpgw']->js))
@@ -1256,13 +1158,13 @@
 			return $js;
 		}
 		
-				/**
+		/**
 		* Get window.on* events from javascript class
 		*
 		* @author Dave Hall skwashd at phpgroupware.org
 		* @return string the wndow events to be used or empty
 		*/
-		function get_on_events()
+		public function get_on_events()
 		{
 			if(@is_object($GLOBALS['phpgw']->js))
 			{
@@ -1274,29 +1176,16 @@
 			}
 		}
 
-		function hex2bin($data)
+		/**
+		* Convert hexadecimal data into binary
+		*
+		* @param string $data hexidecimal data as a string
+		* @return string binary value of $data;
+		*/
+		public function hex2bin($data)
 		{
 			$len = strlen($data);
-			return @pack('H' . $len, $data);
-		}
-
-	
-		/**
-		* Get on(un)load attributes from javascript class
-		*
-		* @author Dave Hall <skwashd@phpgroupware.org>
-		* @return string Body attributes or empty
-		*/
-		function get_body_attribs()
-		{
-			if(@is_object($GLOBALS['phpgw']->js))
-			{
-				return $GLOBALS['phpgw']->js->get_body_attribs();
-			}
-			else
-			{
-				return '';
-			}
+			return pack('H' . $len, $data);
 		}
 
 		/**
@@ -1305,7 +1194,7 @@
 		* @param string $data Data to be encrypted
 		* @return string Encrypted data
 		*/
-		function encrypt($data)
+		public function encrypt($data)
 		{
 			return $GLOBALS['phpgw']->crypto->encrypt($data);
 		}
@@ -1315,7 +1204,7 @@
 		* @param string $data Data to be decrypted
 		* @return string Decrypted data
 		*/
-		function decrypt($data)
+		public function decrypt($data)
 		{
 			return $GLOBALS['phpgw']->crypto->decrypt($data);
 		}
@@ -1327,7 +1216,7 @@
 		* @param string $random Random seed
 		* @return string DES encrypted password
 		*/
-		function des_cryptpasswd($userpass, $random)
+		public function des_cryptpasswd($userpass, $random)
 		{
 			$lcrypt = '{crypt}';
 			$password = crypt($userpass, $random);
@@ -1344,7 +1233,7 @@
 		* @param string $random Random seed
 		* @return string MD5 encrypted password
 		*/ 
-		function md5_cryptpasswd($userpass)
+		public function md5_cryptpasswd($userpass)
 		{
 			return '{md5}' . base64_encode(pack('H*', md5($userpass)));
 		}
@@ -1355,7 +1244,7 @@
 		* @param string $password Password to encrypt
 		* @return Encrypted password or false
 		*/
-		function encrypt_password($password)
+		public function encrypt_password($password)
 		{
 			if (strtolower($GLOBALS['phpgw_info']['server']['ldap_encryption_type']) == 'des')
 			{
@@ -1378,7 +1267,7 @@
 		* @param integer $app Application id to find current position
 		* @return integer Applications position or -1
 		*/
-		function find_portal_order($app)
+		public function find_portal_order($app)
 		{
 			if(!is_array($GLOBALS['phpgw_info']['user']['preferences']['portal_order']))
 			{
@@ -1404,10 +1293,10 @@
 		* @return mixed Result of $GLOBALS['phpgw']->session->appsession()
 		* @deprecated
 		*/
-		function appsession($data = '##NOTHING##')
+		public function appsession($data = '##NOTHING##')
 		{
-		//	echo 'common::appsession() is a depreciated function'
-		//		. " - use session::appsession() instead<br>\n";
+			echo 'common::appsession() is a depreciated function'
+				. " - use session::appsession() instead<br>\n";
 
 			return $GLOBALS['phpgw']->session->appsession('default','',$data);
 		}
@@ -1419,20 +1308,15 @@
 		* @param string $format Date format, defaults to user preferences
 		* @return string Formated date
 		*/
-		function show_date($t = '', $format = '')
+		public function show_date($t = '', $format = '')
 		{
-			if(!is_object($GLOBALS['phpgw']->datetime))
-			{
-				$GLOBALS['phpgw']->datetime = createObject('phpgwapi.datetimefunctions');
-			}
-			
 			if (!$t || (substr(php_uname(), 0, 7) == "Windows" && intval($t) <= 0))
 			{
-				$t = $GLOBALS['phpgw']->datetime->gmtnow;
+				$t = phpgwapi_datetime::gmtnow();
 			}
 
 			//  + (date('I') == 1?3600:0)
-			$t += $GLOBALS['phpgw']->datetime->tz_offset;
+			$t += phpgwapi_datetime::user_timezone();
 			
 			if (! $format)
 			{
@@ -1458,7 +1342,7 @@
 		* @param boolean $add_seperator Use separator, defaults to space
 		* @return string Formatted date
 		*/
-		function dateformatorder($yearstr,$monthstr,$daystr,$add_seperator = False)
+		public function dateformatorder($yearstr,$monthstr,$daystr,$add_seperator = False)
 		{
 			$dateformat = strtolower($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
 			$sep = substr($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'],1,1);
@@ -1486,43 +1370,9 @@
 		* @param integer $sec Second
 		* @return string Time formatted as hhmmss with am/pm
 		*/
-		function formattime($hour,$min,$sec='')
+		public function formattime($hour, $min = 0, $sec = null)
 		{
-			$h12 = $hour;
-			$ampm = '';
-			if ($GLOBALS['phpgw_info']['user']['preferences']['common']['timeformat'] == '12')
-			{
-				if ($hour >= 12) 
-				{
-					$ampm = ' pm';
-				}
-				else
-				{
-					$ampm = ' am';
-				}
-
-				$h12 %= 12;
-
-				if ($h12 == 0 && $hour)
-				{
-					$h12 = 12;
-				}
-				if ($h12 == 0 && !$hour)
-				{
-					$h12 = 0;
-				}
-			}
-			else 
-			{
-				$h12 = $hour;
-			}
-
-			if ($sec)
-			{
-				$sec = ":$sec";
-			}
-
-			return "$h12:$min$sec$ampm";
+			die('use phpgwapi_datetime::format_time()');
 		}
 
 		/**
@@ -1532,7 +1382,7 @@
 		* @param integer $account_id Account id, defaults to phpgw_info['user']['account_id']
 		* @internal This is not the best place for it, but it needs to be shared between Aeromail and SM
 		*/
-		function create_emailpreferences($prefs='',$accountid='')
+		public function create_emailpreferences($prefs='',$accountid='')
 		{
 			return $GLOBALS['phpgw']->preferences->create_email_preferences($accountid);
 			// Create the email Message Class if needed
@@ -1563,7 +1413,7 @@
 		* @return string HTML string with code check result message
 		* @internal This will be moved into the applications area
 		*/
-		function check_code($code)
+		public function check_code($code)
 		{
 			$s = '<br />';
 			switch ($code)
@@ -1657,7 +1507,7 @@
 		* @param integer $line Line number of error
 		* @param string $file Filename in which the error occured
 		*/
-		function phpgw_error($error,$line = '', $file = '') 
+		public function phpgw_error($error,$line = '', $file = '') 
 		{
 			echo '<p><strong>phpGroupWare internal error:</strong><p>'.$error;
 			if ($line)
@@ -1677,7 +1527,7 @@
 		*
 		* @internal Works on systems with grep only
 		*/
-		function debug_list_core_functions()
+		public function debug_list_core_functions()
 		{
 			echo 'common::debug_list_core_functions() is deprecated - no output generated!<br />';
 		}
@@ -1690,7 +1540,7 @@
 		* @param integer $max Maximum of id range
 		* @return integer|boolean Next available id or false
 		*/
-		function next_id($appname,$min=0,$max=0)
+		public function next_id($appname,$min=0,$max=0)
 		{
 			if (!$appname)
 			{
@@ -1734,7 +1584,7 @@
 		* @param integer $max Maximum of id range
 		* @return integer|boolean Last used id or false
 		*/
-		function last_id($appname,$min=0,$max=0)
+		public function last_id($appname,$min=0,$max=0)
 		{
 			if (!$appname)
 			{
@@ -1774,7 +1624,10 @@
 			}
 		}
 
-		function start_xslt_capture()
+		/**
+		* Starts capturing all output so it can be used by the XSLT temaplte engine
+		*/
+		public function start_xslt_capture()
 		{
 			if (!isset($GLOBALS['phpgw_info']['xslt_capture']))
 			{
@@ -1783,10 +1636,14 @@
 			}
 		}
 
-		/* Note: need to be run BEFORE exit is called, as buffers get flushed automatically before
-		 *       any registered shutdown-functions (eg. phpgw_footer) gets called
-		 */
-		function stop_xslt_capture()
+		/**
+		* Stops capturing all output and uses it in the XSLT temaplte engine by stuffing it 
+		* into an xml node called "body_data"
+		*
+		* @internal Note: need to be run BEFORE exit is called, as buffers get flushed automatically before
+		* any registered shutdown-functions (eg. phpgw_footer) gets called
+		*/
+		public function stop_xslt_capture()
 		{
 			if (isset($GLOBALS['phpgw_info']['xslt_capture']))
 			{
@@ -1808,8 +1665,7 @@
 		* @param string $base ???
 		* @returns ????
 		*/
-
-		function msgbox($text = '', $type = True, $base = '')
+		public function msgbox($text = '', $type = True, $base = '')
 		{
 			if ($text=='' && @isset($GLOBALS['phpgw_info']['flags']['msgbox_data']))
 			{
@@ -1893,7 +1749,7 @@
 		* @returns array for use with msgbox
 		*/
 		
-		function msgbox_data($receipt)
+		public function msgbox_data($receipt)
 		{
 			$msgbox_data_error=array();
 			if (isSet($receipt['error']) AND is_array($receipt['error']))
