@@ -8,13 +8,14 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package phpgwapi
-	* @version $Id: class.custom_fields.inc.php,v 1.2 2007/02/11 17:43:46 sigurdne Exp $
+	* @version $Id: class.custom_fields.inc.php 18358 2007-11-27 04:43:37Z skwashd $
 	*/
 
 	/**
 	 * Custom Fields
 	 * @package phpgwapi
 	 */
+	phpgw::import_class('phpgwapi.datetime');
 	class custom_fields
 	{
 		/**
@@ -46,6 +47,11 @@
 			'save'				=> true
 		);
 
+		/**
+		* @var int $total_records total number of records found
+		*/
+		var $total_records = 0;
+
 		var $soap_functions = array(
 			'list' => array(
 				'in'  => array('int','int','struct','string','int'),
@@ -83,11 +89,12 @@
 			
 			$this->location = $location;
 		
-			$this->account		= $GLOBALS['phpgw_info']['user']['account_id'];
-			$this->db           = clone($GLOBALS['phpgw']->db); // clone to awoid conflict the db in lang-function
-			$this->db2			= clone($this->db);
-			$this->join			= $this->db->join;
-			$this->like			= $this->db->like;
+			$this->account			= $GLOBALS['phpgw_info']['user']['account_id'];
+			$this->db           	=& $GLOBALS['phpgw']->db; // clone to avoid conflict the db in lang-function
+			$this->join				= $this->db->join;
+			$this->like				= $this->db->like;
+			$this->dateformat 		= phpgwapi_db::date_format();
+			$this->datetimeformat 	= phpgwapi_db::datetime_format();
 
 			if($this->appname && $this->location)
 			{
@@ -115,10 +122,11 @@
 		/**
 		 * Add a custom field/attribute
 		 * 
-		 * @param array $attirb the field data
+		 * @param array $attrib the field data
+		 * @param string $attrib_table where to append the attrib
 		 * @return int the the new custom field db pk
 		 */
-		function add_attrib($attrib)
+		function add_attrib($attrib, $attrib_table = '')
 		{
 			$receipt = array();
 			// Checkboxes are only present if ticked, so we declare them here to stop errors
@@ -126,10 +134,11 @@
 			$attrib['list'] = isset($attrib['list']) ? !!$attrib['list'] : false;
 			$attrib['history'] = isset($attrib['history']) ? !!$attrib['history'] : false;
 
-			$attrib['column_name'] = $this->db->db_addslashes($attrib['column_name']);
+			$attrib['column_name'] = $this->db->db_addslashes(strtolower($attrib['column_name']));
 			$attrib['input_text'] = $this->db->db_addslashes($attrib['input_text']);
 			$attrib['statustext'] = $this->db->db_addslashes($attrib['statustext']);
 			$attrib['default'] =  isset($arrib['default']) ? $this->db->db_addslashes($attrib['default']) : '';
+			$attrib['helpmsg'] = $this->db->db_addslashes($attrib['helpmsg']);
 
 			$sql = "SELECT * FROM phpgw_cust_attribute where appname='{$attrib['appname']}' AND location='{$attrib['location']}' AND column_name = '{$attrib['column_name']}'";
 			$this->db->query($sql,__LINE__,__FILE__);
@@ -142,7 +151,7 @@
 				return $receipt; //no point continuing
 			}
 
-			$this->db->transaction_begin();
+
 
 			$sql = 'SELECT MAX(attrib_sort) AS max_sort, MAX(id) AS current_id FROM phpgw_cust_attribute'
 					. " WHERE appname='{$attrib['appname']}' AND location='{$attrib['location']}'";
@@ -172,6 +181,8 @@
 				$attrib['search'],
 				$attrib['list'],
 				$attrib['history'],
+				$attrib['disabled'],
+				$attrib['helpmsg'],
 				$attrib_sort,
 				$attrib['column_info']['type'],
 				$attrib['column_info']['precision'],
@@ -182,7 +193,11 @@
 
 			$values	= $this->db->validate_insert($values);
 
-			$this->db->query("INSERT INTO phpgw_cust_attribute (appname,location,id,column_name, input_text, statustext,search,list,history,attrib_sort, datatype,precision_,scale,default_value,nullable) "
+			$this->_init_process();
+
+			$this->db->transaction_begin();
+
+			$this->db->query("INSERT INTO phpgw_cust_attribute (appname,location,id,column_name, input_text, statustext,search,list,history,disabled,helpmsg,attrib_sort, datatype,precision_,scale,default_value,nullable) "
 				. "VALUES ($values)",__LINE__,__FILE__);
 
 			$receipt['id']= $attrib['id'];
@@ -202,15 +217,19 @@
 				unset($attrib['column_info']['default']);
 			}
 
-			$attrib_table = $this->get_attrib_table($attrib['appname'],$attrib['location']);
+			if(!$attrib_table)
+			{
+				$attrib_table = $this->get_attrib_table($attrib['appname'],$attrib['location']);
+			}
 
-			$this->_init_process();
-			
-			if($this->oProc->AddColumn($attrib_table,$attrib['column_name'], $attrib['column_info']))
+			$this->oProc->m_odb->transaction_begin();
+
+			$this->oProc->AddColumn($attrib_table,$attrib['column_name'], $attrib['column_info']);
+
+			if($this->oProc->m_odb->transaction_commit())
 			{
 				$receipt['message'][] = array('msg'	=> lang('Attribute has been saved')	);
 				$this->db->transaction_commit();
-
 			}
 			else
 			{
@@ -226,6 +245,7 @@
 
 				}
 			}
+
 			return $receipt;
 		}
 
@@ -301,26 +321,31 @@
 			}
 			endif;
 		}
-		
+
 		/**
 		 * Edit a custom field
 		 * 
 		 * @param array $attrib the field data
+		 * @param string $attrib_table where to edit the attrib
 		 * @return int the field db pk
 		 */
-		function edit_attrib($attrib)
+		function edit_attrib($attrib, $attrib_table = '')
 		{
 			// Checkboxes are only present if ticked, so we declare them here to stop errors
 			$attrib['search'] = isset($attrib['search']) ? !!$attrib['search'] : false;
 			$attrib['list'] = isset($attrib['list']) ? !!$attrib['list'] : false;
 			$attrib['history'] = isset($attrib['history']) ? !!$attrib['history'] : false;
-			
-			$attrib_table = $this->get_attrib_table($attrib['appname'],$attrib['location']);
+
+			if(!$attrib_table)
+			{
+				$attrib_table = $this->get_attrib_table($attrib['appname'],$attrib['location']);
+			}
 			$choice_table = 'phpgw_cust_choice';
 
 			$attrib['column_name'] = $this->db->db_addslashes($attrib['column_name']);
 			$attrib['input_text'] = $this->db->db_addslashes($attrib['input_text']);
 			$attrib['statustext'] = $this->db->db_addslashes($attrib['statustext']);
+			$attrib['helpmsg'] = $this->db->db_addslashes($attrib['helpmsg']);
 			$attrib['column_info']['default'] = $this->db->db_addslashes($attrib['column_info']['default']);
 
 			if($attrib['column_info']['type']=='R' || $attrib['column_info']['type']== 'CH' || $attrib['column_info']['type'] =='LB' || $attrib['column_info']['type'] =='AB' || $attrib['column_info']['type'] =='VENDOR')
@@ -339,7 +364,7 @@
 			$OldDataType		= $this->db->f('datatype');
 			$OldPrecision		= $this->db->f('precision_');			
 			
-//			$table_def = $this->get_table_def($attrib['appname'],$attrib['location']);	
+			$table_def = $this->get_table_def($attrib_table);	
 
 			$this->db->transaction_begin();
 
@@ -350,18 +375,18 @@
 				'search'		=> isset($attrib['search']) ? $attrib['search'] : '',
 				'list'			=> isset($attrib['list']) ? $attrib['list'] : '',
 				'history'		=> isset($attrib['history']) ? $attrib['history'] : '',
-				'nullable'		=> $attrib['column_info']['nullable'] == False ? 'False' : 'True'
+				'nullable'		=> $attrib['column_info']['nullable'] == 'False' ? 'False' : 'True',
+				'disabled'		=> isset($attrib['disabled']) ? $attrib['disabled'] : '',
+				'helpmsg'		=> $attrib['helpmsg'],
 			);
 
 			$value_set	= $this->db->validate_update($value_set);
 
 			$this->db->query("UPDATE phpgw_cust_attribute set $value_set WHERE appname='" . $attrib['appname']. "' AND location='" . $attrib['location']. "' AND id=" . $attrib['id'],__LINE__,__FILE__);
 
-			$this->_init_process();
-			
 			$this->oProc->m_odb->transaction_begin();
 
-//			$this->oProc->m_aTables = $table_def;
+			$this->oProc->m_aTables = $table_def;
 
 			if($OldColumnName !=$attrib['column_name'])
 			{
@@ -467,7 +492,7 @@
 				$value_set=array(
 					'descr'		=> $custom_function['descr'],
 					'file_name'	=> $custom_function['custom_function_file'],
-					'active'	=> $custom_function['active']
+					'active'	=> isset($custom_function['active'])?$custom_function['active']:''
 					);
 
 				$value_set	= $this->db->validate_update($value_set);
@@ -487,7 +512,7 @@
 		 * @param string $appname the name of the application
 		 * @param string $location the name of the location
 		 */
-		function get_attribs($appname, $location, $start = 0, $query = '', $sort = 'ASC', $order = 'attrib_sort', $allrows = false, $inc_choices = false)
+		function get_attribs($appname, $location, $start = 0, $query = '', $sort = 'ASC', $order = 'attrib_sort', $allrows = false, $inc_choices = false,$filtermethod='')
 		{
 			$start		= (int) $start;
 			$query		= $this->db->db_addslashes($query);
@@ -513,19 +538,27 @@
 			}
 
 			$querymethod = '';
-			if($query)
+			if ( $query )
 			{
 				$querymethod = " AND (phpgw_cust_attribute.column_name $this->like '%$query%' or phpgw_cust_attribute.input_text $this->like '%$query%')";
 			}
 
-			$sql = "FROM phpgw_cust_attribute WHERE appname='$appname' AND location = '$location' ";
+			$sql = "FROM phpgw_cust_attribute WHERE appname='$appname' AND location = '$location' AND custom = 1 $querymethod $filtermethod";
+
+			$this->total_records = 0;
+			$this->db->query("SELECT COUNT(id) AS cnt_rec $sql",__LINE__,__FILE__);
+			if ( $this->db->next_record() )
+			{
+				$this->total_records = $this->db->f('cnt_rec');;
+			}
+
 			if ( $allrows )
 			{
-				$this->db->query("SELECT * $sql" . $querymethod . $ordermethod, __LINE__, __FILE__);
+				$this->db->query("SELECT * $sql" . $ordermethod, __LINE__, __FILE__);
 			}
 			else
 			{
-				$this->db->limit_query("SELECT * $sql" . $querymethod . $ordermethod,$start, __LINE__, __FILE__);
+				$this->db->limit_query("SELECT * $sql" . $ordermethod,$start, __LINE__, __FILE__);
 			}
 
 			$attribs = array();
@@ -534,13 +567,14 @@
 				$attribs[] = array
 				(
 					'id'				=> $this->db->f('id'),
+					'attrib_id'			=> $this->db->f('id'), // FIXME: for now...
 					'entity_type'		=> $this->db->f('type_id'),
 					'attrib_sort'		=> (int) $this->db->f('attrib_sort'),
 					'list'				=> $this->db->f('list'),
 					'lookup_form'		=> $this->db->f('lookup_form'),
 					'entity_form'		=> $this->db->f('entity_form'),
 					'column_name'		=> $this->db->f('column_name'),
-					'name'				=> $this->db->f('input_text', true),
+					'name'				=> $this->db->f('column_name'),
 					'size'				=> $this->db->f('size'),
 					'statustext'		=> $this->db->f('statustext', true),
 					'input_text'		=> $this->db->f('input_text', true),
@@ -548,26 +582,24 @@
 					'datatype'			=> $this->db->f('datatype'),
 					'search'			=> $this->db->f('search'),
 					'trans_datatype'	=> $this->translate_datatype($this->db->f('datatype')),
-					'nullable'			=> ($this->db->f('nullable') == 'True')
-				);
-			}
+					'nullable'			=> ($this->db->f('nullable') == 'True'),
+					'allow_null'		=> ($this->db->f('nullable') == 'True'), // FIXME: for now...
+					'history'			=> $this->db->f('history'),
+					'disabled'			=> $this->db->f('disabled'),
+					'helpmsg'			=> !!$this->db->f('helpmsg')
 
-			$this->total_records = count($attribs);
-			$this->db->query("SELECT COUNT(id) AS cnt_rec $sql",__LINE__,__FILE__);
-			if ( $this->db->next_record() )
-			{
-				$this->total_records = $this->db->f('cnt_rec');;
+				);
 			}
 
 			if ( count($attribs) && $inc_choices )
 			{
-				foreach ( $attribs as $aid => $attrib )
+				foreach ( $attribs as &$attrib )
 				{
 					if ( $attrib['datatype'] == 'R'
 						|| $attrib['datatype'] == 'CH'
 						|| $attrib['datatype'] =='LB')
 					{
-						$attribs[$aid]['choice'] = $this->read_attrib_choice($appname, $location, $attrib['id']);
+						$attrib['choice'] = $this->read_attrib_choice($appname, $location, $attrib['id']);
 					}
 				}
 			}
@@ -593,6 +625,7 @@
 			if ($this->db->next_record())
 			{
 				$attrib['id']						= $this->db->f('id');
+				$attrib['attrib_id']				= $this->db->f('id'); // for now...
 				$attrib['column_name']				= $this->db->f('column_name');
 				$attrib['input_text']				= $this->db->f('input_text', true);
 				$attrib['statustext']				= $this->db->f('statustext', true);
@@ -608,7 +641,11 @@
 				$attrib['search']					= $this->db->f('search');
 				$attrib['history']					= $this->db->f('history');
 				$attrib['location']					= $this->db->f('location');
-				
+				$attrib['nullable']					= ($this->db->f('nullable') == 'True');
+				$attrib['allow_null']				= ($this->db->f('nullable') == 'True'); // FIXME: for now...
+				$attrib['disabled']					= $this->db->f('disabled');
+				$attrib['helpmsg']					= stripslashes($this->db->f('helpmsg'));
+
 				if ( $inc_choices 
 					&& ( $this->db->f('datatype') == 'R' 
 						|| $this->db->f('datatype') == 'CH' 
@@ -800,8 +837,8 @@
 		function resort_custom_function($id, $resort, $appname, $location)
 		{
 			$resort = $resort == 'down' ? 'down' : 'up';
-			$appname = $this->db->db_addslashes($this->appname);
-			$location = $this->db->db_addslashes($this->location);
+			$appname = $this->db->db_addslashes($appname);
+			$location = $this->db->db_addslashes($location);
 			$id = (int)$id;
 
 			if(!$location || !$appname)
@@ -845,44 +882,6 @@
 			$this->db->transaction_commit();
 		}
 
-		/**
-		 * Save an attribute record
-		 * 
-		 * @param array $attrib the attribute data
-		 * @param string $action the save action to use [edit|save]
-		 * @return int the attribute id (db pk)
-		 */
-		function save_attrib($attrib, $action='edit')
-		{
-			if ($action=='edit')
-			{
-				if ( isset($attrib['id']) && $attrib['id'])
-				{
-
-					return $this->so->edit_attrib($attrib);
-				}
-			}
-			return $this->so->add_attrib($attrib);
-		}
-
-		function save_custom_function($custom_function,$action='')
-		{
-			$receipt = 0;
-			if ($action=='edit')
-			{
-				if ($custom_function['id'] != '')
-				{
-
-					$receipt = $this->so->edit_custom_function($custom_function);
-				}
-			}
-			else
-			{
-				$receipt = $this->so->add_custom_function($custom_function);
-			}
-			return $receipt;
-		}
-
 		function select_custom_function($selected='', $appname)
 		{
 
@@ -972,10 +971,10 @@
 				'link' => 255
 			);
 
-			return $datatype_precision[$datatype];
+			return isset($datatype_precision[$datatype])?$datatype_precision[$datatype]:'';
 		}
 
-		function _delete_attrib($location,$appname,$attrib_id)
+		function _delete_attrib($location,$appname,$attrib_id,$table = '')
 		{
 			$this->_init_process();
 			$this->oProc->m_odb->transaction_begin();
@@ -987,7 +986,10 @@
 			$this->db->next_record();
 
 			$ColumnName		= $this->db->f('column_name');
-			$table = $this->get_attrib_table($appname,$location);
+			if(!$table)
+			{
+				$table = $this->get_attrib_table($appname,$location);
+			}
 
 			$this->oProc->DropColumn($table,false, $ColumnName);
 
@@ -1012,6 +1014,30 @@
 			$this->db->transaction_commit();
 			$this->oProc->m_odb->transaction_commit();
 		}
+
+		function get_table_def($table = '', $table_def = array())
+		{
+			if(!isset($this->oProc) || !is_object($this->oProc))
+			{
+				$this->_init_process();
+				$GLOBALS['phpgw_setup']->oProc = $this->oProc;
+			}
+
+			$setup = createobject('phpgwapi.setup_process');
+			$tableinfo = $setup->sql_to_array($table);
+
+			$fd = '$fd = array(' . str_replace("\t",'',$tableinfo[0]) .');';
+
+			eval($fd);
+			$table_def[$table]['fd'] = isset($table_def[$table]['fd']) && $table_def[$table]['fd'] ? $table_def[$table]['fd'] + $fd : $fd;
+			$table_def[$table]['pk'] = isset($table_def[$table]['pk']) && $table_def[$table]['pk'] ? $table_def[$table]['pk'] : $tableinfo[1];
+			$table_def[$table]['fk'] = isset($table_def[$table]['fk']) && $table_def[$table]['fk'] ? $table_def[$table]['fk'] : $tableinfo[2];		
+			$table_def[$table]['ix'] = isset($table_def[$table]['ix']) && $table_def[$table]['ix'] ? $table_def[$table]['ix'] : $tableinfo[3];
+			$table_def[$table]['uc'] = isset($table_def[$table]['uc']) && $table_def[$table]['uc'] ? $table_def[$table]['uc'] : $tableinfo[4];
+			
+//	_debug_array($table_def);
+			return $table_def;
+		}
 		
 		function _delete_custom_function($appname,$location,$custom_function_id)
 		{
@@ -1036,8 +1062,8 @@
 		function _init_process()
 		{
 			$this->oProc 				= createObject('phpgwapi.schema_proc',$GLOBALS['phpgw_info']['server']['db_type']);
-			$this->oProc->m_odb			=& $this->db;
-			$this->oProc->m_odb->Halt_On_Error	= 'report';
+			$this->oProc->m_odb			= clone($this->db); // nested transactions
+			$this->oProc->m_odb->Halt_On_Error	= 'yes';
 		}
 		
 		/**
@@ -1064,9 +1090,9 @@
 				$where='WHERE ' . implode("' AND ", $condition) . "'";
 			}
 
-			$this->db2->query("SELECT max(id) as maximum FROM $table $where",__LINE__,__FILE__);
-			$this->db2->next_record();
-			$next_id = $this->db2->f('maximum')+1;
+			$this->db->query("SELECT max(id) as maximum FROM $table $where",__LINE__,__FILE__);
+			$this->db->next_record();
+			$next_id = $this->db->f('maximum')+1;
 			return $next_id;
 		}
 
@@ -1077,8 +1103,12 @@
 		 * @return array values and definitions of custom attributes prepared for ui
 		 */
 
-		function prepare_attributes($values='',$appname, $location)
+		function prepare_attributes($values='',$appname, $location,$view_only='')
 		{
+			$contacts		= CreateObject('phpgwapi.contacts');
+			$vendor 		= CreateObject('property.soactor');
+			$vendor->role	= 'vendor';
+
 			$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 
 			$input_type_array = array(
@@ -1087,21 +1117,24 @@
 				'LB' => 'listbox'
 			);
 
-//_debug_array($values['attributes']);
 			$m=0;
 			for ($i=0;$i<count($values['attributes']);$i++)
 			{
 				$values['attributes'][$i]['datatype_text'] 	= $this->translate_datatype($values['attributes'][$i]['datatype']);
+				$values['attributes'][$i]['help_url']		= $values['attributes'][$i]['helpmsg'] ? $GLOBALS['phpgw']->link('/index.php', array('menuaction'=> 'manual.uimanual.attrib_help', 'appname'=> $appname, 'location'=> $location, 'id' => $values['attributes'][$i]['id'])): '';
 				if($values['attributes'][$i]['datatype']=='D')
 				{
-					if ( !isset($GLOBALS['phpgw']->jscal) || !is_object($GLOBALS['phpgw']->jscal) )
+					if(!$view_only)
 					{
-						$GLOBALS['phpgw']->jscal = createObject('phpgwapi.jscalendar');
-					}
+						if ( !isset($GLOBALS['phpgw']->jscal) || !is_object($GLOBALS['phpgw']->jscal) )
+						{
+							$GLOBALS['phpgw']->jscal = createObject('phpgwapi.jscalendar');
+						}
 
-					$GLOBALS['phpgw']->jscal->add_listener('values_attribute_' . $i);
-					$values['attributes'][$i]['img_cal']= $GLOBALS['phpgw']->common->image('phpgwapi','cal');
-					$values['attributes'][$i]['lang_datetitle']= lang('Select date');
+						$GLOBALS['phpgw']->jscal->add_listener('values_attribute_' . $i);
+						$values['attributes'][$i]['img_cal']= $GLOBALS['phpgw']->common->image('phpgwapi','cal');
+						$values['attributes'][$i]['lang_datetitle']= lang('Select date');
+					}
 
 					if(isset($values['attributes'][$i]['value']) && $values['attributes'][$i]['value'])
 					{
@@ -1109,7 +1142,7 @@
 						$values['attributes'][$i]['value']	= $GLOBALS['phpgw']->common->show_date($timestamp_date,$dateformat);
 					}
 				}
-				if($values['attributes'][$i]['datatype']=='AB')
+				else if($values['attributes'][$i]['datatype']=='AB')
 				{
 					if($values['attributes'][$i]['value'])
 					{
@@ -1118,13 +1151,13 @@
 					}
 
 					$insert_record_values[]	= $values['attributes'][$i]['name'];
-					$lookup_link		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uilookup.addressbook', 'column'=> $values['attributes'][$i]['name']));
+					$lookup_link		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uilookup.addressbook', 'column'=> $values['attributes'][$i]['name']));
 
 					$lookup_functions[$m]['name'] = 'lookup_'. $values['attributes'][$i]['name'] .'()';
 					$lookup_functions[$m]['action'] = 'Window1=window.open('."'" . $lookup_link ."'" .',"Search","width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
 					$m++;
 				}
-/*				if($values['attributes'][$i]['datatype']=='VENDOR')
+				else if($values['attributes'][$i]['datatype']=='VENDOR')
 				{
 					if($values['attributes'][$i]['value'])
 					{
@@ -1141,14 +1174,13 @@
 					}
 
 					$insert_record_values[]	= $values['attributes'][$i]['name'];
-					$lookup_link		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uilookup.vendor', 'column'=> $values['attributes'][$i]['name']));
+					$lookup_link		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uilookup.vendor', 'column'=> $values['attributes'][$i]['name']));
 
 					$lookup_functions[$m]['name'] = 'lookup_'. $values['attributes'][$i]['name'] .'()';
 					$lookup_functions[$m]['action'] = 'Window1=window.open('."'" . $lookup_link ."'" .',"Search","width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
 					$m++;
 				}
-*/
-				if($values['attributes'][$i]['datatype']=='user')
+				else if($values['attributes'][$i]['datatype']=='user')
 				{
 					if($values['attributes'][$i]['value'])
 					{
@@ -1156,14 +1188,13 @@
 					}
 
 					$insert_record_values[]	= $values['attributes'][$i]['name'];
-					$lookup_link		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uilookup.phpgw_user', 'column'=> $values['attributes'][$i]['name']));
+					$lookup_link		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->appname.'.uilookup.phpgw_user', 'column'=> $values['attributes'][$i]['name']));
 
 					$lookup_functions[$m]['name'] = 'lookup_'. $values['attributes'][$i]['name'] .'()';
 					$lookup_functions[$m]['action'] = 'Window1=window.open('."'" . $lookup_link ."'" .',"Search","width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
 					$m++;
 				}
-
-				if($values['attributes'][$i]['datatype']=='R' || $values['attributes'][$i]['datatype']=='CH' || $values['attributes'][$i]['datatype']=='LB')
+				else if($values['attributes'][$i]['datatype']=='R' || $values['attributes'][$i]['datatype']=='CH' || $values['attributes'][$i]['datatype']=='LB')
 				{
 					$values['attributes'][$i]['choice']	= $this->read_attrib_choice($appname, $location,$values['attributes'][$i]['id']);
 					$input_type=$input_type_array[$values['attributes'][$i]['datatype']];
@@ -1171,8 +1202,24 @@
 					if($values['attributes'][$i]['datatype']=='CH')
 					{
 						$values['attributes'][$i]['value']=unserialize($values['attributes'][$i]['value']);
-						$values['attributes'][$i]['choice'] = $this->bocommon->select_multi_list_2($values['attributes'][$i]['value'],$values['attributes'][$i]['choice'],$input_type);
 
+						if (isset($values['attributes'][$i]['choice']) AND is_array($values['attributes'][$i]['choice']))
+						{
+							foreach($values['attributes'][$i]['choice'] as &$choice)
+							{
+								$choice['input_type'] = $input_type;
+								if(isset($values['attributes'][$i]['value']) && is_array($values['attributes'][$i]['value']))
+								{
+									foreach ($values['attributes'][$i]['value'] as &$selected)
+									{
+										if($selected == $choice['id'])
+										{
+											$choice['checked'] = 'checked';
+										}
+									}
+								}
+							}
+						}
 					}
 					else
 					{
@@ -1186,6 +1233,10 @@
 						}
 					}
 				}
+				else if ($entity['attributes'][$i]['datatype']!='I' && $entity['attributes'][$i]['value'])
+				{
+					$entity['attributes'][$i]['value'] = stripslashes($entity['attributes'][$i]['value']);
+				}
 
 				$values['attributes'][$i]['datatype_text'] = $this->translate_datatype($values['attributes'][$i]['datatype']);
 				$values['attributes'][$i]['counter']	= $i;
@@ -1220,29 +1271,78 @@
 		*/
 		function preserve_attribute_values($values,$values_attribute)
 		{
+//_debug_array($values);
+//_debug_array($values_attribute);
 			foreach ( $values_attribute as $key => $attribute )
 			{	
 				for ($i=0;$i<count($values['attributes']);$i++)
 				{
 					if($values['attributes'][$i]['id'] == $attribute['attrib_id'])
 					{
-						$values['attributes'][$i]['value'] = $attribute['value'];
-
-						if(isset($values['attributes'][$i]['choice']) && is_array($values['attributes'][$i]['choice']))
+						if(isset($attribute['value']))
 						{
-							for ($j=0;$j<count($values['attributes'][$i]['choice']);$j++)
+							if(is_array($attribute['value']))
 							{
-								if($values['attributes'][$i]['choice'][$j]['id'] == $attribute['value'])
+								foreach($values['attributes'][$i]['choice'] as &$choice)
 								{
-									$values['attributes'][$i]['choice'][$j]['checked'] = 'checked';	
+									foreach ($attribute['value'] as &$selected)
+									{
+										if($selected == $choice['id'])
+										{
+											$choice['checked'] = 'checked';
+										}
+									}
 								}
 							}
+							else if(isset($values['attributes'][$i]['choice']) && is_array($values['attributes'][$i]['choice']))
+							{
+
+								foreach ($values['attributes'][$i]['choice'] as &$choice)
+								{
+									if($choice['id'] == $attribute['value'])
+									{
+										$choice['checked'] = 'checked';	
+									}
+								}
+							}
+							else
+							{
+								$values['attributes'][$i]['value'] = $attribute['value'];
+							}
 						}
 					}
 				}
 			}
-			
 			return $values;
 		}
+
+		function convert_attribute_save($values_attribute='')
+		{
+			if(is_array($values_attribute))
+			{
+				foreach ( $values_attribute as &$attrib )
+				{
+					if ( $attrib['datatype'] == 'CH' && $attrib['value'] )
+					{
+						$attrib['value'] = serialize($attrib['value'] );
+					}
+					if ( $attrib['datatype'] == 'R' && $attrib['value'] )
+					{
+						$attrib['value'] = $attrib['value'][0];
+					}
+
+					if ( $attrib['datatype'] == 'N' && $attrib['value'] )
+					{
+						$attrib['value'] = str_replace(',', '.', $attrib['value']);
+					}
+	
+					if ( $attrib['datatype'] == 'D' && $attrib['value'] )
+					{
+						$attrib['value'] = date($this->dateformat, phpgwapi_datetime::date_to_timestamp($attrib['value']));
+					}
+				}
+			}
+			return $values_attribute;
+		}
 	}
 ?>
