@@ -8,7 +8,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage utilities
-	* @version $Id: class.datetime.inc.php,v 1.2 2007/11/19 11:29:01 sigurdne Exp $
+	* @version $Id: class.datetime.inc.php 18358 2007-11-27 04:43:37Z skwashd $
 	*/
 
 	/**
@@ -149,7 +149,7 @@
 					? (int) $GLOBALS['phpgw_info']['user']['preferences']['common']['tz_offset'] * self::SECONDS_IN_HOUR : 0;
 		}
 
-		public static function user_locatime()
+		public static function user_localtime()
 		{
 			return time() + self::user_timezone();
 		}
@@ -655,7 +655,7 @@
 
 		public static function gmtdate($localtime)
 		{
-			return self::localdates($localtime - $this->tz_offset);
+			return self::localdates($localtime - self::user_timezone());
 		}
 
 		/**
@@ -708,8 +708,12 @@
 		{
 			$dateformat =& $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
 
-			$fields = preg_split('/[./-]/',$datestr);
-			foreach ( preg_split('/[./-]/', $dateformat) as $n => $field )
+	
+	// 		FIXME : something wrong with the pattern for preg_split
+	//		$fields = preg_split('/[./-]/',$datestr);
+	//		foreach ( preg_split('/[./-]/', $dateformat) as $n => $field )
+			$fields = split('[./-]',$datestr);
+			foreach(split('[./-]',$dateformat) as $n => $field)
 			{
 				$date[$field] = (int) $fields[$n];
 
