@@ -12,7 +12,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage database
-	* @version $Id: class.schema_proc_pgsql.inc.php,v 1.3 2007/02/23 10:46:03 sigurdne Exp $
+	* @version $Id: class.schema_proc_pgsql.inc.php 17987 2007-02-23 10:45:22Z sigurdne $
 	* @link http://www.greatbridge.org/project/phppgadmin
 	* @internal SQL for table properties taken from phpPgAdmin Version 2.2.1
 	*/
@@ -33,7 +33,7 @@
 		var $ix = array();
 		var $uc = array();
 		var $indexes_sql = array();
-		
+
 		function schema_proc_pgsql()
 		{
 			$this->m_sStatementTerminator = ';';
@@ -145,9 +145,12 @@
 					}
 					break;
 				case 'numeric':
-					/* Borrowed from phpPgAdmin */
-					$iPrecision = ($iScale >> 16) & 0xffff;
-					$iScale     = ($iScale - 4) & 0xffff;
+					if($iPrecision == -1)
+					{
+						/* Borrowed from phpPgAdmin */
+						$iPrecision = ($iScale >> 16) & 0xffff;
+						$iScale     = ($iScale - 4) & 0xffff;
+					}
 					$sTranslated = "'type' => 'decimal', 'precision' => $iPrecision, 'scale' => $iScale";
 					break;
 				case 'float':
@@ -194,26 +197,29 @@
 
 		function GetIXSQL($sFields)
 		{
-			$this->indexes_sql[$sFields] = "CREATE INDEX __index_name__ ON __table_name__ USING btree ($sFields)";
+			$this->indexes_sql[str_replace(',','_',$sFields)] = "CREATE INDEX __index_name__ ON __table_name__ USING btree ($sFields)";
 			return '';
 		}
 
 			
-			   function GetFKSQL($sFields)
-			   {
-				 if (ereg("\((.*)\)", $sFields, $regs))
-				 {
-				   $ret = "FOREIGN KEY (".$regs[1].")\n" .
-					 "  REFERENCES ".$sFields;
-				   return $ret;
-				 } else
-				   return ""; // incorrect FK declaration found
-			   }
+		function GetFKSQL($reftable, $sFields)
+		{
+			if(is_array($sFields))
+			{
+				$ret = "FOREIGN KEY (".implode(',',array_keys($sFields)).")\n" .
+					"  REFERENCES $reftable(".implode(',',array_values($sFields)).")";
+				return $ret;
+			}
+			else
+			{
+				return ""; // incorrect FK declaration found
+			}
+		}
 			
 		function _GetColumns($oProc, $sTableName, &$sColumns, $sDropColumn = '', $sAlteredColumn = '', $sAlteredColumnType = '')
 		{
-			$sdb = $oProc->m_odb;
-			$sdc = $oProc->m_odb;
+			$sdb = clone($oProc->m_odb);
+			$sdc = clone($oProc->m_odb);
 
 			$sColumns = '';
 			$this->pk = array();
@@ -229,7 +235,7 @@
 			}
 			$query .= ' ORDER BY a.attnum';
 
-			$oProc->m_odb->query($query);
+			$sdb->query($query, __LINE__, __FILE__);
 			while ($oProc->m_odb->next_record())
 			{
 				if ($sColumns != '')
@@ -265,13 +271,13 @@
 					and a.atttypid = t.oid
 					ORDER BY a.attnum";
 			/* attnum field type length lengthvar notnull(Yes/No) */
-			$sdb->query($sql_get_fields);
+			$sdb->query($sql_get_fields, __LINE__, __FILE__);
 			while ($sdb->next_record())
 			{
 				$colnum  = $sdb->f(0);
 				$colname = $sdb->f(1);
 
-				if ($sdb->f(5) == 'Yes')
+				if ($sdb->f(5) == 'f')
 				{
 					$null = "'nullable' => True";
 				}
@@ -311,7 +317,7 @@
 							c.oid = d.adrelid AND
 							d.adnum = $colnum
 					";
-				$sdc->query($sql_get_default);
+				$sdc->query($sql_get_default, __LINE__, __FILE__);
 				$sdc->next_record();
 				if ($sdc->f(0))
 				{
@@ -319,10 +325,16 @@
 					{
 						$default = '';
 						$nullcomma = '';
+						$type = "'type' => 'auto'";
 					}
 					else
 					{
-						$default = "'default' => '".$sdc->f(0)."'";
+						$default = "'default' => '" . str_replace(array('::bpchar','::character varying','now()'),array('','','current_timestamp'),$sdc->f(0));
+						// For db-functions - add an apos
+						if(substr($default,-1)!= "'")
+						{
+							$default .= "'"; 
+						}
 						$nullcomma = ',';
 					}
 				}
@@ -358,7 +370,7 @@
 					AND ta.attnum = i.indkey[ia.attnum-1]
 				ORDER BY
 					index_name, tab_name, column_name";
-			$sdc->query($sql_pri_keys);
+			$sdc->query($sql_pri_keys, __LINE__, __FILE__);
 			while ($sdc->next_record())
 			{
 				//echo '<br> checking: ' . $sdc->f(4);
@@ -371,13 +383,43 @@
 					$this->uc[] = $sdc->f(2);
 				}
 			}
+
+			$ForeignKeys = $sdc->MetaForeignKeys($sTableName);
+
+			foreach($ForeignKeys as $table => $keys)
+			{
+				$keystr = array();
+				foreach ($keys as $keypair)
+				{
+					$keypair = explode('=',$keypair);
+					$keystr[] = "'" . $keypair[0] . "' => '" . $keypair[1] . "'";
+				}
+				$this->fk[] = $table . "' => array(" . implode(', ',$keystr)  . ')';
+			}
+
+			$MetaIndexes = $sdc->adodb->MetaIndexes($sTableName);
+
+			foreach($MetaIndexes as $key => $index)
+			{
+				if(count($index['columns']) > 1)
+				{
+					$this->ix[] = "array('" . implode("', '",$index['columns']) . "')";
+				}
+				else
+				{
+					$this->ix[] = "'" . $index['columns'][0] . "'";	
+				}
+			}
+
 			/* ugly as heck, but is here to chop the trailing comma on the last element (for php3) */
-			$this->sCol[count($this->sCol) - 1] = substr($this->sCol[count($this->sCol) - 1],0,-2) . "\n";
+			if($this->sCol)
+			{
+				$this->sCol[count($this->sCol) - 1] = substr($this->sCol[count($this->sCol) - 1],0,-2) . "\n";
+			}
 
 			return false;
 		}
 
-
 		function GetSequenceForTable($oProc,$table,&$sSequenceName)
 		{
 			global $DEBUG;
@@ -396,7 +438,7 @@
 		{
 			global $DEBUG;
 			if($DEBUG) { echo '<br>GetSequenceFieldForTable: You rang?'; }
-			$oProc->m_odb->query("SELECT a.attname FROM pg_attribute a, pg_class c, pg_attrdef d WHERE c.relname='$table' AND c.oid=d.adrelid AND d.adsrc LIKE '%seq_$table%' AND a.attrelid=c.oid AND d.adnum=a.attnum");
+			$oProc->m_odb->query("SELECT a.attname FROM pg_attribute a, pg_class c, pg_attrdef d WHERE c.relname='$table' AND c.oid=d.adrelid AND d.adsrc LIKE '%seq_$table%' AND a.attrelid=c.oid AND d.adnum=a.attnum", __LINE__, __FILE__);
 			$oProc->m_odb->next_record();
 			if ($oProc->m_odb->f('attname'))
 			{
@@ -422,14 +464,14 @@
 		{
 			$this->DropSequenceForTable($oProc,$sTableName);
 
-			return $oProc->m_odb->query("DROP TABLE " . $sTableName . " CASCADE") &&
+			return $oProc->m_odb->query("DROP TABLE " . $sTableName . " CASCADE", __LINE__, __FILE__) &&
 				   $this->DropSequenceForTable($oProc, $sTableName);
 		}
 
 		function DropColumn($oProc, &$aTables, $sTableName, $aNewTableDef, $sColumnName, $bCopyData = true)
 		{
 			$query = "ALTER TABLE $sTableName DROP COLUMN $sColumnName CASCADE";
-			$bRet = !!($oProc->m_odb->query($query));
+			$bRet = !!($oProc->m_odb->query($query, __LINE__, __FILE__));
 			return $bRet;
 		}
 
@@ -461,10 +503,10 @@
 				if ($DEBUG) { echo '<br>RenameTable(): Altering column default for: ' . $sField; }
 			}
 
-			$oProc->m_odb->query("ALTER TABLE $sOldTableName RENAME TO $sNewTableName");			
+			$oProc->m_odb->query("ALTER TABLE $sOldTableName RENAME TO $sNewTableName", __LINE__, __FILE__);
 			if ($sSequenceName)
 			{
-				$Ok = !!($oProc->m_odb->query("ALTER TABLE $sNewTableName ALTER $sField SET DEFAULT nextval('seq_" . $sNewTableName . "')"));
+				$Ok = !!$oProc->m_odb->query("ALTER TABLE $sNewTableName ALTER $sField SET DEFAULT nextval('seq_" . $sNewTableName . "')", __LINE__, __FILE__);
 				$this->DropSequenceForTable($oProc,$sOldTableName);
 			}
 			
@@ -493,7 +535,7 @@
 		function RenameColumn($oProc, &$aTables, $sTableName, $sOldColumnName, $sNewColumnName, $bCopyData = true)
 		{
 			$query = "ALTER TABLE $sTableName RENAME COLUMN $sOldColumnName TO $sNewColumnName";
-			return !!($oProc->m_odb->query($query));
+			return !!($oProc->m_odb->query($query, __LINE__, __FILE__));
 		}
 
 		function AlterColumn($oProc, &$aTables, $sTableName, $sColumnName, &$aColumnDef, $bCopyData = true)
@@ -529,14 +571,19 @@
 
 			$sFieldSQL = $this->TranslateType($sType, $iPrecision, $iScale);
 			$query = "ALTER TABLE $sTableName ALTER COLUMN $sColumnName TYPE $sFieldSQL";
-			$Ok = !!($oProc->m_odb->query($query));
+			$Ok = !!($oProc->m_odb->query($query, __LINE__, __FILE__));
 
-			if($bNullable == False || $bNullable == 'False')
+			if($bNullable === False || $bNullable === 'False')
 			{
-				$sFieldSQL = ' NOT NULL';
-				$query = "ALTER TABLE $sTableName ALTER COLUMN $sColumnName SET $sFieldSQL";
-				$Ok = !!($oProc->m_odb->query($query));
+				$sFieldSQL = ' SET NOT NULL';
 			}
+			else
+			{
+				$sFieldSQL = ' DROP NOT NULL';			
+			}
+
+			$query = "ALTER TABLE $sTableName ALTER COLUMN $sColumnName $sFieldSQL";
+			$Ok = !!$oProc->m_odb->query($query, __LINE__, __FILE__);
 
 			if($sDefault == '0')
 			{
@@ -555,7 +602,7 @@
 			if(isset($defaultSQL) && $defaultSQL)
 			{
 				$query = "ALTER TABLE $sTableName ALTER COLUMN $sColumnName SET $defaultSQL";
-				$Ok = !!($oProc->m_odb->query($query));
+				$Ok = !!$oProc->m_odb->query($query, __LINE__, __FILE__);
 			}
 
 			return $Ok;
@@ -563,7 +610,8 @@
 
 		function AddColumn($oProc, &$aTables, $sTableName, $sColumnName, &$aColumnDef)
 		{
-			if (isset($aColumnDef['default']))	// pgsql cant add a colum with a default
+			$default = '';
+			if (isset($aColumnDef['default']) && $aColumnDef['default'])	// pgsql cant add a colum with a default
 			{
 				$default = $aColumnDef['default'];
 				unset($aColumnDef['default']);
@@ -576,7 +624,7 @@
 			$oProc->_GetFieldSQL($aColumnDef, $sFieldSQL);
 			$query = "ALTER TABLE $sTableName ADD COLUMN $sColumnName $sFieldSQL";
 
-			if (($Ok = !!($oProc->m_odb->query($query))) && isset($default))
+			if (($Ok = !!$oProc->m_odb->query($query, __LINE__, __FILE__)) && isset($default) && $default)
 			{
 				if($default == '0')
 				{
@@ -596,7 +644,7 @@
 
 				$query .= "UPDATE $sTableName SET $sColumnName='$default';\n";
 
-				$Ok = !!($oProc->m_odb->query($query));
+				$Ok = !!$oProc->m_odb->query($query, __LINE__, __FILE__);
 
 				if ($OK && $notnull)
 				{
@@ -632,13 +680,13 @@
 				if ($bCreateSequence && $sSequenceSQL != '')
 				{
 					if ($DEBUG) { echo '<br>Making sequence using: ' . $sSequenceSQL; }
-					$oProc->m_odb->query($sSequenceSQL);
+					$oProc->m_odb->query($sSequenceSQL, __LINE__, __FILE__);
 				}
 
-				$query = "CREATE TABLE $sTableName ($sTableSQL) WITH OIDS";
+				$query = "CREATE TABLE $sTableName ($sTableSQL)";
 				//echo 'sql' .$query . "\n";
 
-				$result = !!($oProc->m_odb->query($query));
+				$result = !!$oProc->m_odb->query($query, __LINE__, __FILE__);
 				if($result==True)
 				{
 					if (isset($this->indexes_sql) && $DEBUG)
@@ -654,7 +702,7 @@
 						{
 							$ix_name = str_replace(',','_',$key).'_'.$sTableName.'_idx';
 							$IndexSQL = str_replace(array('__index_name__','__table_name__'), array($ix_name,$sTableName), $sIndexSQL);
-							$oProc->m_odb->query($IndexSQL);
+							$oProc->m_odb->query($IndexSQL, __LINE__, __FILE__);
 						}
 					}			
 				}
