@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage communication
-	* @version $Id: class.send.inc.php,v 1.4 2007/03/21 08:20:46 sigurdne Exp $
+	* @version $Id: class.send.inc.php 18042 2007-03-16 09:15:55Z sigurdne $
 	*/
 
 	/**
@@ -148,7 +148,7 @@
 			$smtp->Port = $GLOBALS['phpgw_info']['server']['smtp_port'] ? $GLOBALS['phpgw_info']['server']['smtp_port'] : 25;
 			$smtp->Host 	= $GLOBALS['phpgw_info']['server']['smtp_server'];
 			$smtp->Encoding = '8bit';
-			$smtp->CharSet = $GLOBALS['phpgw_info']['server']['charset'];
+			$smtp->CharSet = 'utf-8';
 			$smtp->PluginDir = PHPGW_SERVER_ROOT."/phpgwapi/inc/phpmailer/";
 
 			if($content_type =='html')
