@@ -9,7 +9,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.setup.inc.php,v 1.3 2007/02/11 17:43:46 sigurdne Exp $
+	* @version $Id: class.setup.inc.php 18358 2007-11-27 04:43:37Z skwashd $
 	*/
 
 	/**
@@ -55,17 +55,15 @@
 		 */
 		function loaddb()
 		{
-			$form_domain = get_var('FormDomain', array('POST'), '');
-			$ConfigDomain = get_var('ConfigDomain', array('COOKIE','POST'), $form_domain);
+			$form_domain = phpgw::get_var('FormDomain', 'string', 'POST', '');
+			$ConfigDomain = phpgw::get_var('ConfigDomain', 'string', 'REQUEST', $form_domain);
 
 			$GLOBALS['phpgw_info']['server']['db_type'] = $GLOBALS['phpgw_domain'][$ConfigDomain]['db_type'];
-
+			$GLOBALS['phpgw_info']['server']['db_host']	= $GLOBALS['phpgw_domain'][$ConfigDomain]['db_host'];
+			$GLOBALS['phpgw_info']['server']['db_name'] = $GLOBALS['phpgw_domain'][$ConfigDomain]['db_name'];
+			$GLOBALS['phpgw_info']['server']['db_user'] = $GLOBALS['phpgw_domain'][$ConfigDomain]['db_user'];
+			$GLOBALS['phpgw_info']['server']['db_pass'] = $GLOBALS['phpgw_domain'][$ConfigDomain]['db_pass'];
 			$this->db	  = createObject('phpgwapi.db');
-			$this->db->Host     = $GLOBALS['phpgw_domain'][$ConfigDomain]['db_host'];
-			$this->db->Type     = $GLOBALS['phpgw_domain'][$ConfigDomain]['db_type'];
-			$this->db->Database = $GLOBALS['phpgw_domain'][$ConfigDomain]['db_name'];
-			$this->db->User     = $GLOBALS['phpgw_domain'][$ConfigDomain]['db_user'];
-			$this->db->Password = $GLOBALS['phpgw_domain'][$ConfigDomain]['db_pass'];
 
 			$GLOBALS['ConfigDomain'] = $ConfigDomain;
 		}
@@ -79,16 +77,16 @@
 		{
 			$remoteip     = $_SERVER['REMOTE_ADDR'];
 
-			$FormLogout   = get_var('FormLogout',  array('GET','POST'));
-			$ConfigLogin  = get_var('ConfigLogin', array('POST'));
-			$HeaderLogin  = get_var('HeaderLogin', array('POST'));
-			$FormDomain   = get_var('FormDomain',  array('POST'));
-			$FormPW       = get_var('FormPW',      array('POST'));
+			$FormLogout   = phpgw::get_var('FormLogout');
+			$ConfigLogin  = phpgw::get_var('ConfigLogin',	'string', 'POST');
+			$HeaderLogin  = phpgw::get_var('HeaderLogin',	'string', 'POST');
+			$FormDomain   = phpgw::get_var('FormDomain',	'string', 'POST');
+			$FormPW       = phpgw::get_var('FormPW',		'string', 'POST');
 
-			$ConfigDomain = get_var('ConfigDomain',array('POST','COOKIE'));
-			$ConfigPW     = get_var('ConfigPW',    array('POST','COOKIE'));
-			$HeaderPW     = get_var('HeaderPW',    array('POST','COOKIE'));
-			$ConfigLang   = get_var('ConfigLang',  array('POST','COOKIE'));
+			$ConfigDomain = phpgw::get_var('ConfigDomain');
+			$ConfigPW     = phpgw::get_var('ConfigPW');
+			$HeaderPW     = phpgw::get_var('HeaderPW');
+			$ConfigLang   = phpgw::get_var('ConfigLang');
 
 			/*
 			if(!empty($remoteip) && !$this->checkip($remoteip))
@@ -557,7 +555,7 @@
 		 */
 		function deregister_hooks($appname)
 		{
-			if($this->alessthanb($setup_info['phpgwapi']['currentver'],'0.9.8pre5'))
+			if(isset($setup_info['phpgwapi']['currentver']) && $this->alessthanb($setup_info['phpgwapi']['currentver'],'0.9.8pre5'))
 			{
 				/* No phpgw_hooks table yet. */
 				return False;
