@@ -6,7 +6,7 @@
 	* @license http://www.fsf.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.setup_process.inc.php,v 1.2 2007/02/06 12:42:17 sigurdne Exp $
+	* @version $Id: class.setup_process.inc.php 18358 2007-11-27 04:43:37Z skwashd $
 	*/
 
 	/**
@@ -42,7 +42,7 @@
 		 */
 		function init_process()
 		{
-			$ConfigDomain = get_var('ConfigDomain',array('COOKIE','POST'));
+			$ConfigDomain = phpgw::get_var('ConfigDomain');
 			$phpgw_domain = $GLOBALS['phpgw_domain'];
 
 			$GLOBALS['phpgw_setup']->oProc = createObject('phpgwapi.schema_proc',$phpgw_domain[$ConfigDomain]['db_type']);
@@ -51,7 +51,7 @@
 			$GLOBALS['phpgw_setup']->oProc->m_odb->Database = $phpgw_domain[$ConfigDomain]['db_name'];
 			$GLOBALS['phpgw_setup']->oProc->m_odb->User     = $phpgw_domain[$ConfigDomain]['db_user'];
 			$GLOBALS['phpgw_setup']->oProc->m_odb->Password = $phpgw_domain[$ConfigDomain]['db_pass'];
-			$GLOBALS['phpgw_setup']->oProc->m_odb->Halt_On_Error = 'report';
+			$GLOBALS['phpgw_setup']->oProc->m_odb->Halt_On_Error = 'yes';
 			$GLOBALS['phpgw_setup']->oProc->m_odb->connect();
 		}
 
@@ -820,17 +820,23 @@
 				$this->init_process();
 			}
 
-			$GLOBALS['phpgw_setup']->oProc->m_oTranslator->_GetColumns($GLOBALS['phpgw_setup']->oProc, $tablename, $sColumns, $sColumnName);
+			$GLOBALS['phpgw_setup']->oProc->m_oTranslator->sCol = array();
+			$GLOBALS['phpgw_setup']->oProc->m_oTranslator->_GetColumns($GLOBALS['phpgw_setup']->oProc, $tablename, $sColumns);
 
-			while(list($key,$tbldata) = each($GLOBALS['phpgw_setup']->oProc->m_oTranslator->sCol))
+			$arr = '';
+			if(is_array($GLOBALS['phpgw_setup']->oProc->m_oTranslator->sCol))
 			{
-				$arr .= $tbldata;
+				reset($GLOBALS['phpgw_setup']->oProc->m_oTranslator->sCol);
+				foreach($GLOBALS['phpgw_setup']->oProc->m_oTranslator->sCol as $tbldata)
+				{
+					$arr .= $tbldata;
+				}
 			}
+			
 			$pk = $GLOBALS['phpgw_setup']->oProc->m_oTranslator->pk;
 			$fk = $GLOBALS['phpgw_setup']->oProc->m_oTranslator->fk;
 			$ix = $GLOBALS['phpgw_setup']->oProc->m_oTranslator->ix;
 			$uc = $GLOBALS['phpgw_setup']->oProc->m_oTranslator->uc;
-
 			return array($arr,$pk,$fk,$ix,$uc);
 		}
 	}
