@@ -7,7 +7,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.setup_translation.inc.php,v 1.3 2007/11/19 22:10:11 sigurdne Exp $
+	* @version $Id: class.setup_translation.inc.php 18358 2007-11-27 04:43:37Z skwashd $
 	*/
 
 	if (!defined('MAX_MESSAGE_ID_LENGTH'))
@@ -36,7 +36,7 @@
 		 */
 		function setup_translation()
 		{
-			$ConfigLang = get_var('ConfigLang',Array('POST','COOKIE'));
+			$ConfigLang = phpgw::get_var('ConfigLang');
 
 			if(!$ConfigLang)
 			{
