@@ -8,7 +8,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage vfs
-	* @version $Id: class.vfs_sql.inc.php,v 1.4 2007/10/07 09:48:55 sigurdne Exp $
+	* @version $Id: class.vfs_sql.inc.php 18302 2007-10-07 09:47:59Z sigurdne $
 	*/
 
 	/**
@@ -1992,7 +1992,7 @@
 			reset ($this->attributes);
 			while (list ($num, $attribute) = each ($this->attributes))
 			{
-				if (isset ($data['attributes'][$attribute]) && $data['attributes'][$attribute])
+				if (isset ($data['attributes'][$attribute]))
 				{
 					$$attribute = $data['attributes'][$attribute];
 
