@@ -8,11 +8,10 @@
 	* @license http://www.gnu.org/licenses/lpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage gui
-	* @version $Id: class.xslttemplates.inc.php,v 1.6 2007/11/05 22:13:01 sigurdne Exp $
+	* @version $Id: class.xslttemplates.inc.php 18358 2007-11-27 04:43:37Z skwashd $
 	*/
 
-	if( (floor(phpversion()) == 4 && !extension_loaded('xslt') )
-		|| (floor(phpversion()) >= 5 && !extension_loaded('xsl') ) )
+	if( !extension_loaded('xsl') )
 	{
 		die('PHP CONFIGURATION. xslt-extension is not loaded. Please contact the system administrator.');
 	}
@@ -32,7 +31,11 @@
 	{
 		var $rootdir = '';
 		var $prev_rootdir = '';
-		var $wml_out = '';
+
+		/**
+		* @var string $output the format of the output
+		*/ 
+		private $output = 'html';
 
 		/**
 		* The xslfiles will be loaded up and merged into $xsldata
@@ -47,18 +50,22 @@
 		* need for a more robust schema.
 		* @var array Variables to convert into xml-data
 		*/
-		var $vars = Array();
-		var $xmlvars = Array();
+		var $vars = array();
+		var $xmlvars = array();
 		var $xmldata = '';
 
 		function xslttemplates($root = '.')
 		{
 			//FIXME Print view/mode should be handled by CSS not different markup
-			if(@isset($GLOBALS['phpgw_info']['flags']['printview']) && $GLOBALS['phpgw_info']['flags']['printview'] == True)
+			if ( isset($GLOBALS['phpgw_info']['flags']['printview']) && $GLOBALS['phpgw_info']['flags']['printview'] )
 			{
-				$this->print = True;
+				$this->print = true;
 			}
 			$this->set_root($root);
+			if ( execMethod('phpgwapi.browser.is_mobile') )
+			{
+				$this->set_output('wml');
+			}
 		}
 
 		function halt($msg)
@@ -66,16 +73,36 @@
 			die($msg);
 		}
 
+		 /**
+		 * Set the output format
+		 *
+		 * @internal currently supports html and wml
+		 * @param string $output the desired output format
+		 */
+		 public function set_output($output)
+		{
+			$output = strtolower($output);
+			switch ( $output )
+			{
+				case 'wml':
+				case 'html':
+					$this->output = $output;
+					break;
+				default:
+					$this->output = 'html';
+			}
+		}
+
 		function set_root($rootdir)
 		{
 			if (!is_dir($rootdir))
 			{
 				$this->halt('set_root: '.$rootdir.' is not a directory.');
-				return False;
+				return false;
 			}
 			$this->prev_rootdir = $this->rootdir;
 			$this->rootdir = $rootdir;
-			return True;
+			return true;
 		}
 
 		function reset_root()
@@ -101,45 +128,27 @@
 					$new_filename = $filename;
 				}
 
-		//		echo 'Rootdir: '.$rootdir.'<br>'."\n".'Filename: '.$filename.'<br>'."\n".'New Filename: '.$new_filename.'<br>'."\n".'New time: '.$time.'<br>'."\n" ;
+//				echo 'Rootdir: '.$rootdir.'<br>'."\n".'Filename: '.$filename.'<br>'."\n".'New Filename: '.$new_filename.'<br>'."\n";
 				if (!file_exists($new_filename.'.xsl'))
 				{
 					switch($time)
 					{
 						case 2:
 							$new_root = str_replace($GLOBALS['phpgw_info']['server']['template_set'],'base',$rootdir);
-							$filename = basename($new_filename);
 							$this->add_file($filename,$new_root,3);
 							return true;
 						case 3:
-							$new_root = str_replace('base','default',$rootdir);
-							$filename = basename($new_filename);
+							$new_root = PHPGW_SERVER_ROOT . '/phpgwapi/templates/' . $GLOBALS['phpgw_info']['server']['template_set'];
 							$this->add_file($filename,$new_root,4);
 							return true;
 						case 4:
-							$new_root = PHPGW_SERVER_ROOT . '/phpgwapi/templates/' . $GLOBALS['phpgw_info']['server']['template_set'];
-							$filename = basename($new_filename);
+							$new_root = PHPGW_SERVER_ROOT . '/phpgwapi/templates/base';
 							$this->add_file($filename,$new_root,5);
 							return true;
 						case 5:
-							$new_root = PHPGW_SERVER_ROOT . '/phpgwapi/templates/base';
-							$filename = basename($new_filename);
-							$this->add_file($filename,$new_root,6);
+							$this->add_file($filename,$rootdir,6);
 							return true;
 						case 6:
-							$new_root = PHPGW_SERVER_ROOT . '/phpgwapi/templates/default';
-							$filename = basename($new_filename);
-							$this->add_file($filename,$new_root,7);
-							return true;
-						case 7:
-							$new_root = PHPGW_SERVER_ROOT . SEP . $GLOBALS['phpgw_info']['flags']['currentapp'] . '/templates/base';
-							$filename = basename($new_filename);
-							$this->add_file($filename,$new_root,8);
-							return true;
-						case 8:
-							$this->add_file($filename,$rootdir,9);
-							return true;
-						case 9:
 							$this->halt("filename: file $new_filename.xsl does not exist.");
 							break true;
 						default:
@@ -161,7 +170,7 @@
 			}
 		}
 
-		function set_var($name, $value, $append = False)
+		function set_var($name, $value, $append = false)
 		{
 			if($append)
 			{
@@ -187,7 +196,7 @@
 			}
 		}
 
-		function set_xml($xml, $append = False)
+		function set_xml($xml, $append = false)
 		{
 			if(!$append)
 			{
@@ -217,42 +226,47 @@
 		/**
 		* Parse the xsl-stylesheets
 		*
-		* @param boolean $wml_out set to true for wml-enabled browsers
+		* @param string $ignored this value is now ignored and is only kept as a transitional hack
 		*/
-
-		function xsl_parse($wml_out = false)
+		function xsl_parse()
 		{
 			if( is_array($this->xslfiles) && count($this->xslfiles) > 0)
 			{
-				$this->xsldata = '<?xml version="1.0" encoding="' . $GLOBALS['phpgw_info']['server']['charset'] . '"?>'."\n";
-				$this->xsldata .= '<!DOCTYPE xsl:stylesheet ['."\n";
-				$this->xsldata .= '<!ENTITY nl "&#10;">'."\n";
-				$this->xsldata .= '<!ENTITY nbsp "&#160;">'."\n";
-				$this->xsldata .= ']>'."\n";
-				$this->xsldata .= '<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" 				
-				xmlns:phpgw="http://phpgroupware.org/functions"
-				xmlns:func="http://exslt.org/functions"
-				extension-element-prefixes="func" 
-				exclude-result-prefixes="phpgw"
-				>'."\n";
+				$this->xsldata = <<<XSLT
+<?xml version="1.0" encoding="UTF-8"?>
+	<!DOCTYPE xsl:stylesheet [
+		<!ENTITY nl "&#10;">
+		<!ENTITY nbsp "&#160;">
+		]>
+	<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
+		xmlns:phpgw="http://phpgroupware.org/functions"
+		xmlns:func="http://exslt.org/functions"
+		extension-element-prefixes="func" 
+		exclude-result-prefixes="phpgw"
+		>
 
-				if(!$wml_out)
+XSLT;
+				switch ( $this->output )
 				{
- 					$this->xsldata .= '<xsl:output method="html" version="1.0" encoding="' . $GLOBALS['phpgw_info']['server']['charset'] . '" indent="yes" omit-xml-declaration="yes" standalone="yes" media-type="text/html"/>'."\n";
-	 				//FIXME Remove the line above and uncomment the one below once the main templates are converted or else it fscks validation
- 					//$this->xsldata .= '<xsl:output method="html" version="1.0" encoding="' . $GLOBALS['phpgw_info']['server']['charset'] . '" indent="yes" omit-xml-declaration="yes" doctype-public="-//W3C/DTD XHTML 1.0 Transitional//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd" standalone="yes" media-type="application/xml+xhtml"/>'."\n";
-				}
-				else
-				{
-					$this->xsldata .= '<xsl:output method = "xml" encoding="' . $GLOBALS['phpgw_info']['server']['charset'] . '"  doctype-public="-//WAPFORUM//DTD WML 1.3//EN" doctype-system="http://www.wapforum.org/DTD/wml13.dtd" />'."\n";				
+					case 'wml':
+						$this->xsldata .= '<xsl:output method = "xml" encoding="utf-8"  doctype-public="-//WAPFORUM//DTD WML 1.3//EN" doctype-system="http://www.wapforum.org/DTD/wml13.dtd" />'."\n";				
+						break;
 
+					case 'html':
+					default:
+ 						$this->xsldata .= '<xsl:output method="html" version="1.0" encoding="utf-8" indent="yes" omit-xml-declaration="yes" standalone="yes" doctype-system="http://www.w3.org/TR/html4/strict.dtd" doctype-public="-//W3C//DTD HTML 4.01//EN" media-type="text/html"/>' . "\n";
 				}
-				$this->xsldata .= '<xsl:template match="/">'."\n";
-				$this->xsldata .= "\t".'<xsl:apply-templates select="PHPGW"/>'."\n";
-				$this->xsldata .= '</xsl:template>'."\n";
-				foreach ( $this->xslfiles as $xslfile)
+				
+				$this->xsldata .= <<<XSLT
+		<xsl:template match="/">
+			<xsl:apply-templates select="PHPGW" />
+		</xsl:template>
+
+XSLT;
+
+				foreach ( $this->xslfiles as $xslfile )
 				{
-					$this->xsldata .= "\n\n<!-- XSL File: {$xslfile} -->\n";
+					$this->xsldata .= "\n<!-- XSL File: {$xslfile} -->\n";
 					$this->xsldata .= file_get_contents($xslfile);
 				}
 				$this->xsldata .= '</xsl:stylesheet>'."\n";
@@ -272,12 +286,18 @@
 			$xmldata = $this->vars;
 
 			/* auto generate xml based on vars */
-
-			while(list($key,$value) = each($xmlvars))
+			foreach ( $this->xmlvars as $key => $value )
 			{
 				$xmldata[$key] = $value;
 			}
-			$this->xmldata = var2xml('PHPGW',$xmldata);
+			$this->xmldata = var2xml('PHPGW', $xmldata);
+
+			/*
+				echo "<textarea cols='200' rows='20'>";
+				echo $this->xmldata;
+				echo "</textarea><br>";
+			*/
+			
 			return $this->xmldata;
 		}
 
@@ -297,77 +317,53 @@
 			echo "</ol>\n";
 		}
 
-		function parse($parsexsl = True, $parsexml = True)
+		function parse($parsexsl = true, $parsexml = true)
 		{
 			$output_header = !(isset($GLOBALS['phpgw_info']['flags']['noframework']) && $GLOBALS['phpgw_info']['flags']['noframework']);
 			
-			
-			if($this->wml_out)
-			{
-				// Force the output to wml
-				$wml_out = $this->wml_out;
-			}
-			else
-			{
-				// Determine whether the browser is wml-capable or not
-				$wml_out = execMethod('phpgwapi.browser.is_mobile');
-			}
-			
-			if ( !$wml_out )
+			if ( $this->output != 'wml' )
 			{
 				$GLOBALS['phpgw']->common->phpgw_header($output_header);
 			}
 
 			if($parsexsl)
 			{
-				$this->xsl_parse($wml_out);
+				$this->xsl_parse();
 			}
+
 			if($parsexml)
 			{
 				$this->xml_parse();
 			}
 
-			$minor = explode(".",phpversion());
+			$xml = new DOMDocument;
+			$xml->loadXML($this->xmldata);
 
-			if ($minor[0] == 4)
+			$xsl = new DOMDocument;
+			$xsl->loadXML($this->xsldata);
+
+			// Configure the transformer
+			$proc = new XSLTProcessor;
+			$proc->importStyleSheet($xsl); // attach the xsl rules
+
+			$html =  trim($proc->transformToXML($xml));
+
+			if (!$html || $html == '<?xml version="1.0"?>')
 			{
-				$xsltproc = xslt_create();
-				$arguments = array('/_xml' => $this->xmldata, '/_xsl' => $this->xsldata);
-				$html = xslt_process($xsltproc,'arg:/_xml','arg:/_xsl',NULL,$arguments);
-				xslt_free($xsltproc);
+				echo "<h2>xml-data</h2>";
+				$this->list_lineno($this->xmldata);
+
+				echo "<h2>xsl-data</h2>";
+				$this->list_lineno($this->xsldata);
+				return '';
 			}
-			else
-			{
-				$xml = new DOMDocument;
-				$xml->loadXML($this->xmldata);
-
-				$xsl = new DOMDocument;
-				$xsl->loadXML($this->xsldata);
-
-				// Configure the transformer
-				$proc = new XSLTProcessor;
-				$proc->importStyleSheet($xsl); // attach the xsl rules
-
-				$html =  $proc->transformToXML($xml);
-			}
-
-			if (!$html)
-			{
-				echo "<h2>xml-data</h2>";  $this->list_lineno($this->xmldata);
-				echo "<h2>xsl-data</h2>"; $this->list_lineno($this->xsldata);
-				if ($minor[0] == 4)
-				{
-					die(/*$this->xsldata.*/"\n\n XSLT processing error: ".xslt_error($xsltproc));
-				}
-			}
-
 			return preg_replace('/<!DOCTYPE([^>])+>/', '', $html);
 		}
 
 		function pparse()
 		{
 			print $this->parse();
-			return False;
+			return false;
 		}
 		function pp()
 		{
