@@ -8,76 +8,15 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage utilities
-	* @version $Id: functions.inc.php,v 1.10 2007/10/29 10:13:46 sigurdne Exp $
+	* @version $Id: functions.inc.php 18358 2007-11-27 04:43:37Z skwashd $
 	*/
 	
 	
-	// PHP5 compat fix
-	if (version_compare(phpversion(), '5.0') < 0)
+	if (!function_exists('filter_var')) // ext/filter was added in 5.2.0
 	{
-		eval('
-			function clone($obj)
-			{
-				if ( method_exists($obj, "__clone") )
-				{
-					$new_obj = $obj;
-					$new_obj->__clone();
-					return $new_obj;
-				}
-				return $obj;
-			}
-		');
-	}
-
-	/*
-	* This makes our life a lot easier
-	*/
-	if (!function_exists('http_build_query'))
-	{
-		/**
-		* PHP4 implementation of PHP5's http_build_query
-		*
-		* @author Nikulin Alexander  http://the-notebook.org
-		* @author Dave Hall skwashd at phpgroupware.org
-		* @link taken from http://the-notebook.org/wp-content/uploads/2006/04/openid-comments-0.9.1.zip
-		* @see http://php.net/http-build-query
-		*
-		* @param array $formdata elements of the query string
-		* @param string $numeric_prefix the prefix to apply to all numbers
-		* @param string $separator the string used between variable, the default (&amp;) is W3C compliant
-		* @param string $key the parent element used for recursive arrays
-		* @return string the formatted query string
-		*/
-		function http_build_query( $formdata, $numeric_prefix = null, $separator = '&amp;', $key = null )
-		{
-			$res = array();
-			foreach( (array)$formdata as $k => $v )
-			{
-				$tmp_key = urlencode( is_int($k) ? $numeric_prefix.$k : $k );
-				if( $key ) 
-				{
-					$tmp_key = $key.'['.$tmp_key.']';
-				}
-
-				if ( is_array( $v ) || is_object( $v ) )
-				{
-					$res[] = http_build_query( $v, null, $separator, $tmp_key );
-				}
-				else
-				{
-					$res[] = $tmp_key."=".urlencode( $v );
-				}
-			}
-
-			return implode( $separator, $res );
-		}
-	}
-
-	
-	if (!function_exists('html_entity_decode'))//html_entity_decode() is only available in PHP4.3+
-	{
-		die('<h1>You appear to be using PHP ' . PHP_VERSION . " phpGroupWare requires 4.3.0 or later <br>\n"
-			. 'Please contact your System Administrator</h1>');
+		die('<p class="msg">'
+			. lang('You appear to be using PHP %1, phpGroupWare requires 5.2.0 or later', PHP_VERSION). "\n"
+			. '</p></body></html>');
 	}
 
 	include_once(PHPGW_API_INC.'/common_functions.inc.php');
@@ -111,7 +50,13 @@
 		}
 		if ( !isset($GLOBALS['phpgw']->translation) || !is_object($GLOBALS['phpgw']->translation) )
 		{
-			return sprintf( preg_replace('/(%\d)+/', '%s', $key),  $m1, $m2, $m3, $m4, $m5, $m6, $m7, $m8, $m9, $m10) . ' *#*';
+			$str = $key;
+			for ( $i = 10; $i > 0; --$i )
+			{	
+				$var = "m{$i}";
+				$str = preg_replace("/(%$i)+/", $$var, $str);
+			}
+			return "$str*#*";
 		}
 		return $GLOBALS['phpgw']->translation->translate("$key", $vars);
 	}
@@ -194,7 +139,7 @@
 					// Drop passwords from backtrace
 					if ( !is_object($arg) 
 						&& ($arg == $GLOBALS['phpgw_info']['server']['header_admin_password']
-						|| $arg == $GLOBALS['phpgw_info']['server']['db_pass']
+						|| (isset($GLOBALS['phpgw_info']['server']['db_pass']) && $arg == $GLOBALS['phpgw_info']['server']['db_pass'])
 						|| (isset($GLOBALS['phpgw_info']['user']['passwd']) && $arg == $GLOBALS['phpgw_info']['user']['passwd'] ) )
 					)
 					{
@@ -288,15 +233,7 @@
 			//No default, we just ignore it, for now
 		}
 	}
-
-	if(isset($GLOBALS['phpgw_info']['server']['phpgw_handle_error']) && $GLOBALS['phpgw_info']['server']['phpgw_handle_error'])
-	{
-		set_error_handler('phpgw_handle_error');
-	}
-	else
-	{
-		error_reporting(E_USER_ERROR | E_ERROR | E_WARNING | E_PARSE);
-	}
+	set_error_handler('phpgw_handle_error');
 
 	function clean_vars($vars, $safe_redirect = True)
 	{
@@ -352,16 +289,16 @@
 		$GLOBALS['login'] = $_POST['login'];
 		if (strstr($GLOBALS['login'],'@') === False)
 		{
-			$GLOBALS['login'] .= '@' . get_var('logindomain',array('POST'),$GLOBALS['phpgw_info']['server']['default_domain']);
+			$GLOBALS['login'] .= '@' . phpgw::get_var('logindomain', 'string', 'POST', $GLOBALS['phpgw_info']['server']['default_domain']);
 		}
 		list(,$GLOBALS['phpgw_info']['user']['domain']) = explode('@',$GLOBALS['login']);
 	}
 	else	// on "normal" pageview
 	{
-		$GLOBALS['phpgw_info']['user']['domain'] = get_var('domain', array('GET', 'COOKIE'), FALSE);
+		$GLOBALS['phpgw_info']['user']['domain'] = phpgw::get_var('domain', 'string', 'REQUEST', false);
 	}
 
-	if (@isset($GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['user']['domain']]))
+	if (isset($GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['user']['domain']]))
 	{
 		$GLOBALS['phpgw_info']['server']['db_host'] = $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['user']['domain']]['db_host'];
 		$GLOBALS['phpgw_info']['server']['db_name'] = $GLOBALS['phpgw_domain'][$GLOBALS['phpgw_info']['user']['domain']]['db_name'];
@@ -394,21 +331,20 @@
 	 /************************************************************************\
 	 * Load up the main instance of the db class.                             *
 	 \************************************************************************/
-
-	if($GLOBALS['phpgw_info']['server']['db_abstraction'] == 'phplib')
+	$GLOBALS['phpgw']->db                = createObject('phpgwapi.db');
+	$GLOBALS['phpgw']->db->Debug         = $GLOBALS['phpgw']->debug ? 1 : 0;
+	$GLOBALS['phpgw']->db->Halt_On_Error = 'no';
+	$GLOBALS['phpgw']->adodb             =& $GLOBALS['phpgw']->db->adodb; //Reference
+	
+	@$GLOBALS['phpgw']->adodb->connect($GLOBALS['phpgw_info']['server']['db_host'],
+									   $GLOBALS['phpgw_info']['server']['db_user'],
+									   $GLOBALS['phpgw_info']['server']['db_pass'],
+									   $GLOBALS['phpgw_info']['server']['db_name']
+									  );
+	if(!$GLOBALS['phpgw']->adodb->ErrorNo())
 	{
-//---------test phplib
-		$GLOBALS['phpgw']->db           = createObject('phpgwapi.db');
-		$GLOBALS['phpgw']->db->Debug    = $GLOBALS['phpgw']->debug ? 1 : 0;
-		$GLOBALS['phpgw']->db->Host     = $GLOBALS['phpgw_info']['server']['db_host'];
-		$GLOBALS['phpgw']->db->Type     = $GLOBALS['phpgw_info']['server']['db_type'];
-		$GLOBALS['phpgw']->db->Database = $GLOBALS['phpgw_info']['server']['db_name'];
-		$GLOBALS['phpgw']->db->User     = $GLOBALS['phpgw_info']['server']['db_user'];
-		$GLOBALS['phpgw']->db->Password = $GLOBALS['phpgw_info']['server']['db_pass'];
-
-		$GLOBALS['phpgw']->db->Halt_On_Error = 'no';
-		@$GLOBALS['phpgw']->db->query("select count(config_name) from phpgw_config");
-		if (! @$GLOBALS['phpgw']->db->next_record())
+		$GLOBALS['phpgw']->adodb->query('select count(config_name) from phpgw_config');
+		if($GLOBALS['phpgw']->adodb->ErrorNo())
 		{
 			$setup_dir = ereg_replace($_SERVER['PHP_SELF'],'index.php','setup/');
 			echo '<center><b>Fatal Error:</b> It appears that you have not created the database tables for '
@@ -418,35 +354,10 @@
 	}
 	else
 	{
-		$GLOBALS['phpgw']->db                = createObject('phpgwapi.db');
-		$GLOBALS['phpgw']->db->Debug         = $GLOBALS['phpgw']->debug ? 1 : 0;
-		$GLOBALS['phpgw']->db->Halt_On_Error = 'no';
-
-		$GLOBALS['phpgw']->db->Host     	= $GLOBALS['phpgw_info']['server']['db_host'];
-		$GLOBALS['phpgw']->db->Type     	= $GLOBALS['phpgw_info']['server']['db_type'];
-		$GLOBALS['phpgw']->db->Database 	= $GLOBALS['phpgw_info']['server']['db_name'];
-		$GLOBALS['phpgw']->db->User     	= $GLOBALS['phpgw_info']['server']['db_user'];
-		$GLOBALS['phpgw']->db->Password 	= $GLOBALS['phpgw_info']['server']['db_pass'];
-		$GLOBALS['phpgw']->db->connect();
-
-		if(!$GLOBALS['phpgw']->db->adodb->ErrorNo())
-		{
-			$GLOBALS['phpgw']->db->query('select count(config_name) from phpgw_config');
-			if($GLOBALS['phpgw']->db->adodb->ErrorNo())
-			{
-				$setup_dir = ereg_replace($_SERVER['PHP_SELF'],'index.php','setup/');
-				echo '<center><b>Fatal Error:</b> It appears that you have not created the database tables for '
-				.'phpGroupWare.  Click <a href="' . $setup_dir . '">here</a> to run setup.</center>';
-				exit;
-			}
-		}
-		else
-		{
-			$setup_dir = ereg_replace($_SERVER['PHP_SELF'],'index.php','setup/');
-			echo '<center><b>Fatal Error:</b> Unable to connect to database server '
-			.'Click <a href="' . $setup_dir . '">here</a> to run setup.</center>';
-			exit;
-		}
+		$setup_dir = ereg_replace($_SERVER['PHP_SELF'],'index.php','setup/');
+		echo '<center><b>Fatal Error:</b> Unable to connect to database server '
+		.'Click <a href="' . $setup_dir . '">here</a> to run setup.</center>';
+		exit;
 	}
 	$GLOBALS['phpgw']->db->Halt_On_Error = 'yes';
 
@@ -567,15 +478,14 @@
 	{
 		if ($GLOBALS['phpgw_info']['flags']['currentapp'] == 'login')
 		{
-			if (@$_POST['login'] != '')
+			if ( isset($_POST['login']) && $_POST['login'] != '')
 			{
 				list($login) = explode("@",$_POST['login']);
 				print_debug('LID',$login,'app');
 				$login_id = $GLOBALS['phpgw']->accounts->name2id($login);
 				print_debug('User ID',$login_id,'app');
-				$GLOBALS['phpgw']->accounts->accounts($login_id);
-				$GLOBALS['phpgw']->preferences->preferences($login_id);
-				$GLOBALS['phpgw']->datetime = createObject('phpgwapi.datetimefunctions');
+				$GLOBALS['phpgw']->accounts->set_account($login_id);
+				$GLOBALS['phpgw']->preferences->set_account_id($login_id);
 			}
 		}
 	/**************************************************************************\
@@ -608,28 +518,28 @@
 			$GLOBALS['phpgw']->translation->translation($reset = True);
 		}
 
-		$redirect = unserialize(stripslashes(get_var('redirect',array('GET','COOKIE'))));
-		if($redirect)
+		$redirect = unserialize(phpgw::get_var('redirect','raw', 'COOKIE'));
+		if ( is_array($redirect) && count($redirect) )
 		{
-			while(list($key,$value) = each($redirect))
+			foreach($redirect as $key => $value)
 			{
-				$redirect_data[$key] = $value;
+				$redirect_data[$key] = phpgw::clean_value($value);
 			}
 			
-			if(get_var('sessionid',array('GET')))
+			$sessid = phpgw::get_var('sessionid', 'string', 'GET');
+			if ( $sessid )
 			{
-				$redirect_data['sessionid'] = get_var('sessionid',array('GET'));
-				$redirect_data['kp3'] = get_var('kp3',array('GET'));
+				$redirect_data['sessionid'] = $sessid;
+				$redirect_data['kp3'] = phpgw::get_var('kp3', 'string', 'GET');
 			}
 			
-			$GLOBALS['phpgw']->session->phpgw_setcookie('redirect',false,$cookietime=0);
-			$GLOBALS['phpgw']->redirect_link('/index.php',$redirect_data);
+			$GLOBALS['phpgw']->session->phpgw_setcookie('redirect', false, 0);
+			$GLOBALS['phpgw']->redirect_link('/index.php', $redirect_data);
 			unset($redirect);
 			unset($redirect_data);
+			unset($sessid);
 		}
 
-		$GLOBALS['phpgw']->datetime = createObject('phpgwapi.datetimefunctions');
-
 		/* A few hacker resistant constants that will be used throught the program */
 		define('PHPGW_TEMPLATE_DIR', ExecMethod('phpgwapi.phpgw.common.get_tpl_dir', 'phpgwapi'));
 		define('PHPGW_IMAGES_DIR', ExecMethod('phpgwapi.phpgw.common.get_image_path', 'phpgwapi'));
@@ -643,7 +553,7 @@
 	/************************************************************************\
 	* Load the menuaction                                                    *
 	\************************************************************************/
-		$GLOBALS['phpgw_info']['menuaction'] = get_var('menuaction',Array('GET','POST'));
+		$GLOBALS['phpgw_info']['menuaction'] = phpgw::get_var('menuaction');
 		if(!$GLOBALS['phpgw_info']['menuaction'])
 		{
 			unset($GLOBALS['phpgw_info']['menuaction']);
@@ -679,54 +589,6 @@
 			$GLOBALS['phpgw']->xslttpl = createObject('phpgwapi.xslttemplates',PHPGW_APP_TPL);
 		}
 
-		/*************************************************************************\
-		* These lines load up the themes  .16-compability                          *
-		\*************************************************************************/
-		if (!isset($GLOBALS['phpgw_info']['user']['preferences']['common']['theme']) || !$GLOBALS['phpgw_info']['user']['preferences']['common']['theme'])
-		{
-			if (@$GLOBALS['phpgw_info']['server']['template_set'] == 'user_choice')
-			{
-				$GLOBALS['phpgw_info']['user']['preferences']['common']['theme'] = 'default';
-			}
-			else
-			{
-				$GLOBALS['phpgw_info']['user']['preferences']['common']['theme'] = $GLOBALS['phpgw_info']['server']['template_set'];
-			}
-		}
-		if (@$GLOBALS['phpgw_info']['server']['force_theme'] == 'user_choice')
-		{
-			if (!isset($GLOBALS['phpgw_info']['user']['preferences']['common']['theme']))
-			{
-				$GLOBALS['phpgw_info']['user']['preferences']['common']['theme'] = 'default';
-			}
-		}
-		else
-		{
-			if (isset($GLOBALS['phpgw_info']['server']['force_theme']))
-			{
-				$GLOBALS['phpgw_info']['user']['preferences']['common']['theme'] = $GLOBALS['phpgw_info']['server']['force_theme'];
-			}
-		}
-
-		if(@file_exists(PHPGW_SERVER_ROOT . '/phpgwapi/themes/' . $GLOBALS['phpgw_info']['user']['preferences']['common']['theme'] . '.theme'))
-		{
-			include(PHPGW_SERVER_ROOT . '/phpgwapi/themes/' . $GLOBALS['phpgw_info']['user']['preferences']['common']['theme'] . '.theme');
-		}
-		elseif(@file_exists(PHPGW_SERVER_ROOT . '/phpgwapi/themes/default.theme'))
-		{
-			include(PHPGW_SERVER_ROOT . '/phpgwapi/themes/default.theme');
-		}
-		else
-		{
-			echo '<body bgcolor="FFFFFF">';
-			echo lang('No themes found');
-			echo '</body>';
-			$GLOBALS['phpgw']->log->write(array('text'=>'F-Abort, No themes found'));
-
-			exit;
-		}
-		unset($theme_to_load);
-
 		/*************************************************************************\
 		* If they are using frames, we need to set some variables                 *
 		\*************************************************************************/
@@ -752,11 +614,8 @@
 			}
 		}
 
-		if(!is_object($GLOBALS['phpgw']->datetime))
-		{
-			$GLOBALS['phpgw']->datetime = createObject('phpgwapi.datetimefunctions');
-		}
-		$GLOBALS['phpgw']->applications->read_installed_apps();	// to get translated app-titles
+	//  Already called from sessions::verify
+	//	$GLOBALS['phpgw']->applications->read_installed_apps();	// to get translated app-titles
 		
 		/*************************************************************************\
 		* Load the header unless the developer turns it off                       *
