@@ -10,7 +10,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage accounts
-	* @version $Id: class.sessions_db.inc.php,v 1.2 2007/03/20 08:33:52 sigurdne Exp $
+	* @version $Id: class.sessions_db.inc.php 18358 2007-11-27 04:43:37Z skwashd $
 	* @link http://www.sanisoft.com/phplib/manual/session.php
 	*/
 
@@ -31,9 +31,8 @@
 		{
 			$this->db->query("SELECT * FROM phpgw_sessions WHERE session_id='" . $this->sessionid . "'",__LINE__,__FILE__);
 			$this->db->next_record();
-
-			return $this->db->Record;
-		//	return $this->db->resultSet->fetchRow(); // only adodb
+			
+			return $this->db->resultSet->fetchRow();
 		}
 
 		// This will remove stale sessions out of the database
@@ -61,7 +60,7 @@
 		// This will update the DateLastActive column, so the login does not expire
 		function update_dla()
 		{
-			$menu_action = get_var('menuaction',Array('GET','POST'));
+			$menu_action = phpgw::get_var('menuaction');
 			$action = $menu_action ? $menu_action : $_SERVER['PHP_SELF'];  
 
 			// This way XML-RPC users aren't always listed as
@@ -136,19 +135,11 @@
 				$GLOBALS['phpgw']->db->next_record();
 
 				// I added these into seperate steps for easier debugging
-				$data = $GLOBALS['phpgw']->db->f('content');
-				// Changed by Skeeter 2001 Mar 04 0400Z
-				// This was not properly decoding structures saved into session data properly
-//				$data = $GLOBALS['phpgw']->common->decrypt($data);
-//				return stripslashes($data);
-				// Changed by milosch 2001 Dec 20
-				// do not stripslashes here unless this proves to be a problem.
-				// Changed by milosch 2001 Dec 25
-				/* do not decrypt and return if no data (decrypt returning garbage) */
+				$data = $GLOBALS['phpgw']->db->f('content', true);
 				if($data)
 				{
 					$data = $GLOBALS['phpgw']->crypto->decrypt($data);
-//					echo 'appsession returning: '; _debug_array($data);
+					// echo 'appsession returning: '; _debug_array($data);
 					return $data;
 				}
 			}
@@ -158,8 +149,7 @@
 					. "sessionid = '".$this->sessionid."' AND loginid = '".$this->account_id."'"
 					. " AND app = '".$appname."' AND location = '".$location."'",__LINE__,__FILE__);
 
-				$encrypteddata = $GLOBALS['phpgw']->crypto->encrypt($data);
-				$encrypteddata = $GLOBALS['phpgw']->db->db_addslashes($encrypteddata);
+				$encrypteddata = $GLOBALS['phpgw']->db->db_addslashes($GLOBALS['phpgw']->crypto->encrypt($data));
 
 				if ($GLOBALS['phpgw']->db->num_rows()==0)
 				{
