@@ -5,8 +5,8 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage setup
-	* @version $Id: tables_current.inc.php,v 1.2 2007/02/06 12:47:18 sigurdne Exp $
-	* @internal $Source: /sources/fmsystem/phpgwapi/setup/tables_current.inc.php,v $
+	* @version $Id: tables_current.inc.php 17761 2006-12-26 07:20:49Z skwashd $
+	* @internal $Source$
 	*/
 
 	$phpgw_baseline = array(
@@ -411,7 +411,7 @@
 			'fd' => array(
 				'org_id' => array('type' => 'int','precision' => '4','nullable' => False),
 				'name' => array('type' => 'varchar','precision' => '80','nullable' => False),
-				'active' => array('type' => 'char','precision' => '1','nullable' => False,'default' => 'Y'),
+				'active' => array('type' => 'char','precision' => '1','nullable' => True,'default' => 'Y'),
 				'parent' => array('type' => 'int','precision' => '4','nullable' => True),
 				'created_on' => array('type' => 'int','precision' => '4','nullable' => False),
 				'created_by' => array('type' => 'int','precision' => '4','nullable' => False),
@@ -441,7 +441,7 @@
 			'fd' => array(
 				'contact_addr_id' => array('type' => 'auto','nullable' => False),
 				'contact_id' => array('type' => 'int','precision' => '4','nullable' => False),
-				'addr_type_id' => array('type' => 'int','precision' => '4','nullable' => False),
+				'addr_type_id' => array('type' => 'int','precision' => '4','nullable' => True),
 				'add1' => array('type' => 'varchar','precision' => '64','nullable' => True),
 				'add2' => array('type' => 'varchar','precision' => '64','nullable' => True),
 				'add3' => array('type' => 'varchar','precision' => '64','nullable' => True),
@@ -578,7 +578,11 @@
 				'precision_' => array('type' => 'int','precision' => '4','nullable' => True),
 				'scale' => array('type' => 'int','precision' => '4','nullable' => True),
 				'default_value' => array('type' => 'varchar','precision' => '20','nullable' => True),
-				'nullable' => array('type' => 'varchar','precision' => '5','nullable' => True)
+				'nullable' => array('type' => 'varchar','precision' => '5','nullable' => True),
+				'disabled' => array('type' => 'int','precision' => '2','nullable' => True),
+				'lookup_form' => array('type' => 'int','precision' => '2','nullable' => True),
+				'custom' => array('type' => 'int','precision' => '2','nullable' => True,'default' => 1),
+				'helpmsg' => array('type' => 'text','nullable' => True)
 			),
 			'pk' => array('appname','location','id'),
 			'fk' => array(),
