@@ -9,8 +9,13 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: head.inc.php,v 1.3 2007/02/17 22:03:04 sigurdne Exp $ */
+  /* $Id: head.inc.php 18311 2007-10-10 08:53:53Z skwashd $ */
 
+	if ( !isset($GLOBALS['phpgw_info']['server']['site_title']) )
+	{
+		$GLOBALS['phpgw_info']['server']['site_title'] = lang('please set a site name in admin &gt; siteconfig');
+	}
+	
 	$tpl = CreateObject('phpgwapi.Template',PHPGW_TEMPLATE_DIR);
 	$tpl->set_unknowns('remove');
 	$tpl->set_file(array('head' => 'head.tpl'));
@@ -19,13 +24,13 @@
 	$app = $app ? ' ['.(isset($GLOBALS['phpgw_info']['apps'][$app]) ? $GLOBALS['phpgw_info']['apps'][$app]['title'] : lang($app)).']':'';
 
 	if(file_exists(PHPGW_SERVER_ROOT . '/phpgwapi/templates/desktop/css/' . $GLOBALS['phpgw_info']['user']['preferences']['common']['theme'] . '.css'))
-        {
-                $theme_css = $GLOBALS['phpgw_info']['server']['webserver_url'] . '/phpgwapi/templates/desktop/css/'.$GLOBALS['phpgw_info']['user']['preferences']['common']['theme'].'.css';
-        }
-        else
-        {
-                $theme_css = $GLOBALS['phpgw_info']['server']['webserver_url'] . '/phpgwapi/templates/desktop/css/desktop.css';
-        }
+	{
+			$theme_css = $GLOBALS['phpgw_info']['server']['webserver_url'] . '/phpgwapi/templates/desktop/css/'.$GLOBALS['phpgw_info']['user']['preferences']['common']['theme'].'.css';
+	}
+	else
+	{
+			$theme_css = $GLOBALS['phpgw_info']['server']['webserver_url'] . '/phpgwapi/templates/desktop/css/desktop.css';
+	}
 
 	if( !is_object($GLOBALS['phpgw']->js) )
 	{
@@ -33,19 +38,12 @@
 	}
 	$GLOBALS['phpgw']->js->set_onload('initPage();');
 
-	if ( ! (isset($GLOBALS['phpgw_info']['theme']) && is_array($GLOBALS['phpgw_info']['theme']) && count($GLOBALS['phpgw_info']['theme']) ) )
-	{
-		$GLOBALS['phpgw_info']['theme'] = array('font'	=> '');
-	}
-
 	$var = Array (
 		'img_icon'      => PHPGW_IMAGES_DIR . '/favicon.ico',
 		'img_shortcut'  => PHPGW_IMAGES_DIR . '/favicon.ico',
-		'font_family'   => $GLOBALS['phpgw_info']['theme']['font'],
 		'website_title' => $GLOBALS['phpgw_info']['server']['site_title'] . $app,
-		'body_tags'     => $GLOBALS['phpgw']->common->get_body_attribs(),
-		'theme_css'	=> $theme_css,
-		'css'		=> $GLOBALS['phpgw']->common->get_css(),
+		'theme_css'		=> $theme_css,
+		'css'			=> $GLOBALS['phpgw']->common->get_css(),
 		'java_script'   => $GLOBALS['phpgw']->common->get_java_script(),
 	);
 	$tpl->set_var($var);
