@@ -9,7 +9,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: navbar.inc.php,v 1.3 2007/02/17 22:03:04 sigurdne Exp $ */
+  /* $Id: navbar.inc.php 18311 2007-10-10 08:53:53Z skwashd $ */
 
   function parse_navbar($force = False)
   {
@@ -150,7 +150,6 @@
 		if (isset($GLOBALS['phpgw_info']['flags']['app_header']))
 		{
 			$var['current_app_header'] = $GLOBALS['phpgw_info']['flags']['app_header'];
-			$var['th_bg'] = $GLOBALS['phpgw_info']['theme']['th_bg'];
 		}
 		else
 		{
@@ -185,7 +184,9 @@
 		);
 		$var = array();
 		$var['powered_by'] = lang('Powered by phpGroupWare version %1',$GLOBALS['phpgw_info']['server']['versions']['phpgwapi']);
-		if (isset($GLOBALS['phpgw_info']['navbar']['admin']) && $GLOBALS['phpgw_info']['user']['preferences']['common']['show_currentusers'])
+		if (isset($GLOBALS['phpgw_info']['navbar']['admin']) 
+			&& isset($GLOBALS['phpgw_info']['user']['preferences']['common']['show_currentusers'])
+			&& $GLOBALS['phpgw_info']['user']['preferences']['common']['show_currentusers'])
 		{
 			$var['current_users'] = '<a href="' . $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.uicurrentsessions.list_sessions'))
 				. '">' . lang('Current users') . ': ' . $GLOBALS['phpgw']->session->total() . '</a>';
