@@ -5,7 +5,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage gui
-	* @version $Id: navbar.inc.php,v 1.10 2007/11/20 09:35:14 sigurdne Exp $
+	* @version $Id: navbar.inc.php,v 1.24 2007/08/23 11:58:21 sigurdne Exp $
 	*/
 
 
@@ -17,36 +17,28 @@
 	*/
 	function parse_navbar($force = False)
 	{
-		$GLOBALS['idots_tpl'] = createobject('phpgwapi.Template',PHPGW_TEMPLATE_DIR);
 
-		$GLOBALS['idots_tpl']->set_file(
-			array(
-				'navbar' => 'navbar.tpl'
-			)
-		);
-		
-		$GLOBALS['idots_tpl']->set_block('navbar','navbar_header','navbar_header');
-		$GLOBALS['idots_tpl']->set_block('navbar','extra_blocks_header','extra_block_header');
-		$GLOBALS['idots_tpl']->set_block('navbar','extra_block_row','extra_block_row');
-		$GLOBALS['idots_tpl']->set_block('navbar','extra_block_spacer','extra_block_spacer');
-		$GLOBALS['idots_tpl']->set_block('navbar','extra_blocks_footer','extra_blocks_footer');
-		$GLOBALS['idots_tpl']->set_block('navbar','navbar_footer','navbar_footer');
+		$GLOBALS['phpgw']->template->set_root(PHPGW_TEMPLATE_DIR);
+		$GLOBALS['phpgw']->template->set_file('navbar', 'navbar.tpl');
+		$GLOBALS['phpgw']->template->set_block('navbar','navbar_header','navbar_header');
+		$GLOBALS['phpgw']->template->set_block('navbar','extra_blocks_header','extra_block_header');
+		$GLOBALS['phpgw']->template->set_block('navbar','extra_block_row','extra_block_row');
+		$GLOBALS['phpgw']->template->set_block('navbar','extra_block_spacer','extra_block_spacer');
+		$GLOBALS['phpgw']->template->set_block('navbar','extra_blocks_footer','extra_blocks_footer');
+		$GLOBALS['phpgw']->template->set_block('navbar','navbar_footer','navbar_footer');
 
 		$var['img_root'] = $GLOBALS['phpgw_info']['server']['webserver_url'] . '/phpgwapi/templates/idots/images';
-		$var['table_bg_color'] = $GLOBALS['phpgw_info']['theme']['navbar_bg'];
 		$var['logo'] = isset($GLOBALS['phpgw_info']['server']['logo_file']) && $GLOBALS['phpgw_info']['server']['logo_file'] ? $GLOBALS['phpgw_info']['server']['logo_file'] : 'logo.png';
 		$var['logo_title'] = isset($GLOBALS['phpgw_info']['server']['login_logo_title']) && $GLOBALS['phpgw_info']['server']['login_logo_title'] ? $GLOBALS['phpgw_info']['server']['login_logo_title'] : 'phpGroupWare Logo';
 		$var['logo_url'] = isset($GLOBALS['phpgw_info']['server']['login_logo_url']) && $GLOBALS['phpgw_info']['server']['login_logo_url'] ? $GLOBALS['phpgw_info']['server']['login_logo_url'] : 'www.phpgroupware.org';
 
-		$sidecontent = isset($GLOBALS['phpgw_info']['user']['preferences']['common']['sidecontent']) && $GLOBALS['phpgw_info']['user']['preferences']['common']['sidecontent'] ? $GLOBALS['phpgw_info']['user']['preferences']['common']['sidecontent'] : 'sidebox'; 
-
 		$applications = '';
-		$items++;
+		$items = 0;
+		$app_icons = '';
+		$app_titles = '';
 		foreach($GLOBALS['phpgw_info']['navbar'] as $app => $app_data)
 		{
-	//		if ($app != 'home' && $app != 'preferences' && $app != 'about' && $app != 'logout')
-			if (($app != 'home' && $app != 'preferences' && $app != 'about' && $app != 'logout') 
-				|| ($sidecontent != 'sidebox' && $sidecontent != 'javamenu'))
+			if ($app != 'home' && $app != 'preferences' && $app != 'about' && $app != 'logout')
 			{
 				$title = $GLOBALS['phpgw_info']['apps'][$app]['title'];
 				
@@ -98,19 +90,21 @@
 		}
 		else
 		{
-			$var['current_app_title']=$GLOBALS['phpgw_info']['navbar'][$GLOBALS['phpgw_info']['flags']['currentapp']]['title'];
+			$var['current_app_title'] = lang($GLOBALS['phpgw_info']['flags']['currentapp']);
 		}
 
-		if (isset($GLOBALS['phpgw_info']['navbar']['admin']) && $GLOBALS['phpgw_info']['user']['preferences']['common']['show_currentusers'])
+		if (isset($GLOBALS['phpgw_info']['navbar']['admin']) 
+			&& isset($GLOBALS['phpgw_info']['user']['preferences']['common']['show_currentusers'])
+			&& $GLOBALS['phpgw_info']['user']['preferences']['common']['show_currentusers'] )
 		{
 			$var['current_users'] = '<a href="'
-			. $GLOBALS['phpgw']->link('/index.php','menuaction=admin.uicurrentsessions.list_sessions') . '">'
+			. $GLOBALS['phpgw']->link('/index.php', array('menuaction' => 'admin.uicurrentsessions.list_sessions')) . '">'
 			. lang('Current users') . ': ' . $GLOBALS['phpgw']->session->total() . '</a>';
 		}
 		$now = time();
 		$var['user_info'] = '<b>'.$GLOBALS['phpgw']->common->display_fullname() .'</b>'. ' - '
 		. lang($GLOBALS['phpgw']->common->show_date($now,'l')) . ' '
-		. $GLOBALS['phpgw']->common->show_date($now,$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
+		. $GLOBALS['phpgw']->common->show_date($now, $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
 
 		if ( $GLOBALS['phpgw']->acl->check('changepassword', 1, 'preferences') )
 		{
@@ -138,45 +132,45 @@
 		// This is gonna change
 		if (isset($cd))
 		{
-			$var['messages'] = $api_messages . '<br />' . checkcode($cd);
+			$var['messages'] = $api_messages . '<br>' . checkcode($cd);
 		}
 
-		$GLOBALS['idots_tpl']->set_var($var);
-		$GLOBALS['idots_tpl']->pfp('out','navbar_header');
+		$GLOBALS['phpgw']->template->set_var($var);
+		$GLOBALS['phpgw']->template->pfp('out','navbar_header');
 
-		if($sidecontent == 'sidebox' || $sidecontent == 'javamenu') 
+		$menu_title = lang('General Menu');
+
+		$file[] = array('text' => 'Home',
+				'url' => $GLOBALS['phpgw_info']['navbar']['home']['url']);
+		if ( isset($GLOBALS['phpgw_info']['navbar']['preferences']))
 		{
-			$menu_title = lang('General Menu');
-
-			$file[] = array('text' => 'Home',
-					'url' => $GLOBALS['phpgw_info']['navbar']['home']['url']);
-			if ($GLOBALS['phpgw_info']['user']['apps']['preferences'])
-			{
-				$file[] = array ('text' => 'Preferences',
-						'url' => $GLOBALS['phpgw_info']['navbar']['preferences']['url'] 
-								. '#' . $GLOBALS['phpgw_info']['flags']['currentapp']);
-			}
-			$file[] = array ('text' => 'About %1', 'url' => $GLOBALS['phpgw_info']['navbar']['about']['url']);
-			$file[] = array ('text' => 'Logout', 'url' => $GLOBALS['phpgw_info']['navbar']['logout']['url']);
-
-			display_sidebox('',$menu_title,$file);
-		
-			$GLOBALS['phpgw']->hooks->single('sidebox_menu',$GLOBALS['phpgw_info']['flags']['currentapp']);
+			$file[] = array ('text' => 'Preferences',
+					'url' => $GLOBALS['phpgw_info']['navbar']['preferences']['url'] 
+							. '#' . $GLOBALS['phpgw_info']['flags']['currentapp']);
 		}
+		$file[] = array ('text' => 'About %1', 'url' => $GLOBALS['phpgw_info']['navbar']['about']['url']);
+		$file[] = array ('text' => 'Logout', 'url' => $GLOBALS['phpgw_info']['navbar']['logout']['url']);
 
-		$GLOBALS['idots_tpl']->pparse('out','navbar_footer');
+		display_sidebox('',$menu_title,$file);
+		
+		$GLOBALS['phpgw']->hooks->single('sidebox_menu',$GLOBALS['phpgw_info']['flags']['currentapp']);
+
+		$GLOBALS['phpgw']->template->pparse('out','navbar_footer');
 
 		// If the application has a header include, we now include it
-		if (!@$GLOBALS['phpgw_info']['flags']['noappheader'] && @isset($GLOBALS['HTTP_GET_VARS']['menuaction']))
+		if ( (!isset($GLOBALS['phpgw_info']['flags']['noappheader'])
+			|| !$GLOBALS['phpgw_info']['flags']['noappheader'] )
+			&& isset($_GET['menuaction']) )
 		{
-			list($app,$class,$method) = explode('.',$GLOBALS['HTTP_GET_VARS']['menuaction']);
-			if (is_array($GLOBALS[$class]->public_functions) && $GLOBALS[$class]->public_functions['header'])
+			list($app,$class,$method) = explode('.',$_GET['menuaction']);
+			if (is_array($GLOBALS[$class]->public_functions) && isset($GLOBALS[$class]->public_functions['header']) )
 			{
 				$GLOBALS[$class]->header();
 			}
 		}
+		$GLOBALS['phpgw']->template->set_root(PHPGW_APP_TPL);
 		$GLOBALS['phpgw']->hooks->process('after_navbar');
-		return;
+		unset($GLOBALS['phpgw_info']['navbar']);
 	}
 
 	/**
@@ -187,21 +181,36 @@
 	* @param string $file
 	* @param boolean $use_lang
 	*/
-	function display_sidebox($appname, $menu_title, $file, $use_lang = True)
+	function display_sidebox($appname, $menu_title, $file, $use_lang = true)
 	{
 		
-		if(!$appname || ($appname == $GLOBALS['phpgw_info']['flags']['currentapp'] && $file))
+		if(!$appname || ($appname == $GLOBALS['phpgw_info']['flags']['currentapp'] && is_array($file) ) )
 		{
 			$var['lang_title'] = $menu_title;
-			$GLOBALS['idots_tpl']->set_var($var);
-			$GLOBALS['idots_tpl']->pfp('out','extra_blocks_header');
+			$GLOBALS['phpgw']->template->set_var($var);
+			$GLOBALS['phpgw']->template->pfp('out','extra_blocks_header');
 			
-			foreach($file as $null => $item)
+			foreach ( $file as $item )
 			{
+				if ( !isset($item['url']) )
+				{
+					$item['url'] = '';
+				}
+
+				if ( !isset($item['image']) )
+				{
+					$item['image'] = '';
+				}
+
+				if ( !isset($item['this']) )
+				{
+					$item['this'] = '';
+				}
+
 				sidebox_menu_item($item['url'], $item['text'], $item['image'], $use_lang, $item['this']);
 			}
 
-			$GLOBALS['idots_tpl']->pparse('out','extra_blocks_footer');
+			$GLOBALS['phpgw']->template->pfp('out','extra_blocks_footer');
 		}
 	}
 
@@ -217,18 +226,18 @@
 	{
 		if($item_text == '_NewLine_')
 		{
-			$GLOBALS['idots_tpl']->pparse('out','extra_block_spacer');
+			$GLOBALS['phpgw']->template->pfp('out','extra_block_spacer');
 		}
 		else
 		{
 			$lang_item = $use_lang ? lang($item_text) : $item_text;
 
-			$var['icon_or_star']= ($item_image ? $item_image : '*');
+			$var['icon_or_star']= !is_array($item_image)?($item_image ? $item_image : ''):'';
 			$var['lang_item'] = $current_item ? '<b>' . $lang_item . '</b>': $lang_item;
 			$var['item_link']=$item_link;
 
-			$GLOBALS['idots_tpl']->set_var($var);		
-			$GLOBALS['idots_tpl']->pparse('out','extra_block_row');
+			$GLOBALS['phpgw']->template->set_var($var);		
+			$GLOBALS['phpgw']->template->pparse('out','extra_block_row');
 		}
 	}
 	
@@ -242,21 +251,18 @@
 	*/
 	function parse_navbar_end()
 	{
-		$GLOBALS['idots_tpl'] = createobject('phpgwapi.Template',PHPGW_TEMPLATE_DIR);
-
-		$GLOBALS['idots_tpl']->set_file(
-			array(
-				'footer' => 'footer.tpl'
-			)
-		);
-		$var = Array(
-			'img_root'			=> $GLOBALS['phpgw_info']['server']['webserver_url'] . '/phpgwapi/templates/idots/images',
-			'table_bg_color'	=> $GLOBALS['phpgw_info']['theme']['navbar_bg'],
-			'version'			=> $GLOBALS['phpgw_info']['server']['versions']['phpgwapi']
-		);
 		$GLOBALS['phpgw']->hooks->process('navbar_end');
 
-		$var['powered_by'] = lang('Powered by phpGroupWare version %1',$GLOBALS['phpgw_info']['server']['versions']['phpgwapi']);
-		$GLOBALS['idots_tpl']->set_var($var);
-		$GLOBALS['idots_tpl']->pfp('out','footer');
+		$GLOBALS['phpgw']->template->set_root(PHPGW_TEMPLATE_DIR);
+		$GLOBALS['phpgw']->template->set_file('footer', 'footer.tpl');
+		$var = array
+		(
+			'img_root'		=> $GLOBALS['phpgw_info']['server']['webserver_url'] . '/phpgwapi/templates/idots/images',
+			'powered_by'	=> lang('Powered by phpGroupWare version %1', $GLOBALS['phpgw_info']['server']['versions']['phpgwapi']),
+			'version'		=> $GLOBALS['phpgw_info']['server']['versions']['phpgwapi']
+		);
+	//	$GLOBALS['phpgw']->hooks->process('navbar_end');
+
+		$GLOBALS['phpgw']->template->set_var($var);
+		$GLOBALS['phpgw']->template->pfp('out','footer');
 	}
