@@ -5,7 +5,7 @@
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package phpgwapi
 	* @subpackage gui
-	* @version $Id: navbar.inc.php,v 1.2 2007/02/17 22:03:04 sigurdne Exp $
+	* @version $Id: navbar.inc.php 17902 2007-01-24 16:04:52Z Caeies $
 	*/
 
 
@@ -65,7 +65,7 @@
 		{
 			$var['navbar_color'] = $GLOBALS['phpgw_info']['theme']['bg_color'];
 			$var['align'] = 'right';
-			$var['value'] = $GLOBALS['phpgw']->common->create_tabs($tabs,$selected,-1);
+			$var['value'] = $GLOBALS['phpgw']->common->create_tabs($tabs,$selected);
 			$tpl->set_var($var);
 			$tpl->parse('applications','navbar_app',True);
 		}
