@@ -5,7 +5,7 @@
 	* @copyright Copyright (C) 2000-2006 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package preferences
-	* @version $Id: preferences.php,v 1.47 2007/03/25 19:38:39 sigurdne Exp $
+	* @version $Id: preferences.php 18358 2007-11-27 04:43:37Z skwashd $
 	*/
 
 	$GLOBALS['phpgw_info']['flags'] = array
@@ -13,7 +13,7 @@
 		'noheader'				=> true,
 		'noappheader'			=> true,
 		'nonavbar'				=> true,
-		'currentapp'			=> isset($_GET['appname']) ? $_GET['appname'] : '',
+		'currentapp'			=> isset($_GET['appname']) ? htmlspecialchars($_GET['appname']) : 'preferences',
 		'enable_nextmatchs'		=> true
 	);
 	
@@ -21,32 +21,7 @@
 	 * Include phpgroupware header
 	 */
 	include_once('../header.inc.php');
-	
-	if ( isset($_POST['cancel']) && $_POST['cancel'] )
-	{
-		Header('Location: ' . $GLOBALS['phpgw']->link('/preferences/index.php') . '#' . $_GET['appname']);
-		exit;
-	}
-	
-	$user    = get_var('user',Array('POST'));
-	$forced  = get_var('forced',Array('POST'));
-	$default = get_var('default',Array('POST'));
 
-	$t =& $GLOBALS['phpgw']->template;
-	$t->set_root( $GLOBALS['phpgw']->common->get_tpl_dir('preferences') );
-	$t->set_file('preferences', 'preferences.tpl');
-	$t->set_block('preferences','list','lists');
-	$t->set_block('preferences','row','rowhandle');
-	$t->set_block('preferences','help_row','help_rowhandle');
-	$t->set_var(array('rowhandle' => '','help_rowhandle' => '','messages' => ''));
-	
-	if ($_GET['appname'] != 'preferences')
-	{
-		$GLOBALS['phpgw']->translation->add_app('preferences');	// we need the prefs translations too
-	}
-
-	/* Make things a little easier to follow */
-	/* Some places we will need to change this if there in common */
 
 
 	/**
@@ -56,15 +31,41 @@
 	 */
 	function check_app()
 	{
-		if ($_GET['appname'] == 'preferences')
+		$app = phpgw::get_var('appname', 'string', 'GET', '');
+		if ( !$app || $app == 'preferences' )
 		{
 			return 'common';
 		}
-		else
-		{
-			return $_GET['appname'];
-		}
+		return $app;
 	}
+	$appname = phpgw::get_var('appname', 'string', 'GET', 'preferences');
+
+	if ( phpgw::get_var('cancel', 'bool', 'POST') )
+	{
+		Header('Location: ' . $GLOBALS['phpgw']->link('/preferences/index.php') . "#$appname");
+		exit;
+	}
+	
+	$user    = phpgw::get_var('user', 'string', 'POST');
+	$forced  = phpgw::get_var('forced', 'string', 'POST');
+	$default = phpgw::get_var('default', 'string', 'POST');
+
+	$t =& $GLOBALS['phpgw']->template;
+	$t->set_root( $GLOBALS['phpgw']->common->get_tpl_dir('preferences') );
+	$t->set_file('preferences', 'preferences.tpl');
+	$t->set_block('preferences','list','lists');
+	$t->set_block('preferences','row','rowhandle');
+	$t->set_block('preferences','help_row','help_rowhandle');
+	$t->set_var(array('rowhandle' => '','help_rowhandle' => '','messages' => ''));
+	
+	if ( $appname != 'preferences' )
+	{
+		$GLOBALS['phpgw']->translation->add_app('preferences');	// we need the prefs translations too
+	}
+
+	/* Make things a little easier to follow */
+	/* Some places we will need to change this if there in common */
+
 
 	/**
 	 * Is the current value forced
@@ -505,14 +506,18 @@
 
 	$session_data = $GLOBALS['phpgw']->session->appsession('session_data','preferences');
 
-	$prefix = get_var('prefix',array('GET'),(isset($session_data['appname']) && $session_data['appname'] == $_GET['appname']) ? $session_data['prefix'] : '');
+	$prefix = phpgw::get_var('prefix', 'string', 'GET');
+	if ( !$prefix && (isset($session_data['appname']) && $session_data['appname'] == $_GET['appname']) )
+	{
+		$prefix = $session_data['prefix'];
+	}
 	
 	if (is_admin())
 	{
 		/* This is where we will keep track of our postion. */
 		/* Developers won't have to pass around a variable then */
 
-		$GLOBALS['type'] = get_var('type',Array('GET','POST'),$session_data['type']);
+		$GLOBALS['type'] = phpgw::get_var('type', 'string', 'REQUEST', $session_data['type']);
 
 		if (empty($GLOBALS['type']))
 		{
@@ -523,17 +528,28 @@
 	{
 		$GLOBALS['type'] = 'user';
 	}
-	$show_help = "$session_data[show_help]" != '' && $session_data['appname'] == $_GET['appname'] ? 
-		$session_data['show_help'] : intval($GLOBALS['phpgw_info']['user']['preferences']['common']['show_help']);
 
-	if ($toggle_help = get_var('toggle_help','POST'))
+	$show_help = true;
+	if ( isset($session_data['show_help']) 
+		&& $session_data['show_help'] != '' 
+		&& $session_data['appname'] == $appname )
 	{
-		$show_help = intval(!$show_help);
+		$show_help = $session_data['show_help'];
+	}
+	else if ( isset($GLOBALS['phpgw_info']['user']['preferences']['common']['show_help']) )
+	{
+		$show_help = !!$GLOBALS['phpgw_info']['user']['preferences']['common']['show_help'];
+	}
+
+	$toggle_help = phpgw::get_var('toggle_help', 'bool', 'POST');
+	if ( $toggle_help )
+	{
+		$show_help = !$show_help;
 	}
 	$has_help = 0;
 
 	$error = '';
-	if ( isset($_POST['submit']) && $_POST['submit'] )
+	if ( phpgw::get_var('submit', 'bool', 'POST') )
 	{
 		if ( !isset($session_data['notifys']) )
 		{
@@ -561,32 +577,33 @@
 			$GLOBALS['phpgw']->redirect_link('/preferences/index.php');
 		}
 		
-		if ($GLOBALS['type'] == 'user' && $_GET['appname'] == 'preferences' && (isset($user['show_help']) && $user['show_help'] != ''))
+		if ($GLOBALS['type'] == 'user' && $appname == 'preferences' && (isset($user['show_help']) && $user['show_help'] != ''))
 		{
 			$show_help = $user['show_help'];	// use it, if admin changes his help-prefs
 		}
 	}
-	$GLOBALS['phpgw']->session->appsession('session_data','preferences',array(
+	$GLOBALS['phpgw']->session->appsession('session_data','preferences',array
+	(
 		'type'      => $GLOBALS['type'],	// save our state in the app-session
 		'show_help' => $show_help,
 		'prefix'    => $prefix,
-		'appname'   => $_GET['appname']		// we use this to reset prefix on appname-change
+		'appname'   => $appname		// we use this to reset prefix on appname-change
 	));
 	// changes for the admin itself, should have immediate feedback ==> redirect
 	if ( !$error 
-		&& ( isset($_POST['submit']) && $_POST['submit'] )
+		&& ( phpgw::get_var('submit', 'bool', 'POST') )
 		&& $GLOBALS['type'] == 'user' 
-		&& $_GET['appname'] == 'preferences')
+		&& $appname == 'preferences')
 	{
-		$GLOBALS['phpgw']->redirect_link('/preferences/preferences.php', array('appname' => $_GET['appname']) );
+		$GLOBALS['phpgw']->redirect_link('/preferences/preferences.php', array('appname' => $appname) );
 	}
 
-	$GLOBALS['phpgw_info']['flags']['app_header'] = $_GET['appname'] == 'preferences' ?
-		lang('Preferences') : lang('%1 - Preferences',$GLOBALS['phpgw_info']['apps'][$_GET['appname']]['title']);
+	$GLOBALS['phpgw_info']['flags']['app_header'] = $appname == 'preferences' ?
+		lang('Preferences') : lang('%1 - Preferences', lang($appname) );
 	$GLOBALS['phpgw']->common->phpgw_header(true);
 
 	$t->set_var('messages',$error);
-	$t->set_var('action_url',$GLOBALS['phpgw']->link('/preferences/preferences.php', array('appname'=> $_GET['appname'])));
+	$t->set_var('action_url',$GLOBALS['phpgw']->link('/preferences/preferences.php', array('appname'=> $appname)));
 
 	switch ($GLOBALS['type'])	// set up some globals to be used by the hooks
 	{
@@ -611,14 +628,13 @@
 	//echo "prefs=<pre>"; print_r($prefs); echo "</pre>\n";
 	
 	$notifys = array();
-	if (!$GLOBALS['phpgw']->hooks->single('settings',$_GET['appname']))
+	if (!$GLOBALS['phpgw']->hooks->single('settings', $appname))
 	{
 		$t->set_block('preferences','form','formhandle');	// skip the form
 		$t->set_var('formhandle','');
 		
 		$t->set_var('messages',lang('Error: There was a problem finding the preference file for %1 in %2',
-			$GLOBALS['phpgw_info']['navbar'][$_GET['appname']]['title'],PHPGW_SERVER_ROOT . SEP
-			. $_GET['appname'] . SEP . 'inc' . SEP . 'hook_settings.inc.php'));
+			lang($appname), "/path/to/phpgroupware/{$appname}/inc/hook_settings.inc.php"));
 	}
 
 	if (count($notifys))	// there have been notifys in the hook, we need to save in the session
@@ -627,7 +643,7 @@
 			'type'      => $GLOBALS['type'],	// save our state in the app-session
 			'show_help' => $show_help,
 			'prefix'    => $prefix,
-			'appname'   => $_GET['appname'],	// we use this to reset prefix on appname-change
+			'appname'   => $appname,	// we use this to reset prefix on appname-change
 			'notifys'   => $notifys
 		));
 		//echo "notifys:<pre>"; print_r($notifys); echo "</pre>\n";
@@ -636,15 +652,15 @@
 	{
 		$tabs[] = array(
 			'label' => lang('Your preferences'),
-			'link'  => $GLOBALS['phpgw']->link('/preferences/preferences.php',array('appname'=> $_GET['appname'], 'type'=> 'user'))
+			'link'  => $GLOBALS['phpgw']->link('/preferences/preferences.php',array('appname'=> $appname, 'type'=> 'user'))
 		);
 		$tabs[] = array(
 			'label' => lang('Default preferences'),
-			'link'  => $GLOBALS['phpgw']->link('/preferences/preferences.php',array('appname'=> $_GET['appname'], 'type'=> 'default'))
+			'link'  => $GLOBALS['phpgw']->link('/preferences/preferences.php',array('appname'=> $appname, 'type'=> 'default'))
 		);
 		$tabs[] = array(
 			'label' => lang('Forced preferences'),
-			'link'  => $GLOBALS['phpgw']->link('/preferences/preferences.php',array('appname'=> $_GET['appname'], 'type'=> 'forced'))
+			'link'  => $GLOBALS['phpgw']->link('/preferences/preferences.php',array('appname'=> $appname, 'type'=> 'forced'))
 		);
 
 		switch($GLOBALS['type'])
