@@ -54,9 +54,9 @@
 
 		function property_boagreement($session=False)
 		{
-			$this->currentapp		= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->so = CreateObject('property.soagreement');
 			$this->bocommon = CreateObject('property.bocommon');
+			$this->custom 		= createObject('phpgwapi.custom_fields');
 			$this->vfs 			= CreateObject('phpgwapi.vfs');
 			$this->rootdir 		= $this->vfs->basedir;
 			$this->fakebase 	= $this->vfs->fakebase;
@@ -238,199 +238,65 @@
 
 		function read_single($data)
 		{
-			$agreement	= $this->so->read_single($data);
-			$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
-			$agreement['start_date']		= $GLOBALS['phpgw']->common->show_date($agreement['start_date'],$dateformat);
-			$agreement['end_date']		= $GLOBALS['phpgw']->common->show_date($agreement['end_date'],$dateformat);
-			if($agreement['termination_date'])
+			$values['attributes'] = $this->custom->get_attribs('property', '.agreement', 0, '', 'ASC', 'attrib_sort', true, true);
+			
+			if(isset($data['agreement_id']) && $data['agreement_id'])
 			{
-				$agreement['termination_date']= $GLOBALS['phpgw']->common->show_date($agreement['termination_date'],$dateformat);
+				$values = $this->so->read_single($data['agreement_id'], $values);
+			}
+			
+			$values = $this->custom->prepare_attributes($values, 'property', '.agreement');
+			
+			$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
+			if(isset($values['entry_date']) && $values['entry_date'])
+			{
+				$values['entry_date']	= $GLOBALS['phpgw']->common->show_date($values['entry_date'],$dateformat);
 			}
 
-			$agreement = $this->convert_attribute($agreement);
+			$values['start_date']		= $GLOBALS['phpgw']->common->show_date($values['start_date'],$dateformat);
+			$values['end_date']		= $GLOBALS['phpgw']->common->show_date($values['end_date'],$dateformat);
+			if(isset($values['termination_date']) && $values['termination_date'])
+			{
+				$values['termination_date']= $GLOBALS['phpgw']->common->show_date($values['termination_date'],$dateformat);
+			}
 
 			$this->vfs->override_acl = 1;
 
-			$agreement['files'] = $this->vfs->ls (array(
+			$values['files'] = $this->vfs->ls (array(
 			     'string' => $this->fakebase. '/' . 'agreement' .  '/' . $data['agreement_id'],
 			     'relatives' => array(RELATIVE_NONE)));
 
 			$this->vfs->override_acl = 0;
 
-			if(!isset($agreement['files'][0]['file_id']) || !$agreement['files'][0]['file_id'])
+			if(!isset($values['files'][0]['file_id']) || !$values['files'][0]['file_id'])
 			{
-				unset($agreement['files']);
+				unset($values['files']);
 			}
 
-			return $agreement;
-
+			return $values;
 		}
 
 		function read_single_item($data)
 		{
-			$item	= $this->so->read_single_item($data);
-//_debug_array($item);
-			$item	= $this->convert_attribute($item,True);
-			return $item;
-		}
-
-		function convert_attribute($list,$detail='')
-		{
-			if($detail)
+			$values['attributes'] = $this->custom->get_attribs('property', '.agreement.detail', 0, '', 'ASC', 'attrib_sort', true, true);
+			if(isset($data['agreement_id']) && $data['agreement_id'] && isset($data['id']) && $data['id'])
 			{
-				$this->so->role	= 'detail';
+				$values = $this->so->read_single_item($data, $values);
 			}
-			$contacts			= CreateObject('phpgwapi.contacts');
-
-			$vendor = CreateObject('property.soactor');
-			$vendor->role = 'vendor';
-
-			$dateformat = $GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat'];
-
-			$input_type_array = array(
-				'R' => 'radio',
-				'CH' => 'checkbox',
-				'LB' => 'listbox'
-			);
-
-			$sep = '/';
-			$dlarr[strpos($dateformat,'Y')] = 'Y';
-			$dlarr[strpos($dateformat,'m')] = 'm';
-			$dlarr[strpos($dateformat,'d')] = 'd';
-			ksort($dlarr);
-
-			$dateformat= (implode($sep,$dlarr));
-
-//html_print_r($list);
-			$m=0;
-			for ($i=0;$i<count($list['attributes']);$i++)
-			{
-				if($list['attributes'][$i]['datatype']=='D' && $list['attributes'][$i]['value'])
-				{
-					$timestamp_date= mktime(0,0,0,date(m,strtotime($list['attributes'][$i]['value'])),date(d,strtotime($list['attributes'][$i]['value'])),date(y,strtotime($list['attributes'][$i]['value'])));
-					$list['attributes'][$i]['value']	= $GLOBALS['phpgw']->common->show_date($timestamp_date,$dateformat);
-				}
-				if($list['attributes'][$i]['datatype']=='AB')
-				{
-					if($list['attributes'][$i]['value'])
-					{
-						$contact_data	= $contacts->read_single_entry($list['attributes'][$i]['value'],array('n_given'=>'n_given','n_family'=>'n_family','email'=>'email'));
-						$list['attributes'][$i]['contact_name']	= $contact_data[0]['n_family'] . ', ' . $contact_data[0]['n_given'];
-					}
-
-					$insert_record_list[]	= $list['attributes'][$i]['name'];
-					$lookup_link		= $GLOBALS['phpgw']->link('/index.php','menuaction='.$this->currentapp.'.uilookup.addressbook&column=' . $list['attributes'][$i]['name']);
-
-					$lookup_functions[$m]['name'] = 'lookup_'. $list['attributes'][$i]['name'] .'()';
-					$lookup_functions[$m]['action'] = 'Window1=window.open('."'" . $lookup_link ."'" .',"Search","width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
-					$m++;
-				}
-				if($list['attributes'][$i]['datatype']=='VENDOR')
-				{
-					if($list['attributes'][$i]['value'])
-					{
-						$vendor_data	= $vendor->read_single(array('actor_id'=>$list['attributes'][$i]['value']));
-
-						for ($n=0;$n<count($vendor_data['attributes']);$n++)
-						{
-							if($vendor_data['attributes'][$n]['name'] == 'org_name')
-							{
-								$list['attributes'][$i]['vendor_name']= $vendor_data['attributes'][$n]['value'];
-								$n =count($vendor_data['attributes']);
-							}
-						}
-					}
-
-					$insert_record_list[]	= $list['attributes'][$i]['name'];
-					$lookup_link		= $GLOBALS['phpgw']->link('/index.php','menuaction='.$this->currentapp.'.uilookup.vendor&column=' . $list['attributes'][$i]['name']);
-
-					$lookup_functions[$m]['name'] = 'lookup_'. $list['attributes'][$i]['name'] .'()';
-					$lookup_functions[$m]['action'] = 'Window1=window.open('."'" . $lookup_link ."'" .',"Search","width=800,height=700,toolbar=no,scrollbars=yes,resizable=yes");';
-					$m++;
-				}
-
-				if($list['attributes'][$i]['datatype']=='R' || $list['attributes'][$i]['datatype']=='CH' || $list['attributes'][$i]['datatype']=='LB')
-				{
-					$list['attributes'][$i]['choice']	= $this->so->read_attrib_choice($list['attributes'][$i]['attrib_id']);
-					$input_type=$input_type_array[$list['attributes'][$i]['datatype']];
-
-					if($list['attributes'][$i]['datatype']=='CH')
-					{
-						$list['attributes'][$i]['value']=unserialize($list['attributes'][$i]['value']);
-						$list['attributes'][$i]['choice'] = $this->bocommon->select_multi_list_2($list['attributes'][$i]['value'],$list['attributes'][$i]['choice'],$input_type);
-
-					}
-					else
-					{
-						for ($j=0;$j<count($list['attributes'][$i]['choice']);$j++)
-						{
-							$list['attributes'][$i]['choice'][$j]['input_type']=$input_type;
-							if($list['attributes'][$i]['choice'][$j]['id']==$list['attributes'][$i]['value'])
-							{
-								$list['attributes'][$i]['choice'][$j]['checked']='checked';
-							}
-						}
-					}
-				}
-
-				$list['attributes'][$i]['datatype_text'] = $this->bocommon->translate_datatype($list['attributes'][$i]['datatype']);
-				$list['attributes'][$i]['counter']	= $i;
-				$list['attributes'][$i]['type_id']	= $data['type_id'];
-			}
-
-			if(isset($lookup_functions) && is_array($lookup_functions))
-			{
-				for ($j=0;$j<count($lookup_functions);$j++)
-				{
-					$list['lookup_functions'] .= 'function ' . $lookup_functions[$j]['name'] ."\r\n";
-					$list['lookup_functions'] .= '{'."\r\n";
-					$list['lookup_functions'] .= $lookup_functions[$j]['action'] ."\r\n";
-					$list['lookup_functions'] .= '}'."\r\n";
-				}
-			}
-
-			$GLOBALS['phpgw']->session->appsession('insert_record_agreement' . !!$detail,$this->currentapp,isset($insert_record_list)?$insert_record_list:'');
-
-//html_print_r($list);
-			return $list;
-		}
-
-		function convert_attribute_save($values_attribute='')
-		{
-
-			for ($i=0;$i<count($values_attribute);$i++)
-			{
-				if($values_attribute[$i]['datatype']=='CH' && $values_attribute[$i]['value'])
-				{
-					$values_attribute[$i]['value'] = serialize($values_attribute[$i]['value']);
-				}
-				if($values_attribute[$i]['datatype']=='R' && $values_attribute[$i]['value'])
-				{
-					$values_attribute[$i]['value'] = $values_attribute[$i]['value'][0];
-				}
-
-				if($values_attribute[$i]['datatype']=='N' && $values_attribute[$i]['value'])
-				{
-					$values_attribute[$i]['value'] = str_replace(",",".",$values_attribute[$i]['value']);
-				}
-
-				if($values_attribute[$i]['datatype']=='D' && $values_attribute[$i]['value'])
-				{
-					$values_attribute[$i]['value'] = date($this->bocommon->dateformat,$this->bocommon->date_to_timestamp($values_attribute[$i]['value']));
-				}
-			}
-
-			return $values_attribute;
+			$values = $this->custom->prepare_attributes($values, 'property', '.agreement.detail');
+			return $values;
 		}
 
 		function save($values,$values_attribute='',$action='')
 		{
-
 			$values['start_date']	= $this->bocommon->date_to_timestamp($values['start_date']);
 			$values['end_date']	= $this->bocommon->date_to_timestamp($values['end_date']);
 			$values['termination_date']	= $this->bocommon->date_to_timestamp($values['termination_date']);
 
-			$values_attribute = $this->convert_attribute_save($values_attribute);
+			if(is_array($values_attribute))
+			{
+				$values_attribute = $this->custom->convert_attribute_save($values_attribute);
+			}
 
 			if ($action=='edit')
 //			if ($values['agreement_id'])
@@ -518,68 +384,20 @@
 			$this->so->delete_item($agreement_id,$activity_id);
 		}
 
-		function delete($agreement_id='',$id='',$attrib='')
+		function delete($agreement_id='')
 		{
-			if ($attrib)
-			{
-				$this->so->delete_attrib($id);
-			}
-			else
-			{
-				$this->so->delete($agreement_id);
-			}
-		}
-
-		function read_attrib($type_id='')
-		{
-			$attrib = $this->so->read_attrib(array('start' => $this->start,'query' => $this->query,'sort' => $this->sort,'order' => $this->order,
-											'allrows'=>$this->allrows));
-
-			for ($i=0; $i<count($attrib); $i++)
-			{
-				$attrib[$i]['datatype'] = $this->bocommon->translate_datatype($attrib[$i]['datatype']);
-			}
-
-			$this->total_records = $this->so->total_records;
-
-			return $attrib;
-		}
-
-		function read_single_attrib($id)
-		{
-			return $this->so->read_single_attrib($id);
-		}
-
-		function resort_attrib($data)
-		{
-			$this->so->resort_attrib($data);
-		}
-
-		function save_attrib($attrib,$action='')
-		{
-			if ($action=='edit')
-			{
-				if ($attrib['id'] != '')
-				{
-
-					$receipt = $this->so->edit_attrib($attrib);
-				}
-			}
-			else
-			{
-				$receipt = $this->so->add_attrib($attrib);
-			}
-			return $receipt;
+			$this->so->delete($agreement_id);
 		}
 
+	
 		function column_list($selected='',$allrows='')
 		{
 			if(!$selected)
 			{
-				$selected = isset($GLOBALS['phpgw_info']['user']['preferences'][$this->currentapp]["agreement_columns"])?$GLOBALS['phpgw_info']['user']['preferences'][$this->currentapp]["agreement_columns"]:'';
+				$selected = isset($GLOBALS['phpgw_info']['user']['preferences']['property']["agreement_columns"])?$GLOBALS['phpgw_info']['user']['preferences']['property']["agreement_columns"]:'';
 			}
 
-			$columns = $this->so->read_attrib(array('allrows'=>$allrows,'column_list'=>True));
+			$columns = $this->custom->get_attribs('property','.agreement', 0, '','','',true);
 
 			$column_list=$this->bocommon->select_multi_list($selected,$columns);
 
