@@ -72,14 +72,14 @@
 		{
 			if($currentapp)
 			{
-				$this->currentapp	= $currentapp;
+			//	$this->currentapp	= $currentapp;
 			}
 			else
 			{
-				$this->currentapp	= 'property';			
+			//	$this->currentapp	= 'property';			
 			}
 
-			$this->socommon			= CreateObject('property.socommon',$this->currentapp);
+			$this->socommon			= CreateObject('property.socommon','property');
 			$this->account		= $GLOBALS['phpgw_info']['user']['account_id'];
 
 			if (!isset($GLOBALS['phpgw']->asyncservice))
@@ -534,9 +534,6 @@
 		{
 //_debug_array($data);
 
-			$contacts	= CreateObject('property.soactor');
-			$contacts->role='vendor';
-
 			if( isset($data['type']) && $data['type']=='view')
 			{
 				$GLOBALS['phpgw']->xslttpl->add_file(array('vendor_view'));
@@ -549,9 +546,14 @@
 			$vendor['value_vendor_id']		= $data['vendor_id'];
 			$vendor['value_vendor_name']		= $data['vendor_name'];
 
-			if($data['vendor_id'] && !$data['vendor_name'])
+			if(isset($data['vendor_id']) && $data['vendor_id'] && !$data['vendor_name'])
 			{
-				$vendor_data	= $contacts->read_single(array('actor_id'=>$data['vendor_id']));
+				$contacts	= CreateObject('property.soactor');
+				$contacts->role='vendor';
+				$custom 		= createObject('phpgwapi.custom_fields');	
+				$vendor_data['attributes'] = $custom->get_attribs('property','.vendor', 0, '', 'ASC', 'attrib_sort', true, true);
+
+				$vendor_data	= $contacts->read_single($data['vendor_id'],$vendor_data);
 				if(is_array($vendor_data))
 				{
 					foreach($vendor_data['attributes'] as $attribute)
@@ -563,14 +565,14 @@
 						}
 					}
 				}
+				unset($contacts);
 			}
 
-			$vendor['vendor_link']			= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uilookup.vendor'));
+			$vendor['vendor_link']			= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uilookup.vendor'));
 			$vendor['lang_vendor']			= lang('Vendor');
 			$vendor['lang_select_vendor_help']	= lang('Klick this link to select vendor');
 			$vendor['lang_vendor_name']		= lang('Vendor Name');
 
-			unset($contacts);
 //_debug_array($vendor);
 			return $vendor;
 		}
@@ -589,7 +591,7 @@
 			$tenant['value_tenant_id']			= $data['tenant_id'];
 			$tenant['value_first_name']			= $data['first_name'];
 			$tenant['value_last_name']			= $data['last_name'];
-			$tenant['tenant_link']				= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uilookup.tenant'));
+			$tenant['tenant_link']				= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uilookup.tenant'));
 			if($data['role']=='customer')
 			{
 				$tenant['lang_select_tenant_help']		= lang('Klick this link to select customer');
@@ -607,7 +609,9 @@
 			{
 				$tenant_object	= CreateObject('property.soactor');
 				$tenant_object->role = 'tenant';
-				$tenant_data	= $tenant_object->read_single(array('actor_id' => $data['tenant_id']));
+				$custom 		= createObject('phpgwapi.custom_fields');
+				$tenant_data['attributes'] = $custom->get_attribs('property','.tenant', 0, '', 'ASC', 'attrib_sort', true, true);
+				$tenant_data	= $tenant_object->read_single($data['tenant_id'],$tenant_data);
 				if(is_array($tenant_data['attributes']))
 				{
 //_debug_array($tenant_data);
@@ -643,7 +647,7 @@
 
 			$b_account['value_b_account_id']		= $data['b_account_id'];
 			$b_account['value_b_account_name']		= $data['b_account_name'];
-			$b_account['b_account_link']			= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uilookup.b_account'));
+			$b_account['b_account_link']			= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uilookup.b_account'));
 			$b_account['lang_select_b_account_help']	= lang('Klick this link to select budget account');
 			$b_account['lang_b_account']			= lang('Budget account');
 			if($data['b_account_id'] && !$data['b_account_name'])
@@ -732,37 +736,26 @@
 		}
 
 
-		function select_multi_list_2($selected='',$input_list,$input_type='')
+		function select_multi_list_2($selected='',$list,$input_type='')
 		{
-			$j=0;
-			if (isset($input_list) AND is_array($input_list))
+			if (isset($list) AND is_array($list))
 			{
-				foreach($input_list as $entry)
+				foreach($list as &$choice)
 				{
-					$output_list[$j]['id'] = $entry['id'];
-					$output_list[$j]['value'] = $entry['value'];
-					$output_list[$j]['input_type'] = $input_type;
-
-					for ($i=0;$i<count($selected);$i++)
+					$choice['input_type'] = $input_type;
+					if(isset($selected) && is_array($selected))
 					{
-						if($selected[$i] == $entry['id'])
+						foreach ($selected as &$sel)
 						{
-							$output_list[$j]['checked'] = 'checked';
+							if($sel == $choice['id'])
+							{
+								$choice['checked'] = 'checked';
+							}
 						}
 					}
-					$j++;
 				}
 			}
-
-/*			for ($i=0;$i<count($output_list);$i++)
-			{
-				if ($output_list[$i]['checked'] != 'checked')
-				{
-					unset($output_list[$i]['checked']);
-				}
-			}
-*/
-			return $output_list;
+			return $list;
 		}
 
 		function translate_datatype($datatype)
@@ -1400,15 +1393,15 @@
 		{
 			if($type=='tts'):
 			{
-				$link = array('menuaction' => $this->currentapp.'.uitts.view');
+				$link = array('menuaction' => 'property.uitts.view');
 			}
 			elseif($type=='request'):
 			{
-				$link = array('menuaction' => $this->currentapp.'.uirequest.view');
+				$link = array('menuaction' => 'property.uirequest.view');
 			}
 			elseif($type=='project'):
 			{
-				$link = array('menuaction' => $this->currentapp.'.uiproject.view');
+				$link = array('menuaction' => 'property.uiproject.view');
 			}
 			elseif(substr($type,0,6)=='entity'):
 			{
@@ -1417,7 +1410,7 @@
 				$cat_id		= $type[2];
 				$link =	array
 				(
-					'menuaction'	=> $this->currentapp.'.uientity.view',
+					'menuaction'	=> 'property.uientity.view',
 					'entity_id'	=> $entity_id,
 					'cat_id'	=> $cat_id
 				);
@@ -1455,24 +1448,42 @@
 			{	
 				for ($i=0;$i<count($values['attributes']);$i++)
 				{
-					if($values['attributes'][$i]['attrib_id'] == $attribute['attrib_id'])
+					if($values['attributes'][$i]['id'] == $attribute['attrib_id'])
 					{
-						$values['attributes'][$i]['value'] = $attribute['value'];
-
-						if(isset($values['attributes'][$i]['choice']) && is_array($values['attributes'][$i]['choice']))
+						if(isset($attribute['value']))
 						{
-							for ($j=0;$j<count($values['attributes'][$i]['choice']);$j++)
+							if(is_array($attribute['value']))
 							{
-								if($values['attributes'][$i]['choice'][$j]['id'] == $attribute['value'])
+								foreach($values['attributes'][$i]['choice'] as &$choice)
 								{
-									$values['attributes'][$i]['choice'][$j]['checked'] = 'checked';	
+									foreach ($attribute['value'] as &$selected)
+									{
+										if($selected == $choice['id'])
+										{
+											$choice['checked'] = 'checked';
+										}
+									}
 								}
 							}
+							else if(isset($values['attributes'][$i]['choice']) && is_array($values['attributes'][$i]['choice']))
+							{
+
+								foreach ($values['attributes'][$i]['choice'] as &$choice)
+								{
+									if($choice['id'] == $attribute['value'])
+									{
+										$choice['checked'] = 'checked';	
+									}
+								}
+							}
+							else
+							{
+								$values['attributes'][$i]['value'] = $attribute['value'];
+							}
 						}
 					}
 				}
 			}
-			
 			return $values;
 		}
 		
