@@ -71,7 +71,7 @@
 
 		function property_bolookup($session=False)
 		{
-			$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
+		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->so 		= CreateObject('property.solookup');
 			$this->solocation = CreateObject('property.solocation');
 
