@@ -198,7 +198,7 @@
 					'record_id'  => $this->db->f('history_record_id'),
 					'owner'      => $GLOBALS['phpgw']->accounts->id2name($this->db->f('history_owner')),
 //					'status'     => lang($this->types[$this->db->f('history_status')]),
-					'status'     => ereg_replace(' ','',$this->db->f('history_status')),
+					'status'     => preg_replace('/ /','',$this->db->f('history_status')),
 					'new_value'  => $this->db->f('history_new_value'),
 					'datetime'   => $this->db->from_timestamp($this->db->f('history_timestamp'))
 				);
