@@ -36,7 +36,7 @@
 	{
 		function property_sob_account()
 		{
-			$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
+		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->account	= 	$GLOBALS['phpgw_info']['user']['account_id'];
 			$this->bocommon	= CreateObject('property.bocommon');
 			$this->db           	= $this->bocommon->new_db();
@@ -76,8 +76,8 @@
 
 			if($query)
 			{
-				$query = ereg_replace("'",'',$query);
-				$query = ereg_replace('"','',$query);
+				$query = preg_replace("/'/",'',$query);
+				$query = preg_replace('/"/','',$query);
 
 				$querymethod = " where id $this->like '%$query%' or descr $this->like '%$query%'";
 			}
