@@ -36,7 +36,7 @@
 	{
 		function property_sobudget()
 		{
-			$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
+		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->account		= $GLOBALS['phpgw_info']['user']['account_id'];
 			$this->bocommon	= CreateObject('property.bocommon');
 			$this->db           	= $this->bocommon->new_db();
@@ -103,8 +103,8 @@
 
 			if($query)
 			{
-				$query = ereg_replace("'",'',$query);
-				$query = ereg_replace('"','',$query);
+				$query = preg_replace("/'/",'',$query);
+				$query = preg_replace('/"/','',$query);
 
 				$querymethod = " $where ( descr $this->like '%$query%')";
 			}
@@ -198,8 +198,8 @@
 
 			if($query)
 			{
-				$query = ereg_replace("'",'',$query);
-				$query = ereg_replace('"','',$query);
+				$query = preg_replace("/'/",'',$query);
+				$query = preg_replace('/"/','',$query);
 
 			//	$querymethod = " $where ( descr $this->like '%$query%')";
 			}
@@ -270,6 +270,8 @@
 			if($this->db->next_record())
 			{
 				$receipt['error'][] = array('msg'=>lang('budget %1 already saved',$this->db->f('id')));
+				$receipt['budget_id']= $this->db->f('id');
+				return $receipt;
 			}
 
 			if(!$receipt['error'])
@@ -474,8 +476,8 @@
 			$querymethod = '';
 			if($query)
 			{
-				$query = ereg_replace("'",'',$query);
-				$query = ereg_replace('"','',$query);
+				$query = preg_replace("/'/",'',$query);
+				$query = preg_replace('/"/','',$query);
 
 			//	$querymethod = " $where ( descr $this->like '%$query%')";
 			}
@@ -793,7 +795,7 @@
 				
 			}
 			
-			$this->db->query("DELETE FROM fm_budget WHERE year ='" . $basis['year'] . "'  AND b_account_id in (" . implode(",",$b_account) . ") AND revision = '" . $basis['revision'] . "' AND district_id='" . $basis['district_id'] . "'" ,__LINE__,__FILE__);
+			$this->db->query("DELETE FROM fm_budget WHERE year ='" . $basis['year'] . "'  AND b_account_id in ('" . implode("','",$b_account) . "') AND revision = '" . $basis['revision'] . "' AND district_id='" . $basis['district_id'] . "'" ,__LINE__,__FILE__);
 			$this->db->query('DELETE FROM fm_budget_basis WHERE id=' . intval($basis_id),__LINE__,__FILE__);
 			$this->db->transaction_commit();
 		}
@@ -845,7 +847,7 @@
 				$sql = "DELETE FROM fm_budget WHERE year = " . (int)$basis['year']
 					. " AND district_id = " . (int)$basis['district_id']
 					. " AND revision = " . (int)$basis['revision']
-					. " AND b_account_id in (" . implode(",",$b_account) . ")";
+					. " AND b_account_id in ('" . implode("','",$b_account) . "')";
 					
 				$this->db->query($sql,__LINE__,__FILE__);
 				
@@ -892,6 +894,7 @@
 				}
 			}
 			$this->db->transaction_commit();
+			return $receipt;
 		}
 	}
 ?>
