@@ -36,7 +36,7 @@
 	{
 		function property_sowo_hour()
 		{
-			$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
+		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->account		= $GLOBALS['phpgw_info']['user']['account_id'];
 			$this->bocommon	= CreateObject('property.bocommon');
 			$this->db           	= $this->bocommon->new_db();
@@ -684,7 +684,7 @@
 		{
 			$vendor_id=(int)$vendor_id;
 
-			$this->db->query("select column_name from fm_vendor_attribute WHERE datatype='email'",__LINE__,__FILE__);
+			$this->db->query("select column_name from phpgw_cust_attribute WHERE appname='property' AND location = '.vendor' AND datatype='email'",__LINE__,__FILE__);
 			while ($this->db->next_record())
 			{
 				$this->db2->query("select " . $this->db->f('column_name') . " from fm_vendor where id=$vendor_id",__LINE__,__FILE__);
