@@ -52,7 +52,7 @@
 		{
 
 			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-			$this->currentapp		= $GLOBALS['phpgw_info']['flags']['currentapp'];
+		//	$this->currentapp		= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->bo       		= CreateObject('property.boXport',True);
 			$this->invoice  		= CreateObject('property.boinvoice');
 			$this->bocommon  		= CreateObject('property.bocommon');
@@ -82,7 +82,7 @@
 		{
 			if(!$this->acl_add)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>2, 'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>2, 'acl_location'=> $this->acl_location));
 			}
 
 			$receipt = $GLOBALS['phpgw']->session->appsession('session_data','import_receipt');
@@ -251,7 +251,7 @@
 						unset($payment_date);
 						unset($conv_type);
 						unset($auto_tax);
-//						$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uiXport.import'));
+//						$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uiXport.import'));
 					}
 					else
 					{
@@ -266,7 +266,7 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiXport.import',
+				'menuaction'	=> 'property.uiXport.import',
 				'sub'		=> $sub
 			);
 
@@ -294,10 +294,10 @@
 				'lang_datetitle'				=> lang('Select date'),
 
 				'form_action'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'cancel_action'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvoice.index', 'sub'=> $sub)),
+				'cancel_action'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.index', 'sub'=> $sub)),
 				'lang_cancel'					=> lang('Cancel'),
 				'lang_cancel_statustext'			=> lang('cancel the import'),
-				'action_url'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=>  $this->currentapp .'.uiXport.import')),
+				'action_url'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=>  'property' .'.uiXport.import')),
 				'tsvfilename'					=> '',
 
 				'lang_debug'					=> lang('Debug output in browser'),
@@ -318,7 +318,7 @@
 				'lang_kid_nr_statustext'			=> lang('Enter Kid nr'),
 
 				'lang_vendor'					=> lang('Vendor'),
-				'addressbook_link'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uilookup.vendor')),
+				'addressbook_link'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uilookup.vendor')),
 
 				'lang_invoice_date_statustext'			=> lang('Enter the invoice date'),
 				'lang_num_days_statustext'			=> lang('Enter the payment date or the payment delay'),
@@ -393,7 +393,7 @@
 			$appname	= lang('Invoice');
 			$function_msg	= lang('Import from CSV');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('import' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
@@ -432,13 +432,13 @@
 
 			$link_data_add = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiXport.import',
+				'menuaction'	=> 'property.uiXport.import',
 				'convert'	=> 'true'
 			);
 
 			$link_data_cancel = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiXport.import',
+				'menuaction'	=> 'property.uiXport.import',
 				'cancel'	=> True
 
 			);
@@ -504,7 +504,7 @@
 			$appname						= lang('Invoice');
 			$function_msg	= lang('Debug');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('debug' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
@@ -514,7 +514,7 @@
 		{
 			if(!$this->acl_manage)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>16, 'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>16, 'acl_location'=> $this->acl_location));
 			}
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('invoice','menu',
@@ -542,7 +542,7 @@
 						$GLOBALS['phpgw_info']['flags']['xslt_app'] = False;
 						$GLOBALS['phpgw_info']['flags']['noframework'] = True;
 						echo '<pre>' . $receipt['message'][0]['msg'] . '</pre>';
-						echo '&nbsp<a href="'.$GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiXport.export')) . '">' . lang('Back') . '</a>';
+						echo '&nbsp<a href="'.$GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiXport.export')) . '">' . lang('Back') . '</a>';
 					}
 				}
 				endif;
@@ -555,7 +555,7 @@
 
 			$link_data = array
 			(
-				'menuaction'		=> $this->currentapp.'.uiXport.export',
+				'menuaction'		=> 'property.uiXport.export',
 				'invoice_id'		=> $invoice_id,
 				'sub'			=> $sub);
 
@@ -579,7 +579,7 @@
 				'lang_conv_statustext'			=> lang('Select conversion'),
 
 				'lang_rollback_file'			=> lang('Roll back'),
-				'link_rollback_file'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiXport.rollback')),
+				'link_rollback_file'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiXport.rollback')),
 
 				'lang_export_to_file'			=> lang('Export to file'),
 				'value_debug'				=> $values['debug'],
@@ -597,7 +597,7 @@
 			$appname	= lang('Invoice');
 			$function_msg	= lang('Export invoice');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('export' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
@@ -607,7 +607,7 @@
 		{
 			if(!$this->acl_manage)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>16, 'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>16, 'acl_location'=> $this->acl_location));
 			}
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('invoice','menu',
@@ -641,7 +641,7 @@
 				$date = $GLOBALS['phpgw']->common->show_date(mktime(0,0,0,date("m"),date("d"),date("Y")),$GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
 			}
 
-			$link_data = array('menuaction'	=> $this->currentapp.'.uiXport.rollback');
+			$link_data = array('menuaction'	=> 'property.uiXport.rollback');
 
 			$dateformat = strtolower($GLOBALS['phpgw_info']['user']['preferences']['common']['dateformat']);
 			$sep = '/';
@@ -697,7 +697,7 @@
 			$appname		= lang('Invoice');
 			$function_msg		= lang('Rollback invoice');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('rollback' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
