@@ -48,8 +48,6 @@
 			'view'   		=> True,
 			'edit'   		=> True,
 			'delete' 		=> True,
-			'list_attribute'	=> True,
-			'edit_attrib'		=> True,
 			'columns'		=> True,
 			'edit_item'		=> True,
 			'view_item'		=> True,
@@ -61,7 +59,7 @@
 		function property_uiagreement()
 		{
 			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-			$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
+		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->nextmatchs	= CreateObject('phpgwapi.nextmatchs');
 			$this->account		= $GLOBALS['phpgw_info']['user']['account_id'];
 
@@ -127,7 +125,7 @@
 
 				$GLOBALS['phpgw']->preferences->account_id=$this->account;
 				$GLOBALS['phpgw']->preferences->read_repository();
-				$GLOBALS['phpgw']->preferences->add($this->currentapp,'agreement_columns',$values['columns'],'user');
+				$GLOBALS['phpgw']->preferences->add('property','agreement_columns',$values['columns'],'user');
 				$GLOBALS['phpgw']->preferences->save_repository();
 
 				$receipt['message'][] = array('msg' => lang('columns is updated'));
@@ -137,7 +135,7 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiagreement.columns',
+				'menuaction'	=> 'property.uiagreement.columns',
 				'role'		=> $this->role
 			);
 
@@ -168,7 +166,7 @@
 
 			if(!$this->acl_read)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
 			}
 
 			$file_name	= urldecode(phpgw::get_var('file_name'));
@@ -210,7 +208,7 @@
 
 			if(!$this->acl_read)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
 			}
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('agreement',
@@ -247,19 +245,19 @@
 					{
 						$content[$j]['row'][$i]['statustext']		= lang('view the entity');
 						$content[$j]['row'][$i]['text']			= lang('view');
-						$content[$j]['row'][$i++]['link']		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.view','id'=> $entry['id'], 'role'=> $this->role));
+						$content[$j]['row'][$i++]['link']		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiagreement.view','id'=> $entry['id'], 'role'=> $this->role));
 					}
 					if($this->acl_edit)
 					{
 						$content[$j]['row'][$i]['statustext']		= lang('edit the agreement');
 						$content[$j]['row'][$i]['text']			= lang('edit');
-						$content[$j]['row'][$i++]['link']		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.edit','id'=> $entry['id'], 'role'=> $this->role));
+						$content[$j]['row'][$i++]['link']		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiagreement.edit','id'=> $entry['id'], 'role'=> $this->role));
 					}
 					if($this->acl_delete)
 					{
 						$content[$j]['row'][$i]['statustext']		= lang('delete the agreement');
 						$content[$j]['row'][$i]['text']			= lang('delete');
-						$content[$j]['row'][$i++]['link']		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.delete', 'agreement_id'=> $entry['id'], 'role'=> $this->role));
+						$content[$j]['row'][$i++]['link']		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiagreement.delete', 'agreement_id'=> $entry['id'], 'role'=> $this->role));
 					}
 
 					$j++;
@@ -282,7 +280,7 @@
 								'sort'	=> $this->sort,
 								'var'	=> $uicols['name'][$i],
 								'order'	=> $this->order,
-								'extra'	=> array('menuaction'	=> $this->currentapp.'.uiagreement.index',
+								'extra'	=> array('menuaction'	=> 'property.uiagreement.index',
 													'query'		=> $this->query,
 													'role'		=> $this->role,
 													'member_id'	=> $this->member_id,
@@ -322,13 +320,13 @@
 				(
 					'lang_add'		=> lang('add'),
 					'lang_add_statustext'	=> lang('add an agreement'),
-					'add_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.edit', 'role'=> $this->role))
+					'add_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiagreement.edit', 'role'=> $this->role))
 				);
 			}
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiagreement.index',
+				'menuaction'	=> 'property.uiagreement.index',
 				'sort'		=>$this->sort,
 				'order'		=>$this->order,
 				'cat_id'	=>$this->cat_id,
@@ -351,13 +349,13 @@
 
 			$link_columns = array
 			(
-				'menuaction' 	=> $this->currentapp.'.uiagreement.columns',
+				'menuaction' 	=> 'property.uiagreement.columns',
 				'role'		=> $this->role
 			);
 
 			$member_of_data	= $this->cats->formatted_xslt_list(array('selected' => $this->member_id,'globals' => True,'link_data' =>$link_data));
 
-			$GLOBALS['phpgw']->js->validate_file('overlib','overlib',$this->currentapp);
+			$GLOBALS['phpgw']->js->validate_file('overlib','overlib','property');
 
 			$data = array
 			(
@@ -434,19 +432,19 @@
 					{
 						$content[$j]['row'][$i]['statustext']		= lang('view the entity');
 						$content[$j]['row'][$i]['text']			= lang('view');
-						$content[$j]['row'][$i++]['link']		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.view_item', 'agreement_id'=> $entry['agreement_id'], 'id'=> $entry['id']));
+						$content[$j]['row'][$i++]['link']		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiagreement.view_item', 'agreement_id'=> $entry['agreement_id'], 'id'=> $entry['id']));
 					}
 					if($this->acl_edit && !$edit_item && !$view_only)
 					{
 						$content[$j]['row'][$i]['statustext']		= lang('edit the agreement');
 						$content[$j]['row'][$i]['text']			= lang('edit');
-						$content[$j]['row'][$i++]['link']		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.edit_item', 'agreement_id'=> $entry['agreement_id'], 'id'=> $entry['id']));
+						$content[$j]['row'][$i++]['link']		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiagreement.edit_item', 'agreement_id'=> $entry['agreement_id'], 'id'=> $entry['id']));
 					}
 					if($this->acl_delete && !$edit_item && !$view_only)
 					{
 						$content[$j]['row'][$i]['statustext']		= lang('delete this item');
 						$content[$j]['row'][$i]['text']			= lang('delete');
-						$content[$j]['row'][$i++]['link']		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.edit','delete_item'=>1, 'agreement_id'=> $entry['agreement_id'], 'activity_id'=> $entry['id']));
+						$content[$j]['row'][$i++]['link']		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiagreement.edit','delete_item'=>1, 'agreement_id'=> $entry['agreement_id'], 'activity_id'=> $entry['id']));
 					}
 
 					$j++;
@@ -500,7 +498,7 @@
 		{
 			if(!$this->acl_add)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>2, 'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>2, 'acl_location'=> $this->acl_location));
 			}
 
 
@@ -521,12 +519,12 @@
 					if ($values['save'])
 					{
 						$GLOBALS['phpgw']->session->appsession('session_data','agreement_receipt',$receipt);
-						$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.edit', 'id'=> $agreement_id));
+						$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uiagreement.edit', 'id'=> $agreement_id));
 					}
 				}
 				else
 				{
-					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.edit', 'id'=> $agreement_id));
+					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uiagreement.edit', 'id'=> $agreement_id));
 
 				}
 			}
@@ -547,7 +545,7 @@
 				}
 			}
 
-			$GLOBALS['phpgw']->js->validate_file('core','check',$this->currentapp);
+			$GLOBALS['phpgw']->js->validate_file('core','check','property');
 
 			$data = array
 			(
@@ -558,8 +556,8 @@
 				'lang_descr'				=> lang('descr'),
 				'value_descr'				=> $agreement['descr'],
 				'lang_select_all'			=> lang('Select All'),
-				'img_check'				=> $GLOBALS['phpgw']->common->get_image_path($this->currentapp).'/check.png',
-				'add_action'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.add_activity', 'group_id'=> $group_id, 'agreement_id'=> $agreement_id)),
+				'img_check'				=> $GLOBALS['phpgw']->common->get_image_path('property').'/check.png',
+				'add_action'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiagreement.add_activity', 'group_id'=> $group_id, 'agreement_id'=> $agreement_id)),
 				'agreement_id'				=> $agreement_id,
 				'table_header'				=> $table_header,
 				'values'				=> $content,
@@ -582,7 +580,7 @@
 		{
 			if(!$this->acl_add)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>2, 'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>2, 'acl_location'=> $this->acl_location));
 			}
 
 
@@ -591,7 +589,7 @@
 			$delete_item	= phpgw::get_var('delete_item', 'bool');
 			$activity_id	= phpgw::get_var('activity_id', 'int');
 
-			$config		= CreateObject('phpgwapi.config',$this->currentapp);
+			$config		= CreateObject('phpgwapi.config','property');
 			$boalarm	= CreateObject('property.boalarm');
 			$receipt 	= array();
 
@@ -602,7 +600,7 @@
 
 			$values_attribute  = phpgw::get_var('values_attribute');
 
-			$insert_record_agreement = $GLOBALS['phpgw']->session->appsession('insert_record_agreement',$this->currentapp);
+			$insert_record_agreement = $GLOBALS['phpgw']->session->appsession('insert_record_values.agreement','property');
 
 //_debug_array($insert_record_agreement);
 			if(isset($insert_record_agreement) && is_array($insert_record_agreement))
@@ -697,7 +695,7 @@
 						if ($values['save'])
 						{
 							$GLOBALS['phpgw']->session->appsession('session_data','agreement_receipt',$receipt);
-							$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.index', 'role'=> $this->role));
+							$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uiagreement.index', 'role'=> $this->role));
 						}
 					}
 				}
@@ -749,7 +747,7 @@
 				}
 				else if ((!isset($values['save']) || !$values['save']) && (!isset($values['apply']) || !$values['apply']) && (!isset($values['update']) || !$values['update']))
 				{
-					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.index', 'role'=> $this->role));
+					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uiagreement.index', 'role'=> $this->role));
 				}
 			}
 
@@ -784,19 +782,19 @@
 						{
 							$content[$j]['lang_view_statustext']	= lang('view the entity');
 							$content[$j]['text_view']		= lang('view');
-							$content[$j]['link_view']		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.view_item', 'agreement_id'=> $id, 'id'=> $content[$j]['activity_id']));
+							$content[$j]['link_view']		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiagreement.view_item', 'agreement_id'=> $id, 'id'=> $content[$j]['activity_id']));
 						}
 						if($this->acl_edit && (!isset($edit_item) || !$edit_item) && (!isset($view_only) || !$view_only))
 						{
 							$content[$j]['lang_edit_statustext']	= lang('edit the agreement');
 							$content[$j]['text_edit']		= lang('edit');
-							$content[$j]['link_edit']		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.edit_item', 'agreement_id'=> $id, 'id'=> $content[$j]['activity_id']));
+							$content[$j]['link_edit']		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiagreement.edit_item', 'agreement_id'=> $id, 'id'=> $content[$j]['activity_id']));
 						}
 						if($this->acl_delete && (!isset($edit_item) || !$edit_item) && (!isset($view_only) || !$view_only))
 						{
 							$content[$j]['lang_delete_statustext']	= lang('delete this item');
 							$content[$j]['text_delete']		= lang('delete');
-							$content[$j]['link_delete']		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.edit', 'delete_item'=>1, 'id'=> $id, 'activity_id'=> $content[$j]['activity_id']));
+							$content[$j]['link_delete']		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiagreement.edit', 'delete_item'=>1, 'id'=> $id, 'activity_id'=> $content[$j]['activity_id']));
 						}
 
 						$content[$j]['acl_manage']			= $this->acl_manage;
@@ -877,7 +875,7 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiagreement.edit',
+				'menuaction'	=> 'property.uiagreement.edit',
 				'sort'		=>$this->sort,
 				'order'		=>$this->order,
 				'id'		=> $id,
@@ -939,13 +937,13 @@
 			(
 				'lang_add'				=> lang('add detail'),
 				'lang_add_standardtext'	=> lang('add an item to the details'),
-				'add_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.add_activity', 'agreement_id'=> $id, 'group_id'=> $agreement['group_id']))
+				'add_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiagreement.add_activity', 'agreement_id'=> $id, 'group_id'=> $agreement['group_id']))
 			);
 
 
 			$link_file_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiagreement.view_file',
+				'menuaction'	=> 'property.uiagreement.view_file',
 				'id'		=>$id
 			);
 
@@ -960,7 +958,7 @@
 
 			$link_excel = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiagreement.excel',
+				'menuaction'	=> 'property.uiagreement.excel',
 				'id'		=>$id,
 				'allrows'	=>$this->allrows
 			);
@@ -975,9 +973,9 @@
 				$record_limit	= $this->bo->total_records;
 			}
 
-			$GLOBALS['phpgw']->js->validate_file('overlib','overlib',$this->currentapp);
-			$GLOBALS['phpgw']->js->validate_file('core','check',$this->currentapp);
-			$GLOBALS['phpgw']->js->validate_file('dateformat','dateformat',$this->currentapp);
+			$GLOBALS['phpgw']->js->validate_file('overlib','overlib','property');
+			$GLOBALS['phpgw']->js->validate_file('core','check','property');
+			$GLOBALS['phpgw']->js->validate_file('dateformat','dateformat','property');
 
 			$data = array
 			(
@@ -1064,9 +1062,9 @@
 				'values'								=> $content,
 				'table_header'							=> $table_header,
 				'table_update'							=> $table_update,
-				'update_action'							=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.edit', 'id'=> $id)),
+				'update_action'							=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiagreement.edit', 'id'=> $id)),
 				'lang_select_all'						=> lang('Select All'),
-				'img_check'								=> $GLOBALS['phpgw']->common->get_image_path($this->currentapp).'/check.png',
+				'img_check'								=> $GLOBALS['phpgw']->common->get_image_path('property').'/check.png',
 				'set_column'							=> $set_column,
 
 				'lang_agreement_group'					=> lang('Agreement group'),
@@ -1077,7 +1075,8 @@
 				'status_list'							=> $this->bo->select_status_list('select',$agreement['status']),
 				'status_name'							=> 'values[status]',
 				'lang_no_status'						=> lang('Select status'),
-
+				'textareacols'							=> isset($GLOBALS['phpgw_info']['user']['preferences']['property']['textareacols']) && $GLOBALS['phpgw_info']['user']['preferences']['property']['textareacols'] ? $GLOBALS['phpgw_info']['user']['preferences']['property']['textareacols'] : 40,
+				'textarearows'							=> isset($GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows']) && $GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows'] ? $GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows'] : 6
 			);
 
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('agreement') . ': ' . ($id?lang('edit') . ' ' . lang($this->role):lang('add') . ' ' . lang($this->role));
@@ -1098,7 +1097,7 @@
 		{
 			if(!$this->acl_add)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>2, 'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>2, 'acl_location'=> $this->acl_location));
 			}
 
 
@@ -1133,7 +1132,7 @@
 						if ($values['save'])
 						{
 							$GLOBALS['phpgw']->session->appsession('session_data','agreement_receipt',$receipt);
-							$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.edit', 'id'=> $agreement_id));
+							$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uiagreement.edit', 'id'=> $agreement_id));
 						}
 					}
 				}
@@ -1156,7 +1155,7 @@
 				}
 				elseif (!$values['save'] && !$values['apply'] && !$values['update']):
 				{
-					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.edit', 'id'=> $agreement_id));
+					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uiagreement.edit', 'id'=> $agreement_id));
 				}
 				endif;
 			}
@@ -1166,7 +1165,7 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiagreement.edit_item',
+				'menuaction'	=> 'property.uiagreement.edit_item',
 				'agreement_id'	=> $agreement_id,
 				'id'		=> $id,
 				'role'		=> $this->role
@@ -1212,7 +1211,7 @@
 			(
 				'lang_add'				=> lang('add detail'),
 				'lang_add_standardtext'	=> lang('add an item to the details'),
-				'add_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.edit_item', 'agreement_id'=> $agreement_id))
+				'add_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiagreement.edit_item', 'agreement_id'=> $agreement_id))
 			);
 
 			if($id)
@@ -1242,8 +1241,8 @@
 				'lang_update_statustext'	=> lang('update selected investments')
 			);
 
-			$GLOBALS['phpgw']->js->validate_file('core','check',$this->currentapp);
-			$GLOBALS['phpgw']->js->validate_file('dateformat','dateformat',$this->currentapp);
+			$GLOBALS['phpgw']->js->validate_file('core','check','property');
+			$GLOBALS['phpgw']->js->validate_file('dateformat','dateformat','property');
 
 			$data = array
 			(
@@ -1281,9 +1280,9 @@
 				'table_header'				=> $table_header,
 				'acl_manage'				=> $this->acl_manage,
 				'table_update'				=> $table_update,
-				'update_action'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.edit_item', 'agreement_id'=> $agreement_id, 'id'=> $id)),
+				'update_action'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiagreement.edit_item', 'agreement_id'=> $agreement_id, 'id'=> $id)),
 				'lang_select_all'			=> lang('Select All'),
-				'img_check'				=> $GLOBALS['phpgw']->common->get_image_path($this->currentapp).'/check.png',
+				'img_check'				=> $GLOBALS['phpgw']->common->get_image_path('property').'/check.png',
 
 				'lang_m_cost'				=> lang('Material cost'),
 				'lang_m_cost_statustext'		=> lang('Material cost'),
@@ -1299,8 +1298,9 @@
 				'set_column'				=> $set_column,
 				'lang_delete_last'			=> lang('delete last index'),
 				'lang_delete_last_statustext'		=> lang('delete the last index'),
-				'delete_action'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.edit_item', 'delete_last'=>1, 'agreement_id'=> $agreement_id, 'id'=> $id)),
-
+				'delete_action'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiagreement.edit_item', 'delete_last'=>1, 'agreement_id'=> $agreement_id, 'id'=> $id)),
+				'textareacols'				=> isset($GLOBALS['phpgw_info']['user']['preferences']['property']['textareacols']) && $GLOBALS['phpgw_info']['user']['preferences']['property']['textareacols'] ? $GLOBALS['phpgw_info']['user']['preferences']['property']['textareacols'] : 40,
+				'textarearows'				=> isset($GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows']) && $GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows'] ? $GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows'] : 6
 			);
 
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('agreement') . ': ' . ($values['id']?lang('edit item') . ' ' . $agreement['name']:lang('add item') . ' ' . $agreement['name']);
@@ -1313,7 +1313,7 @@
 		{
 			if(!$this->acl_read)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
 			}
 
 			$agreement_id	= phpgw::get_var('agreement_id', 'int');
@@ -1326,7 +1326,7 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiagreement.edit',
+				'menuaction'	=> 'property.uiagreement.edit',
 				'id'		=> $agreement_id
 			);
 
@@ -1350,7 +1350,7 @@
 			$content	= $list['content'];
 			$table_header=$list['table_header'];
 
-			$GLOBALS['phpgw']->js->validate_file('core','check',$this->currentapp);
+			$GLOBALS['phpgw']->js->validate_file('core','check','property');
 
 			$data = array
 			(
@@ -1385,6 +1385,8 @@
 				'lang_total_cost'			=> lang('Total cost'),
 				'value_total_cost'			=> $values['total_cost'],
 				'set_column'				=> $set_column,
+				'textareacols'				=> isset($GLOBALS['phpgw_info']['user']['preferences']['property']['textareacols']) && $GLOBALS['phpgw_info']['user']['preferences']['property']['textareacols'] ? $GLOBALS['phpgw_info']['user']['preferences']['property']['textareacols'] : 40,
+				'textarearows'				=> isset($GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows']) && $GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows'] ? $GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows'] : 6
 			);
 
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('agreement') . ': ' . lang('view item') . ' ' . $agreement['name'];
@@ -1398,33 +1400,22 @@
 		{
 			if(!$this->acl_delete)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>8, 'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>8, 'acl_location'=> $this->acl_location));
 			}
 
-			$attrib		= phpgw::get_var('attrib');
-			$id		= phpgw::get_var('id', 'int');
 			$agreement_id	= phpgw::get_var('agreement_id', 'int');
 			$delete		= phpgw::get_var('delete', 'bool', 'POST');
 			$confirm	= phpgw::get_var('confirm', 'bool', 'POST');
 
-
-			if($attrib)
-			{
-				$function='list_attribute';
-			}
-			else
-			{
-				$function='index';
-			}
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiagreement.'.$function,
+				'menuaction'	=> 'property.uiagreement.index',
 				'role'		=> $this->role
 			);
 
 			if (phpgw::get_var('confirm', 'bool', 'POST'))
 			{
-				$this->bo->delete($agreement_id,$id,$attrib);
+				$this->bo->delete($agreement_id);
 				$GLOBALS['phpgw']->redirect_link('/index.php',$link_data);
 			}
 
@@ -1433,7 +1424,7 @@
 			$data = array
 			(
 				'done_action'			=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'delete_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.delete', 'agreement_id'=> $agreement_id, 'id'=> $id, 'attrib'=> $attrib, 'role'=> $this->role)),
+				'delete_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiagreement.delete', 'agreement_id'=> $agreement_id, 'role'=> $this->role)),
 				'lang_confirm_msg'		=> lang('do you really want to delete this entry'),
 				'lang_yes'			=> lang('yes'),
 				'lang_yes_statustext'		=> lang('Delete the entry'),
@@ -1444,7 +1435,7 @@
 			$appname		= lang('agreement');
 			$function_msg		= lang('delete') . ' ' . lang($this->role);
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('delete' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
@@ -1453,11 +1444,11 @@
 		{
 			if(!$this->acl_read)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
 			}
 
 			$agreement_id	= phpgw::get_var('id', 'int');
-			$config		= CreateObject('phpgwapi.config',$this->currentapp);
+			$config		= CreateObject('phpgwapi.config','property');
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('agreement','nextmatchs','attributes_view'));
 
@@ -1479,7 +1470,7 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiagreement.index',
+				'menuaction'	=> 'property.uiagreement.index',
 				'agreement_id'	=> $agreement_id,
 			);
 
@@ -1514,7 +1505,7 @@
 
 			$link_file_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiagreement.view_file',
+				'menuaction'	=> 'property.uiagreement.view_file',
 				'id'		=>$agreement_id
 			);
 
@@ -1540,7 +1531,7 @@
 
 			$link_data2 = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiagreement.view',
+				'menuaction'	=> 'property.uiagreement.view',
 				'id'		=> $agreement_id,
 			);
 
@@ -1605,6 +1596,8 @@
 
 				'lang_status'					=> lang('Status'),
 				'status_list'					=> $this->bo->select_status_list('select',$agreement['status']),
+				'textareacols'					=> isset($GLOBALS['phpgw_info']['user']['preferences']['property']['textareacols']) && $GLOBALS['phpgw_info']['user']['preferences']['property']['textareacols'] ? $GLOBALS['phpgw_info']['user']['preferences']['property']['textareacols'] : 40,
+				'textarearows'					=> isset($GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows']) && $GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows'] ? $GLOBALS['phpgw_info']['user']['preferences']['property']['textarearows'] : 6
 			);
 
 			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('agreement') . ': ' . lang('view');
@@ -1612,332 +1605,5 @@
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('view' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
-
-
-		function list_attribute()
-		{
-			if(!$this->acl_manage)
-			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>16, 'acl_location'=> $this->acl_location));
-			}
-
-			$id	= phpgw::get_var('id', 'int');
-			$resort	= phpgw::get_var('resort');
-
-			$GLOBALS['phpgw']->xslttpl->add_file(array(
-								'agreement',
-								'nextmatchs',
-								'search_field'));
-
-			if($resort)
-			{
-				$this->bo->resort_attrib(array('resort'=>$resort,'id'=>$id));
-			}
-
-			$attrib_list = $this->bo->read_attrib();
-
-			while (is_array($attrib_list) && list(,$attrib) = each($attrib_list))
-			{
-				$content[] = array
-				(
-					'name'					=> $attrib['name'],
-					'type_name'				=> $attrib['type_name'],
-					'datatype'				=> $attrib['datatype'],
-					'column_name'				=> $attrib['column_name'],
-					'input_text'				=> $attrib['input_text'],
-					'sorting'				=> $attrib['attrib_sort'],
-					'search'				=> $attrib['search'],
-					'link_up'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.list_attribute', 'resort'=>'up', 'id'=> $attrib['id'], 'allrows'=> $this->allrows, 'role'=> $this->role)),
-					'link_down'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.list_attribute', 'resort'=> 'down', 'id'=> $attrib['id'], 'allrows'=> $this->allrows, 'role'=> $this->role)),
-					'link_edit'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.edit_attrib', 'id'=> $attrib['id'], 'role'=>$this->role)),
-					'link_delete'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.delete', 'id'=> $attrib['id'], 'attrib'=> true, 'role'=> $this->role)),
-					'lang_view_attribtext'			=> lang('view the attrib'),
-					'lang_attribute_attribtext'		=> lang('attributes for the attrib'). ' ' . lang('location'),
-					'lang_edit_attribtext'			=> lang('edit the attrib'),
-					'lang_delete_attribtext'		=> lang('delete the attrib'),
-					'text_attribute'			=> lang('Attributes'),
-					'text_up'				=> lang('up'),
-					'text_down'				=> lang('down'),
-					'text_edit'				=> lang('edit'),
-					'text_delete'				=> lang('delete')
-				);
-			}
-
-	//html_print_r($content);
-
-			$table_header[] = array
-			(
-				'lang_descr'		=> lang('Descr'),
-				'lang_datatype'		=> lang('Datatype'),
-				'lang_sorting'		=> lang('sorting'),
-				'lang_search'		=> lang('search'),
-				'lang_edit'			=> lang('edit'),
-				'lang_delete'		=> lang('delete'),
-				'sort_sorting'	=> $this->nextmatchs->show_sort_order(array
-										(
-											'sort'	=> $this->sort,
-											'var'	=> 'attrib_sort',
-											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uiagreement.list_attribute',
-																'allrows'=> $this->allrows,
-																'role'	=> $this->role)
-										)),
-
-				'sort_name'	=> $this->nextmatchs->show_sort_order(array
-										(
-											'sort'	=> $this->sort,
-											'var'	=> 'column_name',
-											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uiagreement.list_attribute',
-																'allrows'=> $this->allrows,
-																'role'	=> $this->role)
-										)),
-				'lang_name'	=> lang('Name'),
-			);
-
-			$table_add[] = array
-			(
-				'lang_add'				=> lang('add'),
-				'lang_add_attribtext'	=> lang('add an attrib'),
-				'add_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.edit_attrib', 'role'=> $this->role)),
-				'lang_done'				=> lang('done'),
-				'lang_done_attribtext'	=> lang('back to admin'),
-				'done_action'			=> $GLOBALS['phpgw']->link('/admin/index.php'),
-			);
-
-			if(!$this->allrows)
-			{
-				$record_limit	= $GLOBALS['phpgw_info']['user']['preferences']['common']['maxmatchs'];
-			}
-			else
-			{
-				$record_limit	= $this->bo->total_records;
-			}
-
-			$link_data = array
-			(
-				'menuaction'	=> $this->currentapp.'.uiagreement.list_attribute',
-				'sort'		=>$this->sort,
-				'order'		=>$this->order,
-				'query'		=>$this->query,
-				'role'		=> $this->role
-
-			);
-
-			$data = array
-			(
-				'allow_allrows'				=> True,
-				'allrows'				=> $this->allrows,
-				'start_record'				=> $this->start,
-				'record_limit'				=> $record_limit,
-				'num_records'				=> count($attrib_list),
-				'all_records'				=> $this->bo->total_records,
-				'link_url'				=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'img_path'				=> $GLOBALS['phpgw']->common->get_image_path('phpgwapi','default'),
-				'lang_searchfield_attribtext'		=> lang('Enter the search string. To show all entries, empty this field and press the SUBMIT button again'),
-				'lang_searchbutton_attribtext'		=> lang('Submit the search string'),
-				'query'					=> $this->query,
-				'lang_search'				=> lang('search'),
-				'table_header_attrib'			=> $table_header,
-				'values_attrib'				=> $content,
-				'table_add2'				=> $table_add
-			);
-
-			$appname	= lang('agreement');
-			$function_msg	= lang('list attribute') . ': ' . lang($this->role);
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
-			//$this->save_sessiondata();
-			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('list_attribute' => $data));
-		//	$GLOBALS['phpgw']->xslttpl->pp();
-		}
-
-		function edit_attrib()
-		{
-			if(!$this->acl_manage)
-			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>16, 'acl_location'=> $this->acl_location));
-			}
-
-			$id			= phpgw::get_var('id', 'int');
-			$values		= phpgw::get_var('values');
-	//		$GLOBALS['phpgw']->common->msgbox(lang('Altering ColumnName OR Datatype  - deletes your data in this Column'));
-	//html_print_r($values);
-			$GLOBALS['phpgw']->xslttpl->add_file(array('agreement','choice',));
-
-			if ($values['save'])
-			{
-				if($id)
-				{
-					$values['id']=$id;
-					$action='edit';
-				}
-				$type_id			= $values['type_id'];
-
-				if (!$values['column_name'])
-				{
-					$receipt['error'][] = array('msg'=>lang('Column name not entered!'));
-				}
-
-				if (!$values['input_text'])
-				{
-					$receipt['error'][] = array('msg'=>lang('Input text not entered!'));
-				}
-				if (!$values['statustext'])
-				{
-					$receipt['error'][] = array('msg'=>lang('Statustext not entered!'));
-				}
-
-				if (!$values['column_info']['type'])
-				{
-					$receipt['error'][] = array('msg'=>lang('Datatype type not chosen!'));
-				}
-
-				if(!ctype_digit($values['column_info']['precision']) && $values['column_info']['precision'])
-				{
-					$receipt['error'][]=array('msg'=>lang('Please enter precision as integer !'));
-					unset($values['column_info']['precision']);
-				}
-
-				if(!ctype_digit($values['column_info']['scale']) && $values['column_info']['scale'])
-				{
-					$receipt['error'][]=array('msg'=>lang('Please enter scale as integer !'));
-					unset($values['column_info']['scale']);
-				}
-
-				if (!$values['column_info']['nullable'])
-				{
-					$receipt['error'][] = array('msg'=>lang('Nullable not chosen!'));
-				}
-
-
-				if (!$receipt['error'])
-				{
-					$receipt = $this->bo->save_attrib($values,$action);
-
-					if(!$id)
-					{
-						$id=$receipt['id'];
-					}
-				}
-				else
-				{
-					$receipt['error'][] = array('msg'	=> lang('Attribute has NOT been saved'));
-				}
-
-			}
-
-			if ($id)
-			{
-				$values = $this->bo->read_single_attrib($id);
-				$function_msg = lang('edit attribute') . ': ' . lang($this->role);
-				$action='edit';
-			}
-			else
-			{
-				$function_msg = lang('add attribute') . ': ' . lang($this->role);
-				$action='add';
-			}
-
-			$link_data = array
-			(
-				'menuaction'	=> $this->currentapp.'.uiagreement.edit_attrib',
-				'id'		=> $id,
-				'role'		=> $this->role
-
-			);
-	//html_print_r($values);
-
-			if(is_array($values['column_info']))
-			{
-				if($values['column_info']['type']=='R' || $values['column_info']['type']=='CH' || $values['column_info']['type']=='LB')
-				{
-					$multiple_choice= True;
-				}
-				
-				$column_type = $values['column_info']['type'];
-				$column_precision =$values['column_info']['precision'];
-				$column_scale =$values['column_info']['scale'];
-				$column_default =$values['column_info']['default'];
-				$column_nullable =$values['column_info']['nullable'];
-			}
-
-			$msgbox_data = $this->bocommon->msgbox_data($receipt);
-
-			$data = array
-			(
-				'lang_choice'				=> lang('Choice'),
-				'lang_new_value'			=> lang('New value'),
-				'lang_new_value_statustext'		=> lang('New value for multiple choice'),
-				'multiple_choice'			=> $multiple_choice,
-				'value_choice'				=> $values['choice'],
-				'lang_delete_value'			=> lang('Delete value'),
-				'lang_value'				=> lang('value'),
-				'lang_delete_choice_statustext'		=> lang('Delete this value from the list of multiple choice'),
-				'msgbox_data'				=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
-				'form_action'				=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'done_action'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiagreement.list_attribute', 'type_id'=> $type_id, 'role'=> $this->role)),
-				'lang_id'				=> lang('Attribute ID'),
-				'lang_save'				=> lang('save'),
-				'lang_done'				=> lang('done'),
-				'value_id'				=> $id,
-
-				'lang_column_name'			=> lang('Column name'),
-				'value_column_name'			=> $values['column_name'],
-				'lang_column_name_statustext'		=> lang('enter the name for the column'),
-
-				'lang_input_text'			=> lang('input text'),
-				'value_input_text'			=> $values['input_text'],
-				'lang_input_name_statustext'		=> lang('enter the input text for records'),
-
-				'lang_id_attribtext'			=> lang('Enter the attribute ID'),
-				'lang_entity_statustext'		=> lang('Select a agreement type'),
-
-				'lang_statustext'			=> lang('Statustext'),
-				'lang_statustext_attribtext'		=> lang('Enter a statustext for the inputfield in forms'),
-				'value_statustext'			=> $values['statustext'],
-
-				'lang_done_attribtext'			=> lang('Back to the list'),
-				'lang_save_attribtext'			=> lang('Save the attribute'),
-
-				'lang_datatype'				=> lang('Datatype'),
-				'lang_datatype_statustext'		=> lang('Select a datatype'),
-				'lang_no_datatype'			=> lang('No datatype'),
-				'datatype_list'				=> $this->bocommon->select_datatype($column_type),
-
-				'lang_precision'			=> lang('Precision'),
-				'lang_precision_statustext'		=> lang('enter the record length'),
-				'value_precision'			=> $column_precision,
-
-				'lang_scale'				=> lang('scale'),
-				'lang_scale_statustext'			=> lang('enter the scale if type is decimal'),
-				'value_scale'				=> $column_scale,
-
-				'lang_default'				=> lang('default'),
-				'lang_default_statustext'		=> lang('enter the default value'),
-				'value_default'				=> $column_default,
-
-				'lang_nullable'				=> lang('Nullable'),
-				'lang_nullable_statustext'		=> lang('Chose if this column is nullable'),
-				'lang_select_nullable'			=> lang('Select nullable'),
-				'nullable_list'				=> $this->bocommon->select_nullable($column_nullable),
-
-				'value_list'				=> $values['list'],
-				'lang_list'					=> lang('show in list'),
-				'lang_list_statustext'			=> lang('check to show this attribute in location list'),
-
-				'value_search'				=> $values['search'],
-				'lang_include_search'			=> lang('Include in search'),
-				'lang_include_search_statustext'	=> lang('check to show this attribute in location list'),
-
-
-			);
-	//html_print_r($data);
-
-			$appname	= lang('agreement');
-
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
-			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('edit_attrib' => $data));
-		//	$GLOBALS['phpgw']->xslttpl->pp();
-		}
 	}
 ?>
