@@ -54,7 +54,7 @@
 		function property_uialarm()
 		{
 			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-			$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
+		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->nextmatchs	= CreateObject('phpgwapi.nextmatchs');
 			$this->account		= $GLOBALS['phpgw_info']['user']['account_id'];
 
@@ -142,7 +142,7 @@
 
 				if (substr($alarm['id'],0,8)=='fm_async')
 				{
-					$link_edit			= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uialarm.edit', 'async_id'=> urlencode($alarm['id'])));
+					$link_edit			= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uialarm.edit', 'async_id'=> urlencode($alarm['id'])));
 					$lang_edit_statustext		= lang('edit the alarm');
 					$text_edit			= lang('edit');
 				}
@@ -184,7 +184,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'account_lid',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uialarm.index',
+											'extra'	=> array('menuaction'	=> 'property.uialarm.index',
 																	'cat_id'	=> $this->cat_id,
 																	'query'		=> $this->query,
 																	'allrows'	=> $this->allrows)
@@ -194,7 +194,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'method',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uialarm.index',
+											'extra'	=> array('menuaction'	=> 'property.uialarm.index',
 																	'cat_id'	=> $this->cat_id,
 																	'query'		=> $this->query,
 																	'allrows'	=> $this->allrows)
@@ -204,7 +204,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'next',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uialarm.index',
+											'extra'	=> array('menuaction'	=> 'property.uialarm.index',
 																	'cat_id'	=> $this->cat_id,
 																	'query'		=> $this->query,
 																	'allrows'	=> $this->allrows)
@@ -214,7 +214,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'id',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uialarm.index',
+											'extra'	=> array('menuaction'	=> 'property.uialarm.index',
 																	'cat_id'	=> $this->cat_id,
 																	'query'		=> $this->query,
 																	'allrows'	=> $this->allrows)
@@ -233,12 +233,12 @@
 			(
 				'lang_add'		=> lang('add'),
 				'lang_add_statustext'	=> lang('add an alarm'),
-				'add_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uialarm.edit'))
+				'add_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uialarm.edit'))
 			);
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uialarm.index',
+				'menuaction'	=> 'property.uialarm.index',
 				'sort'		=>$this->sort,
 				'order'		=>$this->order,
 				'cat_id'	=>$this->cat_id,
@@ -357,7 +357,7 @@
 				
 				if($id[0] == 's_agreement' || $id[0] == 'agreement')
 				{
-					$link_edit			= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.ui' .$id[0] .'.edit', 'id'=> $id[1]));
+					$link_edit			= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.ui' .$id[0] .'.edit', 'id'=> $id[1]));
 					$lang_edit_statustext		= lang('edit the alarm');
 					$text_edit			= lang('edit');
 
@@ -400,7 +400,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'account_lid',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uialarm.list_alarm',
+											'extra'	=> array('menuaction'	=> 'property.uialarm.list_alarm',
 																	'cat_id'	=> $this->cat_id,
 																	'query'		=> $this->query,
 																	'allrows'	=> $this->allrows)
@@ -410,7 +410,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'method',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uialarm.list_alarm',
+											'extra'	=> array('menuaction'	=> 'property.uialarm.list_alarm',
 																	'cat_id'	=> $this->cat_id,
 																	'query'		=> $this->query,
 																	'allrows'	=> $this->allrows)
@@ -420,7 +420,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'next',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uialarm.list_alarm',
+											'extra'	=> array('menuaction'	=> 'property.uialarm.list_alarm',
 																	'cat_id'	=> $this->cat_id,
 																	'query'		=> $this->query,
 																	'allrows'	=> $this->allrows)
@@ -430,7 +430,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'id',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uialarm.list_alarm',
+											'extra'	=> array('menuaction'	=> 'property.uialarm.list_alarm',
 																	'cat_id'	=> $this->cat_id,
 																	'query'		=> $this->query,
 																	'allrows'	=> $this->allrows)
@@ -449,12 +449,12 @@
 			(
 				'lang_add'		=> lang('add'),
 				'lang_add_statustext'	=> lang('add an alarm'),
-				'add_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uialarm.edit'))
+				'add_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uialarm.edit'))
 			);
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uialarm.list_alarm',
+				'menuaction'	=> 'property.uialarm.list_alarm',
 				'sort'		=>$this->sort,
 				'order'		=>$this->order,
 				'cat_id'	=>$this->cat_id,
@@ -565,14 +565,14 @@
 					if ($values['save'])
 					{
 						$GLOBALS['phpgw']->session->appsession('session_data','alarm_receipt',$receipt);
-						$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uialarm.index'));
+						$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uialarm.index'));
 					}
 				}
 			}
 
 			if ($values['cancel'])
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uialarm.index'));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uialarm.index'));
 			}
 
 			if ($async_id)
@@ -583,7 +583,7 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uialarm.edit',
+				'menuaction'	=> 'property.uialarm.edit',
 				'async_id'	=> $async_id
 			);
 
@@ -642,7 +642,7 @@
 
 			$link_data = array
 			(
-				'menuaction' => $this->currentapp.'.uiowner.index'
+				'menuaction' => 'property.uiowner.index'
 			);
 
 			if (phpgw::get_var('confirm', 'bool', 'POST'))
@@ -656,7 +656,7 @@
 			$data = array
 			(
 				'done_action'			=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'delete_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiowner.delete', 'owner_id'=> $owner_id)),
+				'delete_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiowner.delete', 'owner_id'=> $owner_id)),
 				'lang_confirm_msg'		=> lang('do you really want to delete this entry'),
 				'lang_yes'			=> lang('yes'),
 				'lang_yes_statustext'		=> lang('Delete the entry'),
@@ -667,7 +667,7 @@
 			$appname	= lang('owner');
 			$function_msg	= lang('delete owner');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('delete' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
@@ -686,7 +686,7 @@
 
 			$data = array
 			(
-				'done_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiowner.index')),
+				'done_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiowner.index')),
 				'lang_name'		=> lang('name'),
 				'lang_category'		=> lang('category'),
 				'lang_time_created'	=> lang('time created'),
