@@ -58,7 +58,7 @@
 		function property_uibudget()
 		{
 			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-			$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
+		//	$this->currentapp	= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->nextmatchs	= CreateObject('phpgwapi.nextmatchs');
 			$this->account		= $GLOBALS['phpgw_info']['user']['account_id'];
 
@@ -112,7 +112,7 @@
 
 			if(!$acl_read)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>1, 'acl_location'=> $acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>1, 'acl_location'=> $acl_location));
 			}
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('budget',
@@ -142,8 +142,8 @@
 						'district_id'			=> $entry['district_id'],
 						'revision'			=> $entry['revision'],
 						'budget_cost'			=> $entry['budget_cost'],
-						'link_edit'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uibudget.edit', 'budget_id'=> $entry['budget_id'])),
-						'link_delete'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uibudget.delete', 'budget_id'=> $entry['budget_id'])),
+						'link_edit'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uibudget.edit', 'budget_id'=> $entry['budget_id'])),
+						'link_delete'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uibudget.delete', 'budget_id'=> $entry['budget_id'])),
 						'lang_edit_text'		=> lang('edit the budget record'),
 						'lang_delete_text'		=> lang('delete the budget record'),
 						'text_edit'			=> lang('edit'),
@@ -170,7 +170,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'district_id',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uibudget.index',
+											'extra'	=> array('menuaction'	=> 'property.uibudget.index',
 																'district_id'	=>$this->district_id,
 																'year'		=>$this->year,
 																'period'	=>$this->period,
@@ -184,7 +184,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'b_account_id',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uibudget.index',
+											'extra'	=> array('menuaction'	=> 'property.uibudget.index',
 																'district_id'	=>$this->district_id,
 																'year'		=>$this->year,
 																'period'	=>$this->period,
@@ -198,7 +198,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'category',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uibudget.index',
+											'extra'	=> array('menuaction'	=> 'property.uibudget.index',
 																'district_id'	=>$this->district_id,
 																'year'		=>$this->year,
 																'period'	=>$this->period,
@@ -212,7 +212,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'budget_cost',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uibudget.index',
+											'extra'	=> array('menuaction'	=> 'property.uibudget.index',
 																'district_id'	=>$this->district_id,
 																'year'		=>$this->year,
 																'period'	=>$this->period,
@@ -228,13 +228,13 @@
 				(
 					'lang_add'		=> lang('add'),
 					'lang_add_statustext'	=> lang('add a budget query'),
-					'add_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uibudget.edit'))
+					'add_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uibudget.edit'))
 				);
 			}
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uibudget.index',
+				'menuaction'	=> 'property.uibudget.index',
 				'sort'		=>$this->sort,
 				'order'		=>$this->order,
 				'cat_id'	=>$this->cat_id,
@@ -317,7 +317,7 @@
 
 			if(!$acl_read)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>1, 'acl_location'=> $acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>1, 'acl_location'=> $acl_location));
 			}
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('budget',
@@ -345,8 +345,8 @@
 						'district_id'			=> $entry['district_id'],
 						'revision'			=> $entry['revision'],
 						'budget_cost'			=> $entry['budget_cost'],
-						'link_edit'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uibudget.edit_basis', 'budget_id'=> $entry['budget_id'])),
-						'link_delete'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uibudget.delete_basis', 'budget_id'=> $entry['budget_id'])),
+						'link_edit'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uibudget.edit_basis', 'budget_id'=> $entry['budget_id'])),
+						'link_delete'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uibudget.delete_basis', 'budget_id'=> $entry['budget_id'])),
 						'lang_edit_text'		=> lang('edit the budget record'),
 						'lang_delete_text'		=> lang('delete the budget record'),
 						'text_edit'			=> lang('edit'),
@@ -371,7 +371,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'district_id',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uibudget.basis',
+											'extra'	=> array('menuaction'	=> 'property.uibudget.basis',
 																'district_id'	=>$this->district_id,
 																'year'		=>$this->year,
 																'period'	=>$this->period,
@@ -385,7 +385,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'b_account_id',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uibudget.basis',
+											'extra'	=> array('menuaction'	=> 'property.uibudget.basis',
 																'district_id'	=>$this->district_id,
 																'year'		=>$this->year,
 																'period'	=>$this->period,
@@ -399,7 +399,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'b_group',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uibudget.basis',
+											'extra'	=> array('menuaction'	=> 'property.uibudget.basis',
 																'district_id'	=>$this->district_id,
 																'year'		=>$this->year,
 																'period'	=>$this->period,
@@ -413,7 +413,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'budget_cost',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uibudget.basis',
+											'extra'	=> array('menuaction'	=> 'property.uibudget.basis',
 																'district_id'	=>$this->district_id,
 																'year'		=>$this->year,
 																'period'	=>$this->period,
@@ -431,13 +431,13 @@
 				(
 					'lang_add'		=> lang('add'),
 					'lang_add_statustext'	=> lang('add a budget query'),
-					'add_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uibudget.edit_basis'))
+					'add_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uibudget.edit_basis'))
 				);
 			}
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uibudget.basis',
+				'menuaction'	=> 'property.uibudget.basis',
 				'sort'		=>$this->sort,
 				'order'		=>$this->order,
 				'cat_id'	=>$this->cat_id,
@@ -517,7 +517,7 @@
 
 			if(!$acl_read)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>1, 'acl_location'=> $acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>1, 'acl_location'=> $acl_location));
 			}
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('budget',
@@ -546,9 +546,9 @@
 						'grouping'			=> $entry['grouping'],
 						'district_id'			=> $entry['district_id'],
 						'obligation'			=> number_format($entry['obligation'], 0, ',', ' '),
-						'link_obligation'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiworkorder.index', 'filter'=>'all', 'paid'=>1, 'district_id'=> $entry['district_id'], 'b_group'=> $entry['grouping'])),
+						'link_obligation'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiworkorder.index', 'filter'=>'all', 'paid'=>1, 'district_id'=> $entry['district_id'], 'b_group'=> $entry['grouping'])),
 						'actual_cost'			=> number_format($entry['actual_cost'], 0, ',', ' '),
-						'link_actual_cost'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvoice.consume', 'district_id'=> $entry['district_id'], 'b_account_class'=> $entry['grouping'], 'start_date'=> $start_date, 'end_date'=> $end_date, 'submit_search'=>true)),
+						'link_actual_cost'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.consume', 'district_id'=> $entry['district_id'], 'b_account_class'=> $entry['grouping'], 'start_date'=> $start_date, 'end_date'=> $end_date, 'submit_search'=>true)),
 						'diff'				=> number_format($entry['budget_cost'] - $entry['actual_cost'] - $entry['obligation'], 0, ',', ' '),
 						'hits'				=> number_format($entry['hits'], 0, ',', ' '),
 
@@ -581,7 +581,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'b_group',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction'	=> $this->currentapp.'.uibudget.obligations',
+											'extra'	=> array('menuaction'	=> 'property.uibudget.obligations',
 																'district_id'	=>$this->district_id,
 																'year'		=>$this->year,
 																'period'	=>$this->period,
@@ -596,13 +596,13 @@
 				(
 					'lang_add'		=> lang('add'),
 					'lang_add_statustext'	=> lang('add a budget query'),
-					'add_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uibudget.edit_obligations'))
+					'add_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uibudget.edit_obligations'))
 				);
 			}
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uibudget.obligations',
+				'menuaction'	=> 'property.uibudget.obligations',
 				'sort'		=>$this->sort,
 				'order'		=>$this->order,
 				'cat_id'	=>$this->cat_id,
@@ -683,7 +683,7 @@
 
 			if(!$acl_add && !$acl_edit)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>2, 'acl_location'=> $acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>2, 'acl_location'=> $acl_location));
 			}
 
 			$budget_id	= phpgw::get_var('budget_id', 'int');
@@ -723,7 +723,7 @@
 					if (isset($values['save']) && $values['save'])
 					{
 						$GLOBALS['phpgw']->session->appsession('session_data','budget_receipt',$receipt);
-						$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uibudget.index'));
+						$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uibudget.index'));
 					}
 				}
 				else
@@ -740,7 +740,7 @@
 
 			if (isset($values['cancel']) && $values['cancel'])
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uibudget.index'));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uibudget.index'));
 			}
 
 
@@ -751,7 +751,7 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uibudget.edit',
+				'menuaction'	=> 'property.uibudget.edit',
 				'budget_id'	=> $budget_id
 			);
 
@@ -814,7 +814,7 @@
 
 			if(!$acl_add && !$acl_edit)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>2, 'acl_location'=> $acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>2, 'acl_location'=> $acl_location));
 			}
 
 			$budget_id	= phpgw::get_var('budget_id', 'int');
@@ -850,7 +850,7 @@
 					if ($values['save'])
 					{
 						$GLOBALS['phpgw']->session->appsession('session_data','budget_basis_receipt',$receipt);
-						$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uibudget.basis'));
+						$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uibudget.basis'));
 					}
 				}
 				else
@@ -869,7 +869,7 @@
 
 			if ($values['cancel'])
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uibudget.basis'));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uibudget.basis'));
 			}
 
 			if ($budget_id)
@@ -879,7 +879,7 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uibudget.edit_basis',
+				'menuaction'	=> 'property.uibudget.edit_basis',
 				'budget_id'	=> $budget_id
 			);
 
@@ -954,7 +954,7 @@
 
 			$link_data = array
 			(
-				'menuaction' => $this->currentapp.'.uibudget.index'
+				'menuaction' => 'property.uibudget.index'
 			);
 
 			if (phpgw::get_var('confirm', 'bool', 'POST'))
@@ -968,7 +968,7 @@
 			$data = array
 			(
 				'done_action'		=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'delete_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uibudget.delete', 'budget_id'=> $budget_id)),
+				'delete_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uibudget.delete', 'budget_id'=> $budget_id)),
 				'lang_confirm_msg'	=> lang('do you really want to delete this entry'),
 				'lang_yes'		=> lang('yes'),
 				'lang_yes_statustext'	=> lang('Delete the entry'),
@@ -979,7 +979,7 @@
 			$appname		= lang('budget');
 			$function_msg		= lang('delete budget');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('delete' => $data));
 
 		}
@@ -991,7 +991,7 @@
 
 			$link_data = array
 			(
-				'menuaction' => $this->currentapp.'.uibudget.basis'
+				'menuaction' => 'property.uibudget.basis'
 			);
 
 			if (phpgw::get_var('confirm', 'bool', 'POST'))
@@ -1005,7 +1005,7 @@
 			$data = array
 			(
 				'done_action'		=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'delete_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uibudget.delete_basis', 'budget_id'=> $budget_id)),
+				'delete_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uibudget.delete_basis', 'budget_id'=> $budget_id)),
 				'lang_confirm_msg'	=> lang('do you really want to delete this entry'),
 				'lang_yes'		=> lang('yes'),
 				'lang_yes_statustext'	=> lang('Delete the entry'),
@@ -1016,7 +1016,7 @@
 			$appname	= lang('budget');
 			$function_msg	= lang('delete budget');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('delete' => $data));
 
 		}
@@ -1063,7 +1063,7 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uibudget.view',
+				'menuaction'	=> 'property.uibudget.view',
 				'sort'		=>$this->sort,
 				'order'		=>$this->order,
 				'budget_id'	=>$budget_id,
@@ -1083,7 +1083,7 @@
 
 			$link_excel = array
 			(
-				'menuaction'	=> $this->currentapp.'.uibudget.excel',
+				'menuaction'	=> 'property.uibudget.excel',
 				'sort'		=>$this->sort,
 				'order'		=>$this->order,
 				'filter'	=>$this->filter,
@@ -1092,7 +1092,7 @@
 				'allrows'	=> $this->allrows
 			);
 
-			$GLOBALS['phpgw']->js->validate_file('overlib','overlib',$this->currentapp);
+			$GLOBALS['phpgw']->js->validate_file('overlib','overlib','property');
 
 			$data = array
 			(
@@ -1116,7 +1116,7 @@
 				'table_header'				=> $table_header,
 				'values'				=> $content,
 
-				'done_action'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uibudget.index')),
+				'done_action'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uibudget.index')),
 				'lang_done'				=> lang('done'),
 			);
 
