@@ -55,7 +55,7 @@
 		function property_uiinvestment()
 		{
 			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-			$this->currentapp		= $GLOBALS['phpgw_info']['flags']['currentapp'];
+		//	$this->currentapp		= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->account			= $GLOBALS['phpgw_info']['user']['account_id'];
 
 			$this->bo			= CreateObject('property.boinvestment',True);
@@ -101,7 +101,7 @@
 		{
 			if(!$this->acl_read)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
 			}
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('investment',
@@ -164,7 +164,7 @@
 					'index_count'				=> $investment['index_count'],
 					'entity_name'				=> $investment['entity_name'],
 					'this_write_off'			=> number_format($investment['this_write_off'], 0, ',', ''),
-					'link_history'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvestment.history', 'entity_id'=> $investment['entity_id'], 'investment_id'=> $investment['investment_id'], 'entity_type'=> $this->cat_id)),
+					'link_history'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvestment.history', 'entity_id'=> $investment['entity_id'], 'investment_id'=> $investment['investment_id'], 'entity_type'=> $this->cat_id)),
 					'lang_history'				=> lang('History'),
 					'lang_history_statustext'		=> lang('View/Edit the history'),
 					'is_admin'				=> $this->admin_invoice
@@ -212,12 +212,12 @@
 			(
 				'lang_add'		=> lang('Add'),
 				'lang_add_statustext'	=> lang('add an investment'),
-				'add_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvestment.add'))
+				'add_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvestment.add'))
 			);
 
 			$link_data = array
 			(
-				'menuaction'		=> $this->currentapp.'.uiinvestment.index',
+				'menuaction'		=> 'property.uiinvestment.index',
 				'order'			=> $this->order,
 				'sort'			=> $this->sort,
 				'cat_id'		=> $this->cat_id,
@@ -239,7 +239,7 @@
 
 			$msgbox_data = $this->bocommon->msgbox_data($receipt);
 
-			$GLOBALS['phpgw']->js->validate_file('core','check',$this->currentapp);
+			$GLOBALS['phpgw']->js->validate_file('core','check','property');
 
 			$data = array
 			(
@@ -248,9 +248,9 @@
 				'lang_search'					=> lang('Search'),
 				'lang_search_statustext'			=> lang('Search for investment entries'),
 //				'form_action'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'form_action'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvestment.index')),
+				'form_action'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvestment.index')),
 				'lang_select_all'				=> lang('Select All'),
-				'img_check'					=> $GLOBALS['phpgw']->common->get_image_path($this->currentapp).'/check.png',
+				'img_check'					=> $GLOBALS['phpgw']->common->get_image_path('property').'/check.png',
 				'allow_allrows'					=> true,
 				'allrows'					=> $this->allrows,
 				'start_record'					=> $this->start,
@@ -280,14 +280,14 @@
 				'sum_value'					=> number_format($sum_value, 0, ',', ''),
 
 				'table_update'					=> $table_update,
-				'update_action'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvestment.index')),
+				'update_action'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvestment.index')),
 				'table_add'					=> $table_add
 			);
 
 			$appname		= lang('investment');
 			$function_msg		= lang('list investment');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('list' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 			$this->save_sessiondata();
@@ -364,7 +364,7 @@
 					'current_index'				=> $investment['current_index'],
 					'index_count'				=> $investment['index_count'],
 					'this_write_off'			=> number_format($investment['this_write_off'], 0, ',', ''),
-					'link_delete'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvestment.delete', 'entity_id'=> $entity_id, 'investment_id'=> $investment_id, 'index_count'=> $investment['index_count'], 'entity_type'=> $entity_type)),
+					'link_delete'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvestment.delete', 'entity_id'=> $entity_id, 'investment_id'=> $investment_id, 'index_count'=> $investment['index_count'], 'entity_type'=> $entity_type)),
 					'lang_delete'				=> lang('Delete'),
 					'lang_delete_statustext'		=> lang('Delete last entry'),
 					'is_admin'				=> $this->admin_invoice
@@ -405,12 +405,12 @@
 			(
 				'lang_done'				=> lang('done'),
 				'lang_done_statustext'	=> lang('Back to investment list '),
-				'done_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvestment.index', 'preserve'=>1))
+				'done_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvestment.index', 'preserve'=>1))
 			);
 
 			$link_data = array
 			(
-				'menuaction'		=> $this->currentapp.'.uiinvestment.index',
+				'menuaction'		=> 'property.uiinvestment.index',
 				'order'			=> $this->order,
 				'sort'			=> $this->sort,
 				'cat_id'		=> $this->cat_id,
@@ -451,21 +451,21 @@
 				'record_limit'					=> $record_limit,
 				'num_records'					=> count($investment_list),
 				'all_records'					=> $this->bo->total_records,
-				'link_url'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvestment.history', 'entity_id'=> $entity_id, 'investment_id'=> $investment_id, 'entity_type'=> $entity_type)),
+				'link_url'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvestment.history', 'entity_id'=> $entity_id, 'investment_id'=> $investment_id, 'entity_type'=> $entity_type)),
 				'img_path'					=> $GLOBALS['phpgw']->common->get_image_path('phpgwapi','default'),
 				'entity_id'					=> $entity_id,
 				'investment_id'					=> $investment_id,
 				'table_header_history'				=> $table_header,
 				'values_history'				=> $content,
 				'table_update'					=> $table_update,
-				'update_action'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvestment.history', 'entity_id'=> $entity_id, 'investment_id'=> $investment_id, 'entity_type'=> $entity_type)),
+				'update_action'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvestment.history', 'entity_id'=> $entity_id, 'investment_id'=> $investment_id, 'entity_type'=> $entity_type)),
 				'table_done'					=> $table_done
 			);
 
 			$appname	= lang('investment');
 			$function_msg	= lang('investment history');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('history' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 //			$this->save_sessiondata();
@@ -476,7 +476,7 @@
 		{
 			if(!$this->acl_add && !$this->acl_edit)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>2, 'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>2, 'acl_location'=> $this->acl_location));
 			}
 			$values					= phpgw::get_var('values');
 
@@ -484,8 +484,8 @@
 
 			if (isset($values['save']) && $values['save'])
 			{
-				$insert_record = $GLOBALS['phpgw']->session->appsession('insert_record',$this->currentapp);
-				$insert_record_entity = $GLOBALS['phpgw']->session->appsession('insert_record_entity',$this->currentapp);
+				$insert_record = $GLOBALS['phpgw']->session->appsession('insert_record','property');
+				$insert_record_entity = $GLOBALS['phpgw']->session->appsession('insert_record_entity','property');
 
 				for ($j=0;$j<count($insert_record_entity);$j++)
 				{
@@ -555,7 +555,7 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiinvestment.add'
+				'menuaction'	=> 'property.uiinvestment.add'
 			);
 
 			$msgbox_data = $this->bocommon->msgbox_data($receipt);
@@ -579,7 +579,7 @@
 				'lang_select_location_statustext'	=> lang('select either a location or an entity'),
 
 				'form_action'				=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'done_action'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvestment.index', 'preserve'=>1)),
+				'done_action'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvestment.index', 'preserve'=>1)),
 
 				'lang_write_off_period'			=> lang('Write off period'),
 				'lang_new'				=> lang('New'),
@@ -612,7 +612,7 @@
 			$appname		= lang('investment');
 			$function_msg		= lang('add investment');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('add' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
@@ -628,7 +628,7 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiinvestment.history',
+				'menuaction'	=> 'property.uiinvestment.history',
 				'entity_id'	=> $entity_id,
 				'investment_id'	=> $investment_id,
 				'index_count'	=> $index_count,
@@ -647,7 +647,7 @@
 			$data = array
 			(
 				'done_action'		=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'delete_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvestment.delete', 'entity_id'=> $entity_id, 'investment_id'=> $investment_id, 'index_count'=> $index_count, 'entity_type'=> $entity_type)),
+				'delete_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvestment.delete', 'entity_id'=> $entity_id, 'investment_id'=> $investment_id, 'index_count'=> $index_count, 'entity_type'=> $entity_type)),
 				'lang_confirm_msg'	=> lang('do you really want to delete this entry'),
 				'lang_yes'		=> lang('yes'),
 				'lang_yes_statustext'	=> lang('Delete the entry'),
@@ -658,7 +658,7 @@
 			$appname	= lang('investment');
 			$function_msg	= lang('delete investment history element');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('delete' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
