@@ -64,7 +64,7 @@
 		function property_uiinvoice()
 		{
 			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-			$this->currentapp		= $GLOBALS['phpgw_info']['flags']['currentapp'];
+		//	$this->currentapp		= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->nextmatchs		= CreateObject('phpgwapi.nextmatchs');
 			$this->account			= $GLOBALS['phpgw_info']['user']['account_id'];
 
@@ -193,7 +193,7 @@
 		{
 			if(!$this->acl_read)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
 			}
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('invoice','menu',
@@ -241,21 +241,21 @@
 					$sum								= $sum + $extra['amount'];
 					$content[$i]['amount'] 				= number_format($extra['amount'], 2, ',', ' ');
 					$content[$i]['lang_payment_date'] 	= lang('Payment Date');
-					$content[$i]['link_sub'] 			= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvoice.list_sub', 'user_lid'=> $this->user_lid, 'query'=> $this->query));
+					$content[$i]['link_sub'] 			= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.list_sub', 'user_lid'=> $this->user_lid, 'query'=> $this->query));
 					$content[$i]['lang_sub'] 			= lang('Voucher ID');
 					$content[$i]['lang_sub_help'] 		= lang('Klick this link to enter the list of sub-invoices');
-					$content[$i]['link_period'] 		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvoice.edit_period'));
+					$content[$i]['link_period'] 		= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.edit_period'));
 					$content[$i]['lang_period'] 		= lang('Period');
 					$content[$i]['lang_period_help'] 	= lang('Klick this link to edit the period');
 
 					if($this->acl_delete && !$paid)
 					{
-						$content[$i]['link_delete']				= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvoice.delete', 'voucher_id'=> $extra['voucher_id']));
+						$content[$i]['link_delete']				= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.delete', 'voucher_id'=> $extra['voucher_id']));
 						$content[$i]['lang_delete_statustext']	= lang('delete the voucher');
 						$content[$i]['text_delete']				= lang('delete');
 					}
 
-					$content[$i]['link_front']				= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvoice.receipt', 'voucher_id'=> $extra['voucher_id']));
+					$content[$i]['link_front']				= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.receipt', 'voucher_id'=> $extra['voucher_id']));
 					$content[$i]['lang_front_statustext']	= lang('A printout version of the frontpage');
 					$content[$i]['text_front']				= 'F';
 
@@ -271,7 +271,7 @@
 													'var'	=> 'bilagsnr',
 													'order'	=> $this->order,
 													'extra'	=> array(
-															'menuaction' 		=> $this->currentapp.'.uiinvoice.index',
+															'menuaction' 		=> 'property.uiinvoice.index',
 															'cat_id'		=> $this->cat_id,
 															'sub'			=> $this->sub,
 															'paid'			=> $paid,
@@ -289,7 +289,7 @@
 													'sort'	=> $this->sort,
 													'var'	=> 'fakturadato',
 													'order'	=> $this->order,
-													'extra'	=> array('menuaction' => $this->currentapp.'.uiinvoice.index',
+													'extra'	=> array('menuaction' => 'property.uiinvoice.index',
 																	'cat_id'		=> $this->cat_id,
 																	'sub'			=> $this->sub,
 																	'paid'			=> $paid,
@@ -309,7 +309,7 @@
 													'sort'	=> $this->sort,
 													'var'	=> 'spvend_code',
 													'order'	=> $this->order,
-													'extra'	=> array('menuaction' => $this->currentapp.'.uiinvoice.index',
+													'extra'	=> array('menuaction' => 'property.uiinvoice.index',
 																	'cat_id'		=> $this->cat_id,
 																	'sub'			=> $this->sub,
 																	'paid'			=> $paid,
@@ -343,7 +343,7 @@
 
 			$link_data = array
 			(
-				'menuaction'		=> $this->currentapp.'.uiinvoice.index',
+				'menuaction'		=> 'property.uiinvoice.index',
 				'order'				=> $this->order,
 				'sort'				=> $this->sort,
 				'cat_id'			=> $this->cat_id,
@@ -367,7 +367,7 @@
 				(
 					'lang_add'				=> lang('add'),
 					'lang_add_statustext'	=> lang('add an invoice'),
-					'add_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvoice.add'))
+					'add_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.add'))
 				);
 			}
 
@@ -385,7 +385,7 @@
 
 			$link_excel = array
 			(
-				'menuaction'		=> $this->currentapp.'.uiinvoice.excel',
+				'menuaction'		=> 'property.uiinvoice.excel',
 				'order'				=> $this->order,
 				'sort'				=> $this->sort,
 				'cat_id'			=> $this->cat_id,
@@ -404,8 +404,8 @@
 				'district_id'		=> $this->district_id
 			);
 
-			$GLOBALS['phpgw']->js->validate_file('overlib','overlib',$this->currentapp);
-			$GLOBALS['phpgw']->js->validate_file('core','check',$this->currentapp);
+			$GLOBALS['phpgw']->js->validate_file('overlib','overlib','property');
+			$GLOBALS['phpgw']->js->validate_file('core','check','property');
 
 			$data['lang_excel']						= 'excel';
 			$data['link_excel']						= $GLOBALS['phpgw']->link('/index.php',$link_excel);
@@ -439,7 +439,7 @@
 			$appname	= lang('invoice');
 			$function_msg	= lang('list voucher');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 
 			if (isset($paid) && $paid)
 			{
@@ -463,10 +463,10 @@
 				$data['lang_workorder_statustext']		= lang('enter the Workorder ID to search by workorder - at any date');
 				$data['workorder_id']					= $workorder_id;
 
-				$data['addressbook_link']				= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uilookup.vendor'));
+				$data['addressbook_link']				= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uilookup.vendor'));
 				$data['lang_select_vendor_statustext']	= lang('Select the vendor by klicking this link');
 				$data['lang_vendor']					= lang('Vendor');
-				$data['property_link']					= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.index', 'lookup'=> 1, 'type_id'=> 1, 'lookup_name'=> 0));
+				$data['property_link']					= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uilocation.index', 'lookup'=> 1, 'type_id'=> 1, 'lookup_name'=> 0));
 				$data['lang_select_property_statustext']= lang('Select the property by klicking this link');
 				$data['lang_property_statustext']		= lang('Search by property');
 				$data['lang_property']					= lang('property');
@@ -493,9 +493,9 @@
 				$data['user_list']						= $this->bo->get_invoice_user_list('filter',$this->user_lid,array('all'),$default='none');
 				$data['cat_list']						= $this->bo->select_category('filter',$this->cat_id);
 				$data['table_done']						= $table_done;
-				$data['img_check']						= $GLOBALS['phpgw']->common->get_image_path($this->currentapp).'/check.png';
+				$data['img_check']						= $GLOBALS['phpgw']->common->get_image_path('property').'/check.png';
 				$data['lang_save']						= lang('save');
-				$data['done_action']					= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvoice.index'));
+				$data['done_action']					= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.index'));
 				$data['lang_done_statustext']			= lang('Back to the list');
 				$data['lang_save_statustext']			= lang('Save the voucher');
 				$data['lang_select_all']				= lang('Select All');
@@ -553,10 +553,10 @@
 					$content[$i]['dimb_list']				= $this->bo->select_dimb_list($content[$i]['dimb']);
 					$content[$i]['tax_code_list']			= $this->bo->tax_code_list($content[$i]['tax_code']);
 					$content[$i]['lang_remark'] 			= lang('Remark');
-					$content[$i]['link_remark'] 			= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvoice.remark'));
+					$content[$i]['link_remark'] 			= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.remark'));
 					$content[$i]['lang_remark_help'] 		= lang('Klick this link to view the remark');
-					$content[$i]['link_order'] 				= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvoice.view_order'));
-					$content[$i]['link_claim'] 				= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uitenant_claim.check'));
+					$content[$i]['link_order'] 				= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.view_order'));
+					$content[$i]['link_claim'] 				= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uitenant_claim.check'));
 					$i++;
 				}
 			}
@@ -569,7 +569,7 @@
 													'sort'	=> $this->sort,
 													'var'	=> 'pmwrkord_code',
 													'order'	=> $this->order,
-													'extra'	=> array('menuaction'	=> $this->currentapp.'.uiinvoice.list_sub',
+													'extra'	=> array('menuaction'	=> 'property.uiinvoice.list_sub',
 															'cat_id'	=> $this->cat_id,
 															'sub'		=> $this->sub,
 															'paid'		=> $paid,
@@ -582,7 +582,7 @@
 													'sort'	=> $this->sort,
 													'var'	=> 'spbudact_code',
 													'order'	=> $this->order,
-													'extra'	=> array('menuaction'	=> $this->currentapp.'.uiinvoice.list_sub',
+													'extra'	=> array('menuaction'	=> 'property.uiinvoice.list_sub',
 															'cat_id'	=> $this->cat_id,
 															'sub'		=> $this->sub,
 															'paid'		=> $paid,
@@ -596,7 +596,7 @@
 													'sort'	=> $this->sort,
 													'var'	=> 'belop',
 													'order'	=> $this->order,
-													'extra'	=> array('menuaction'	=> $this->currentapp.'.uiinvoice.list_sub',
+													'extra'	=> array('menuaction'	=> 'property.uiinvoice.list_sub',
 															'cat_id'	=> $this->cat_id,
 															'sub'		=> $this->sub,
 															'paid'		=> $paid,
@@ -614,7 +614,7 @@
 													'sort'	=> $this->sort,
 													'var'	=>	'dima',
 													'order'	=>	$this->order,
-													'extra'		=> array('menuaction'	=> $this->currentapp.'.uiinvoice.list_sub',
+													'extra'		=> array('menuaction'	=> 'property.uiinvoice.list_sub',
 																'cat_id'	=> $this->cat_id,
 																'sub'		=> $this->sub,
 																'paid'		=> $paid,
@@ -636,7 +636,7 @@
 
 			$link_data = array
 			(
-				'menuaction'		=> $this->currentapp.'.uiinvoice.list_sub',
+				'menuaction'		=> 'property.uiinvoice.list_sub',
 				'order'			=> $this->order,
 				'sort'			=> $this->sort,
 				'cat_id'		=> $this->cat_id,
@@ -665,13 +665,13 @@
 
 			$link_excel = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiinvoice.excel_sub',
+				'menuaction'	=> 'property.uiinvoice.excel_sub',
 				'voucher_id'	=> $voucher_id,
 				'paid'		=> $paid
 			);
 
-			$GLOBALS['phpgw']->js->validate_file('overlib','overlib',$this->currentapp);
-			$GLOBALS['phpgw']->js->validate_file('core','check',$this->currentapp);
+			$GLOBALS['phpgw']->js->validate_file('overlib','overlib','property');
+			$GLOBALS['phpgw']->js->validate_file('core','check','property');
 
 			$data = array
 			(
@@ -680,13 +680,13 @@
 				'link_excel'					=> $GLOBALS['phpgw']->link('/index.php',$link_excel),
 				'lang_excel_help'				=> lang('Download table to MS Excel'),
 
-				'img_check'					=> $GLOBALS['phpgw']->common->get_image_path($this->currentapp).'/check.png',
+				'img_check'					=> $GLOBALS['phpgw']->common->get_image_path('property').'/check.png',
 				'msgbox_data'					=> $GLOBALS['phpgw']->common->msgbox($msgbox_data),
 				'sum'						=> number_format($sum, 2, ',', ''),
 				'form_action'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
 				'lang_save'					=> lang('save'),
 				'lang_done'					=> lang('Done'),
-				'done_action'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvoice.index', 'user_lid'=> $this->user_lid, 'query'=> $this->query)),
+				'done_action'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.index', 'user_lid'=> $this->user_lid, 'query'=> $this->query)),
 				'lang_done_statustext'				=> lang('Back to the list'),
 				'lang_save_statustext'				=> lang('Save the voucher'),
 				'links'						=> $links,
@@ -713,7 +713,7 @@
 
 			$appname = lang('invoice');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('list_invoice_sub' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 			$this->save_sessiondata();
@@ -740,7 +740,7 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiinvoice.edit_period',
+				'menuaction'	=> 'property.uiinvoice.edit_period',
 				'voucher_id'	=> $voucher_id);
 
 
@@ -782,7 +782,7 @@
 			$appname	= lang('invoice');
 			$function_msg	= lang('remark');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('remark' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
@@ -846,7 +846,7 @@
 					$p_end_date = $GLOBALS['phpgw']->common->show_date(mktime(0,0,0,($content[$i]['period']+1),0,$p_year),$dateformat);
 					$sum				= $sum+$content[$i]['consume'];
 					$content[$i]['link_voucher'] 	= $GLOBALS['phpgw']->link('/index.php',array(
-														'menuaction'	=> $this->currentapp.'.uiinvoice.index',
+														'menuaction'	=> 'property.uiinvoice.index',
 														'paid'		=> true,
 														'user_lid'	=> 'all',
 														'district_id'	=> $district_id,
@@ -877,7 +877,7 @@
 
 			$link_data = array
 			(
-				'menuaction'		=> $this->currentapp.'.uiinvoice.consume',
+				'menuaction'		=> 'property.uiinvoice.consume',
 				'order'			=> $this->order,
 				'sort'			=> $this->sort,
 				'cat_id'		=> $this->cat_id,
@@ -888,7 +888,7 @@
 				'filter'		=> $this->filter
 			);
 
-			$GLOBALS['phpgw']->js->validate_file('overlib','overlib',$this->currentapp);
+			$GLOBALS['phpgw']->js->validate_file('overlib','overlib','property');
 
 			$data['lang_sum']				= lang('Sum');
 			$data['sum']					= number_format($sum, 0, ',', ' ');
@@ -936,14 +936,14 @@
 			$data['lang_workorder_statustext']		= lang('enter the Workorder ID to search by workorder - at any date');
 			$data['workorder_id']				= $workorder_id;
 
-			$data['addressbook_link']			= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uilookup.vendor'));
+			$data['addressbook_link']			= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uilookup.vendor'));
 			$data['lang_select_vendor_statustext']		= lang('Select the vendor by klicking this link');
 			$data['lang_vendor']				= lang('Vendor');
 
 			$bolocation					= CreateObject('property.bolocation');
 			$location_data					= $bolocation->initiate_ui_location(array('type_id'=> 1));
 
-			$data['property_link']				= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.index', 'lookup'=> 1, 'type_id'=> 1, 'lookup_name'=> 0));
+			$data['property_link']				= $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uilocation.index', 'lookup'=> 1, 'type_id'=> 1, 'lookup_name'=> 0));
 
 			$data['lang_select_property_statustext']	= lang('Select the property by klicking this link');
 			$data['lang_property_statustext']		= lang('Search by property');
@@ -959,7 +959,7 @@
 			$appname					= lang('consume');
 			$function_msg					= lang('list consume');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('consume' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 
@@ -970,7 +970,7 @@
 		{
 			if(!$this->acl_delete)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>8, 'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>8, 'acl_location'=> $this->acl_location));
 			}
 
 			$voucher_id = phpgw::get_var('voucher_id', 'int');
@@ -978,7 +978,7 @@
 
 			$link_data = array
 			(
-				'menuaction' => $this->currentapp.'.uiinvoice.index'
+				'menuaction' => 'property.uiinvoice.index'
 			);
 
 			if (phpgw::get_var('confirm', 'bool', 'POST'))
@@ -992,7 +992,7 @@
 			$data = array
 			(
 				'done_action'		=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'delete_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvoice.delete', 'voucher_id'=> $voucher_id)),
+				'delete_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.delete', 'voucher_id'=> $voucher_id)),
 				'lang_confirm_msg'	=> lang('do you really want to delete this entry'),
 				'lang_yes'		=> lang('yes'),
 				'lang_yes_statustext'	=> lang('Delete the entry'),
@@ -1003,7 +1003,7 @@
 			$appname	= lang('invoice');
 			$function_msg	= lang('delete voucher');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('delete' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
@@ -1012,14 +1012,14 @@
 		{
 			if(!$this->acl_add)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>2, 'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>2, 'acl_location'=> $this->acl_location));
 			}
 
 			$receipt = $GLOBALS['phpgw']->session->appsession('session_data','add_receipt');
 
 			if(isset($receipt['voucher_id']) && $receipt['voucher_id'])
 			{
-				$link_receipt = $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvoice.receipt', 'voucher_id'=> $receipt['voucher_id']));
+				$link_receipt = $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.receipt', 'voucher_id'=> $receipt['voucher_id']));
 			}
 
 			$GLOBALS['phpgw']->session->appsession('session_data','add_receipt','');
@@ -1028,7 +1028,7 @@
 
 			$referer = parse_url($_SERVER['HTTP_REFERER']);
 			parse_str($referer['query']); // produce $menuaction
-			if(phpgw::get_var('cancel', 'bool') || $menuaction != $this->currentapp.'.uiinvoice.add')
+			if(phpgw::get_var('cancel', 'bool') || $menuaction != 'property.uiinvoice.add')
 			{
 				$GLOBALS['phpgw']->session->appsession('session_data','add_values','');
 			}
@@ -1061,7 +1061,7 @@
 				$values['amount']		= phpgw::get_var('amount', 'float');
 				$values['order_id']		= phpgw::get_var('order_id', 'int');
 
-				$insert_record = $GLOBALS['phpgw']->session->appsession('insert_record',$this->currentapp);
+				$insert_record = $GLOBALS['phpgw']->session->appsession('insert_record','property');
 				$values = $this->bocommon->collect_locationdata($values,$insert_record);
 
 				$GLOBALS['phpgw']->session->appsession('session_data','add_values',$values);
@@ -1169,7 +1169,7 @@
 					}
 					unset($values);
 					$GLOBALS['phpgw']->session->appsession('session_data','add_receipt',$receipt);
-					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvoice.add'));
+					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uiinvoice.add'));
 				}
 				else
 				{
@@ -1198,7 +1198,7 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiinvoice.add',
+				'menuaction'	=> 'property.uiinvoice.add',
 				'debug'		=> True
 			);
 
@@ -1226,10 +1226,10 @@
 				'lang_datetitle'					=> lang('Select date'),
 
 				'form_action'						=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'cancel_action'						=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiinvoice.index')),
+				'cancel_action'						=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiinvoice.index')),
 				'lang_cancel'						=> lang('Cancel'),
 				'lang_cancel_statustext'			=> lang('cancel'),
-				'action_url'						=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=>  $this->currentapp .'.uiinvoice.add')),
+				'action_url'						=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=>  'property' .'.uiinvoice.add')),
 				'tsvfilename'						=> '',
 
 				'lang_add'							=> lang('add'),
@@ -1246,7 +1246,7 @@
 				'lang_kid_nr_statustext'			=> lang('Enter Kid nr'),
 
 				'lang_vendor'						=> lang('Vendor'),
-				'addressbook_link'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uilookup.vendor')),
+				'addressbook_link'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uilookup.vendor')),
 
 				'lang_invoice_date_statustext'		=> lang('Enter the invoice date'),
 				'lang_num_days_statustext'			=> lang('Enter the payment date or the payment delay'),
@@ -1327,7 +1327,7 @@
 			$appname						= lang('Invoice');
 			$function_msg					= lang('Add invoice');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('add' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
@@ -1337,7 +1337,7 @@
 
 			if(!$this->acl_read)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
 			}
 
 			$GLOBALS['phpgw_info']['flags'][noheader] = True;
@@ -1360,7 +1360,9 @@
 				$contacts->role='vendor';
 				if($values[0]['vendor_id'])
 				{
-					$vendor_data	= $contacts->read_single(array('actor_id'=>$values[0]['vendor_id']));
+					$custom 					= createObject('phpgwapi.custom_fields');	
+					$vendor_data['attributes']	= $custom->get_attribs('property','.vendor', 0, '', 'ASC', 'attrib_sort', true, true);
+					$vendor_data				= $contacts->read_single($values[0]['vendor_id'],$vendor_data);
 					if(is_array($vendor_data))
 					{
 						foreach($vendor_data['attributes'] as $attribute)
@@ -1540,13 +1542,13 @@
 			
 			$link_data_add = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiinvoice.add',
+				'menuaction'	=> 'property.uiinvoice.add',
 				'add_invoice'	=> True
 			);
 
 			$link_data_cancel = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiinvoice.add'
+				'menuaction'	=> 'property.uiinvoice.add'
 			);
 
 			$post_data = array
@@ -1662,7 +1664,7 @@
 			$appname						= lang('Invoice');
 			$function_msg					= lang('Add invoice: Debug');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('debug' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
@@ -1676,10 +1678,10 @@
 			switch($order_type)
 			{
 				case 'workorder':
-					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uiwo_hour.view', 'no_email'=> true, 'show_cost'=> true, 'workorder_id'=> $order_id));
+					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uiwo_hour.view', 'no_email'=> true, 'show_cost'=> true, 'workorder_id'=> $order_id));
 					break;
 				case 's_agreement':
-					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uis_agreement.view', 'id'=> $order_id));
+					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uis_agreement.view', 'id'=> $order_id));
 					break;
 			}
 		}
