@@ -59,7 +59,7 @@
 		function property_uiproject()
 		{
 			$GLOBALS['phpgw_info']['flags']['xslt_app'] = True;
-			$this->currentapp		= $GLOBALS['phpgw_info']['flags']['currentapp'];
+		//	$this->currentapp		= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->nextmatchs		= CreateObject('phpgwapi.nextmatchs');
 			$this->account			= $GLOBALS['phpgw_info']['user']['account_id'];
 
@@ -116,7 +116,7 @@
 		{
 			if(!$this->acl_read)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>1,'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>1,'acl_location'=> $this->acl_location));
 			}
 
 			$GLOBALS['phpgw']->xslttpl->add_file(array('project','values','table_header',
@@ -151,7 +151,7 @@
 								$content[$j]['row'][]= array(
 									'statustext' => lang('search'),
 									'text'		=> $project_entry[$uicols['name'][$k]],
-									'link'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiproject.index', 'query'=> $project_entry['query_location'][$uicols['name'][$k]], 'lookup'=> $lookup, 'from'=> $from, 'filter'=> $this->filter))
+									'link'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiproject.index', 'query'=> $project_entry['query_location'][$uicols['name'][$k]], 'lookup'=> $lookup, 'from'=> $from, 'filter'=> $this->filter))
 								);
 							}
 							else
@@ -167,14 +167,14 @@
 								$content[$j]['row'][]= array(
 								'statustext'	=> lang('search'),
 								'text'		=> $project_entry[$uicols['name'][$k]],
-								'link'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uitts.view', 'id'=> $project_entry[$uicols['name'][$k]]))
+								'link'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uitts.view', 'id'=> $project_entry[$uicols['name'][$k]]))
 								);
 						}
 
 						if($lookup && $k==($count_uicols_name-1))
 						{
 							$content[$j]['row'][]= array(
-							'lookup_action'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.ui' . $from . '.edit', 'project_id'=> $project_entry['project_id']))
+							'lookup_action'	=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.ui' . $from . '.edit', 'project_id'=> $project_entry['project_id']))
 							);
 						}
 					}
@@ -186,7 +186,7 @@
 							$content[$j]['row'][]= array(
 							'statustext'	=> lang('view the project'),
 							'text'		=> lang('view'),
-							'link'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiproject.view', 'id'=> $project_entry['project_id']))
+							'link'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiproject.view', 'id'=> $project_entry['project_id']))
 							);
 						}
 						else
@@ -199,7 +199,7 @@
 							$content[$j]['row'][]= array(
 							'statustext'	=> lang('edit the project'),
 							'text'		=> lang('edit'),
-							'link'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiproject.edit','id'=> $project_entry['project_id']))
+							'link'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiproject.edit','id'=> $project_entry['project_id']))
 							);
 						}
 						else
@@ -212,7 +212,7 @@
 							$content[$j]['row'][]= array(
 							'statustext'	=> lang('delete the project'),
 							'text'		=> lang('delete'),
-							'link'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiproject.delete', 'project_id'=> $project_entry['project_id']))
+							'link'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiproject.delete', 'project_id'=> $project_entry['project_id']))
 							);
 						}
 						else
@@ -241,7 +241,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'location_code',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction' => $this->currentapp.'.uiproject.index',
+											'extra'	=> array('menuaction' => 'property.uiproject.index',
 																//	'type_id'	=> $type_id,
 																	'query'		=> $this->query,
 																	'lookup'	=> $lookup,
@@ -262,7 +262,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'project_id',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction' => $this->currentapp.'.uiproject.index',
+											'extra'	=> array('menuaction' => 'property.uiproject.index',
 																//	'type_id'	=> $type_id,
 																	'query'		=> $this->query,
 																	'lookup'	=> $lookup,
@@ -283,7 +283,7 @@
 											'sort'	=> $this->sort,
 											'var'	=> 'address',
 											'order'	=> $this->order,
-											'extra'	=> array('menuaction' => $this->currentapp.'.uiproject.index',
+											'extra'	=> array('menuaction' => 'property.uiproject.index',
 																//	'type_id'	=> $type_id,
 																	'query'		=> $this->query,
 																	'lookup'	=> $lookup,
@@ -337,13 +337,13 @@
 				(
 					'lang_add'			=> lang('add'),
 					'lang_add_statustext'		=> lang('add a project'),
-					'add_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiproject.edit'))
+					'add_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiproject.edit'))
 				);
 			}
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiproject.index',
+				'menuaction'	=> 'property.uiproject.index',
 						'sort'			=>$this->sort,
 						'order'			=>$this->order,
 						'cat_id'		=>$this->cat_id,
@@ -358,11 +358,11 @@
 						'wo_hour_cat_id'	=>$this->wo_hour_cat_id,
 			);
 
-			$link_date_search = $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiproject.date_search'));
+			$link_date_search = $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiproject.date_search'));
 
 			$link_excel = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiproject.excel',
+				'menuaction'	=> 'property.uiproject.excel',
 						'sort'			=>$this->sort,
 						'order'			=>$this->order,
 						'cat_id'		=>$this->cat_id,
@@ -378,7 +378,7 @@
 						'wo_hour_cat_id'	=>$this->wo_hour_cat_id,
 			);
 
-			$GLOBALS['phpgw']->js->validate_file('overlib','overlib',$this->currentapp);
+			$GLOBALS['phpgw']->js->validate_file('overlib','overlib','property');
 
 			$data = array
 			(
@@ -394,7 +394,7 @@
 				'link_date_search'		=> $link_date_search,
 
 				'lang_select'			=> lang('select'),
-				'lookup_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiworkorder.edit')),
+				'lookup_action'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiworkorder.edit')),
 				'lookup'			=> $lookup,
 				'links'				=> $links,
 				'allow_allrows'			=> false,
@@ -440,7 +440,7 @@
 			$appname	= lang('Project');
 			$function_msg	= lang('list Project');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('list_project' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
@@ -486,7 +486,7 @@
 				'lang_submit'			=> lang('Submit')
 			);
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('date_search' => $data));
 		}
 
@@ -494,7 +494,7 @@
 		{
 			if(!$this->acl_add && !$this->acl_edit)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=> 2, 'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=> 2, 'acl_location'=> $this->acl_location));
 			}
 			$id 				= phpgw::get_var('id', 'int');
 			$values				= phpgw::get_var('values');
@@ -503,8 +503,8 @@
 			$config				= CreateObject('phpgwapi.config');
 			$bolocation			= CreateObject('property.bolocation');
 
-			$insert_record = $GLOBALS['phpgw']->session->appsession('insert_record',$this->currentapp);
-			$insert_record_entity = $GLOBALS['phpgw']->session->appsession('insert_record_entity',$this->currentapp);
+			$insert_record = $GLOBALS['phpgw']->session->appsession('insert_record','property');
+			$insert_record_entity = $GLOBALS['phpgw']->session->appsession('insert_record_entity','property');
 
 			if(isset($insert_record_entity) && is_array($insert_record_entity))
 			{
@@ -555,7 +555,7 @@
 
 				if($location_code)
 				{
-					$values['location_data'] = $bolocation->read_single($location_code,array('tenant_id'=>$tenant_id,'p_num'=>$p_num));
+					$values['location_data'] = $bolocation->read_single($location_code,array('tenant_id'=>$tenant_id,'p_num'=>$p_num, 'view' => true));
 				}
 
 			}
@@ -651,7 +651,7 @@
 						if ($values['approval'] && $values['mail_address'])
 						{
 							$from_name=$GLOBALS['phpgw_info']['user']['fullname'];
-							$from_email=$GLOBALS['phpgw_info']['user']['preferences'][$this->currentapp]['email'];
+							$from_email=$GLOBALS['phpgw_info']['user']['preferences']['property']['email'];
 							$headers = "Return-Path: <". $from_email .">\r\n";
 							$headers .= "From: " . $from_name . "<" . $from_email .">\r\n";
 							$headers .= "Bcc: " . $from_name . "<" . $from_email .">\r\n";
@@ -659,7 +659,7 @@
 							$headers .= "MIME-Version: 1.0\r\n";
 
 							$subject = lang(Approval).": ". $values['project_id'];
-							$message = '<a href ="http://' . $GLOBALS['phpgw_info']['server']['hostname'] . $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiproject.edit','id'=> $values['project_id'])).'">' . lang(Project) . " " . $values['project_id'] ." ". lang('needs approval') .'</a>';
+							$message = '<a href ="http://' . $GLOBALS['phpgw_info']['server']['hostname'] . $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiproject.edit','id'=> $values['project_id'])).'">' . lang(Project) . " " . $values['project_id'] ." ". lang('needs approval') .'</a>';
 
 							$bcc = $from_email;
 
@@ -681,13 +681,13 @@
 						{
 							if($this->account!=$values['coordinator'] && $config->config_data['workorder_approval'])
 							{
-								$prefs_coordinator = $this->bocommon->create_preferences($this->currentapp,$values['coordinator']);
+								$prefs_coordinator = $this->bocommon->create_preferences('property',$values['coordinator']);
 								$to = $prefs_coordinator['email'];
 
 								$from_name=$GLOBALS['phpgw_info']['user']['fullname'];
-								$from_email=$GLOBALS['phpgw_info']['user']['preferences'][$this->currentapp]['email'];
+								$from_email=$GLOBALS['phpgw_info']['user']['preferences']['property']['email'];
 
-								$body = '<a href ="http://' . $GLOBALS['phpgw_info']['server']['hostname'] . $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiproject.edit', 'id'=> $values['project_id'])).'">' . lang('project %1 has been edited',$id) .'</a>' . "\n";
+								$body = '<a href ="http://' . $GLOBALS['phpgw_info']['server']['hostname'] . $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiproject.edit', 'id'=> $values['project_id'])).'">' . lang('project %1 has been edited',$id) .'</a>' . "\n";
 								foreach($receipt['notice_owner'] as $notice)
 								{
 									$body .= $notice . "\n";
@@ -750,14 +750,14 @@
 
 				if(!isset($values['workorder_budget']) && $save)
 				{
-					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uiworkorder.edit', 'project_id'=> $id));
+					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uiworkorder.edit', 'project_id'=> $id));
 				}
 
 				if (!$this->bocommon->check_perms($values['grants'],PHPGW_ACL_EDIT))
 				{
 					$receipt['error'][]=array('msg'=>lang('You have no edit right for this project'));
-					$GLOBALS['phpgw']->session->appsession('receipt',$this->currentapp,$receipt);
-					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=>$this->currentapp.'.uiproject.view', 'id'=> $id));
+					$GLOBALS['phpgw']->session->appsession('receipt','property',$receipt);
+					$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=>'property.uiproject.view', 'id'=> $id));
 				}
 				else
 				{
@@ -822,22 +822,22 @@
 
 			$link_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uiproject.edit',
+				'menuaction'	=> 'property.uiproject.edit',
 				'id'		=> $id
 			);
 
 			$link_request_data = array
 			(
-				'menuaction'	=> $this->currentapp.'.uirequest.index',
+				'menuaction'	=> 'property.uirequest.index',
 				'query'		=> (isset($values['location_data']['loc1'])?$values['location_data']['loc1']:''),
 				'project_id'	=> (isset($values['project_id'])?$values['project_id']:'')
 			);
 
-			$supervisor_id= (isset($GLOBALS['phpgw_info']['user']['preferences'][$this->currentapp]['approval_from'])?$GLOBALS['phpgw_info']['user']['preferences'][$this->currentapp]['approval_from']:'');
+			$supervisor_id= (isset($GLOBALS['phpgw_info']['user']['preferences']['property']['approval_from'])?$GLOBALS['phpgw_info']['user']['preferences']['property']['approval_from']:'');
 			$need_approval = (isset($config->config_data['workorder_approval'])?$config->config_data['workorder_approval']:'');
 
-			$project_status=(isset($GLOBALS['phpgw_info']['user']['preferences'][$this->currentapp]['project_status'])?$GLOBALS['phpgw_info']['user']['preferences'][$this->currentapp]['project_status']:'');
-			$project_category=(isset($GLOBALS['phpgw_info']['user']['preferences'][$this->currentapp]['project_category'])?$GLOBALS['phpgw_info']['user']['preferences'][$this->currentapp]['project_category']:'');
+			$project_status=(isset($GLOBALS['phpgw_info']['user']['preferences']['property']['project_status'])?$GLOBALS['phpgw_info']['user']['preferences']['property']['project_status']:'');
+			$project_category=(isset($GLOBALS['phpgw_info']['user']['preferences']['property']['project_category'])?$GLOBALS['phpgw_info']['user']['preferences']['property']['project_category']:'');
 			if(!isset($values['status']))
 			{
 				$values['status']=$project_status;
@@ -855,7 +855,7 @@
 
 			if ($supervisor_id && $need_approval=='yes')
 			{
-				$prefs = $this->bocommon->create_preferences($this->currentapp,$supervisor_id);
+				$prefs = $this->bocommon->create_preferences('property',$supervisor_id);
 				$supervisor_email = $prefs['email'];
 			}
 
@@ -943,15 +943,15 @@
 				'lang_request_statustext'			=> lang('Link to the request for this project'),
 				'lang_delete_request_statustext'		=> lang('Check to delete this request from this project'),
 				'link_select_request'				=> $GLOBALS['phpgw']->link('/index.php',$link_request_data),
-				'link_request'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uirequest.view')),
+				'link_request'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uirequest.view')),
 
-				'add_workorder_action'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiworkorder.edit')),
+				'add_workorder_action'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiworkorder.edit')),
 				'lang_add_workorder'				=> lang('Add workorder'),
 				'lang_add_workorder_statustext'			=> lang('Add a workorder to this project'),
 
 				'table_header_workorder_budget'			=> $table_header_workorder_budget,
 				'lang_no_workorders'				=> lang('No workorder budget'),
-				'workorder_link'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiworkorder.edit')),
+				'workorder_link'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiworkorder.edit')),
 				'record_history'				=> $record_history,
 				'table_header_history'				=> $table_header_history,
 				'lang_history'					=> lang('History'),
@@ -996,7 +996,7 @@
 				'location_data'					=> $location_data,
 				'location_type'					=> 'form',
 				'form_action'					=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'done_action'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiproject.index')),
+				'done_action'					=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiproject.index')),
 				'lang_year'					=> lang('Year'),
 				'lang_category'					=> lang('category'),
 				'lang_save'					=> lang('save'),
@@ -1076,7 +1076,7 @@
 			);
 
 			$appname		= lang('project');
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('edit' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
@@ -1085,7 +1085,7 @@
 		{
 			if(!$this->acl_delete)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>8, 'acl_location'=>$this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>8, 'acl_location'=>$this->acl_location));
 			}
 
 			$project_id = phpgw::get_var('project_id', 'int');
@@ -1093,7 +1093,7 @@
 
 			$link_data = array
 			(
-				'menuaction' => $this->currentapp.'.uiproject.index',
+				'menuaction' => 'property.uiproject.index',
 				'project_id'	=> $project_id
 			);
 
@@ -1108,7 +1108,7 @@
 			$data = array
 			(
 				'done_action'		=> $GLOBALS['phpgw']->link('/index.php',$link_data),
-				'delete_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiproject.delete', 'project_id'=> $project_id)),
+				'delete_action'		=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiproject.delete', 'project_id'=> $project_id)),
 				'lang_confirm_msg'	=> lang('do you really want to delete this entry'),
 				'lang_yes'		=> lang('yes'),
 				'lang_yes_statustext'	=> lang('Delete the entry'),
@@ -1119,7 +1119,7 @@
 			$appname			= lang('project');
 			$function_msg			= lang('delete project');
 
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('delete' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
@@ -1128,11 +1128,11 @@
 		{
 			if(!$this->acl_read)
 			{
-				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> $this->currentapp.'.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
+				$GLOBALS['phpgw']->redirect_link('/index.php',array('menuaction'=> 'property.uilocation.stop', 'perm'=>1, 'acl_location'=> $this->acl_location));
 			}
 
-			$receipt = $GLOBALS['phpgw']->session->appsession('receipt',$this->currentapp);
-			$GLOBALS['phpgw']->session->appsession('receipt',$this->currentapp,'');
+			$receipt = $GLOBALS['phpgw']->session->appsession('receipt','property');
+			$GLOBALS['phpgw']->session->appsession('receipt','property','');
 			$bolocation			= CreateObject('property.bolocation');
 
 			$id	= phpgw::get_var('id', 'int');
@@ -1234,7 +1234,7 @@
 
 				'table_header_workorder_budget'		=> $table_header_workorder_budget,
 				'lang_no_workorders'			=> lang('No workorder budget'),
-				'workorder_link'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiworkorder.view')),
+				'workorder_link'			=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiworkorder.view')),
 				'record_history'			=> $record_history,
 				'table_header_history'			=> $table_header_history,
 				'lang_history'				=> lang('History'),
@@ -1267,7 +1267,7 @@
 				'vendor_data'				=> isset($vendor_data)?$vendor_data:'',
 				'location_data'				=> $location_data,
 				'location_type'				=> 'view',
-				'done_action'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiproject.index')),
+				'done_action'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiproject.index')),
 				'lang_year'				=> lang('Year'),
 				'lang_category'				=> lang('category'),
 				'lang_save'				=> lang('save'),
@@ -1315,7 +1315,7 @@
 				'key_deliver_list'			=> $this->bo->select_key_location_list($values['key_deliver']),
 				'lang_key_deliver'			=> lang('key deliver location'),
 
-				'edit_action'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> $this->currentapp.'.uiproject.edit', 'id'=> $id)),
+				'edit_action'				=> $GLOBALS['phpgw']->link('/index.php',array('menuaction'=> 'property.uiproject.edit', 'id'=> $id)),
 				'lang_edit_statustext'			=> lang('Edit this entry project'),
 				'lang_edit'				=> lang('Edit'),
 				'currency'				=> $GLOBALS['phpgw_info']['user']['preferences']['common']['currency'],
@@ -1325,7 +1325,7 @@
 			);
 
 			$appname		= lang('project');
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('view' => $data));
 		//	$GLOBALS['phpgw']->xslttpl->pp();
 		}
