@@ -24,7 +24,7 @@
 	* @internal Development of this application was funded by http://www.bergen.kommune.no/bbb_/ekstern/
 	* @package property
 	* @subpackage custom
- 	* @version $Id: synkroniser_med_boei.php 18358 2007-11-27 04:43:37Z skwashd $
+ 	* @version $Id: synkroniser_med_boei.php,v 1.7 2007/09/24 11:20:27 sigurdne Exp $
 	*/
 
 	/**
@@ -38,7 +38,7 @@
 
 		function synkroniser_med_boei()
 		{
-			$this->currentapp		= $GLOBALS['phpgw_info']['flags']['currentapp'];
+		//	$this->currentapp		= $GLOBALS['phpgw_info']['flags']['currentapp'];
 			$this->bocommon			= CreateObject('property.bocommon');
 			$this->db     			= & $GLOBALS['phpgw']->db;
 			$this->join				= $this->db->join;
@@ -98,7 +98,7 @@
 		{
 			$link_data = array
 			(
-				'menuaction' => $this->currentapp.'.custom_functions.index',
+				'menuaction' => 'property.custom_functions.index',
 				'function'	=>$this->function_name,
 				'execute'	=> $execute,
 			);
@@ -133,7 +133,7 @@
 
 			$appname		= lang('location');
 			$function_msg	= 'synkroniser med BOEI';
-			$GLOBALS['phpgw_info']['flags']['app_header'] = lang($this->currentapp) . ' - ' . $appname . ': ' . $function_msg;
+			$GLOBALS['phpgw_info']['flags']['app_header'] = lang('property') . ' - ' . $appname . ': ' . $function_msg;
 			$GLOBALS['phpgw']->xslttpl->set_var('phpgw',array('confirm' => $data));
 			$GLOBALS['phpgw']->xslttpl->pp();
 		}
@@ -167,6 +167,8 @@
 			$this->cron_log($receipt,$cron);
 			$receipt = $this->slett_feil_telefon();
 			$this->cron_log($receipt,$cron);
+			$receipt = $this->update_tenant_name();
+			$this->cron_log($receipt,$cron);
 
 			if(!$cron)
 			{
@@ -609,8 +611,8 @@
 			{
 				$leietaker_utf[]= array (
 				 'id' 				=> $this->db_boei->f('leietaker_id'),
-				 'first_name'		=> $this->bocommon->ascii2utf($this->db_boei->f('fornavn')),
-				 'last_name' 		=> $this->bocommon->ascii2utf($this->db_boei->f('etternavn')),
+				 'first_name'		=> $this->db->db_addslashes($this->bocommon->ascii2utf($this->db_boei->f('fornavn'))),
+				 'last_name' 		=> $this->db->db_addslashes($this->bocommon->ascii2utf($this->db_boei->f('etternavn'))),
 				 'category'			=> $this->db_boei->f('kjonn_juridisk') + 1,
 				 'status_eco'		=> $this->db_boei->f('namssakstatusokonomi_id'),
 				 'status_drift' 	=> $this->db_boei->f('namssakstatusdrift_id'),
@@ -619,8 +621,8 @@
 				 );
 				$leietaker_latin[]= array (
 				 'id' 				=> $this->db_boei->f('leietaker_id'),
-				 'first_name'		=> $this->db_boei->f('fornavn'),
-				 'last_name' 		=> $this->db_boei->f('etternavn'),
+				 'first_name'		=> $this->db->db_addslashes($this->db_boei->f('fornavn')),
+				 'last_name' 		=> $this->db->db_addslashes($this->db_boei->f('etternavn')),
 				 'category'			=> $this->db_boei->f('kjonn_juridisk') + 1,
 				 'status_eco'		=> $this->db_boei->f('namssakstatusokonomi_id'),
 				 'status_drift' 	=> $this->db_boei->f('namssakstatusdrift_id'),
@@ -659,16 +661,47 @@
 
 		}
 
+		function update_tenant_name()
+		{
+			$sql = " SELECT leietaker_id, fornavn, etternavn FROM v_Leietaker";
+			$this->db_boei->query($sql,__LINE__,__FILE__);
+
+			$i=0;
+			while ($this->db_boei->next_record())
+			{
+				$sql2_utf = " UPDATE  fm_tenant SET "
+				. " first_name		= '" . $this->db->db_addslashes($this->bocommon->ascii2utf($this->db_boei->f('fornavn'))) . "',"
+				. " last_name 		= '" . $this->db->db_addslashes($this->bocommon->ascii2utf($this->db_boei->f('etternavn'))) ."'"
+				. " WHERE  id = " . (int)$this->db_boei->f('leietaker_id');
+
+				$sql2_latin = " UPDATE  fm_tenant SET "
+				. " first_name		= '" . $this->db->db_addslashes($this->db_boei->f('fornavn')) . "',"
+				. " last_name 		= '" . $this->db->db_addslashes($this->db_boei->f('etternavn')) ."'"
+				. " WHERE  id = " . (int)$this->db_boei->f('leietaker_id');
+
+				$this->db->query($sql2_latin,__LINE__,__FILE__);
+				$this->db_boei2->query($sql2_latin,__LINE__,__FILE__);
+				$i++;
+			}
+
+			$msg = $i . ' Leietakere er oppdatert';
+			$this->receipt['message'][]=array('msg'=> $msg);
+			return $msg;
+		}
+
+
 		function oppdater_leieobjekt()
 		{			
-			$sql = " SELECT TOP 100 PERCENT objekt_id,leie_id,leietaker_id, boareal, formaal_id, gateadresse_id, gatenr, etasje,driftsstatus_id, flyttenr"
-				. " FROM  v_Leieobjekt"; // WHERE v_Leieobjekt.formaal_id NOT IN (99)";
+			$sql = " SELECT TOP 100 PERCENT v_Leieobjekt.objekt_id,v_Leieobjekt.leie_id,v_Leieobjekt.leietaker_id, boareal, formaal_id, gateadresse_id, gatenr, etasje,driftsstatus_id, v_Leieobjekt.flyttenr, innflyttetdato"
+				. " FROM  v_Leieobjekt JOIN v_reskontro ON v_Leieobjekt.objekt_id=v_reskontro.objekt_id AND v_Leieobjekt.leie_id=v_reskontro.leie_id"
+				. " AND v_Leieobjekt.flyttenr=v_reskontro.flyttenr AND v_Leieobjekt.leietaker_id=v_reskontro.leietaker_id";
 
 			$this->db_boei->query($sql,__LINE__,__FILE__);
 
 		//	$this->db->transaction_begin();
 		//	$this->db_boei2->transaction_begin();
 
+
 			$i=0;
 			while ($this->db_boei->next_record())
 			{
@@ -680,7 +713,8 @@
 				. " street_number = '" . $this->bocommon->ascii2utf($this->db_boei->f('gatenr')) . "',"
 				. " driftsstatus_id = '" . $this->db_boei->f('driftsstatus_id') . "',"
 				. " boareal = '" . $this->db_boei->f('boareal') . "',"
-				. " flyttenr = '" . $this->db_boei->f('flyttenr') . "'"
+				. " flyttenr = '" . $this->db_boei->f('flyttenr') . "',"
+				. " innflyttetdato = '" . date($this->bocommon->dateformat,strtotime($this->db_boei->f('innflyttetdato'))) . "'"
 				. " WHERE  loc1 = '" . $this->db_boei->f('objekt_id') . "'  AND  loc4= '" . $this->db_boei->f('leie_id') . "'";
 				$sql2_latin = " UPDATE  fm_location4 SET "
 				. " tenant_id = '" . $this->db_boei->f('leietaker_id') . "',"
@@ -690,7 +724,8 @@
 				. " street_number = '" . $this->db_boei->f('gatenr') . "',"
 				. " driftsstatus_id = '" . $this->db_boei->f('driftsstatus_id') . "',"
 				. " boareal = '" . $this->db_boei->f('boareal') . "',"
-				. " flyttenr = '" . $this->db_boei->f('flyttenr') . "'"
+				. " flyttenr = '" . $this->db_boei->f('flyttenr') . "',"
+				. " innflyttetdato = '" . date($this->bocommon->dateformat,strtotime($this->db_boei->f('innflyttetdato'))) . "'"
 				. " WHERE  loc1 = '" . $this->db_boei->f('objekt_id') . "'  AND  loc4= '" . $this->db_boei->f('leie_id') . "'";
 
 				$this->db->query($sql2_latin,__LINE__,__FILE__);
