@@ -287,7 +287,7 @@
 			$extra_vars['phpgw_forward'] =  $forward;
 			foreach($_GET as $name => $value)
 			{
-				if (ereg('phpgw_',$name))
+				if (preg_match('/phpgw_/',$name))
 				{
 					$extra_vars[$name] = $value;
 				}
@@ -460,7 +460,7 @@
 	$extra_vars = array();
 	foreach($_GET as $name => $value)
 	{
-		if (ereg('phpgw_',$name))
+		if (preg_match('/phpgw_/',$name))
 		{
 			$extra_vars[$name] = urlencode($value);
 		}
