@@ -5,7 +5,7 @@
 	* @copyright Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package setup
-	* @version $Id: applications.php,v 1.1 2007/02/14 14:58:20 sigurdne Exp $
+	* @version $Id: applications.php 18358 2007-11-27 04:43:37Z skwashd $
 	*/
 
 	$DEBUG = (isset($_POST['debug']) && $_POST['debug']) || (isset($_GET['debug']) && $_GET['debug']);
@@ -45,7 +45,7 @@
 	}
 	// Does not return unless user is authorized
 
-	$ConfigDomain = get_var('ConfigDomain',Array('POST','COOKIE'));
+	$ConfigDomain = phpgw::get_var('ConfigDomain');
 
 	$tpl_root = $GLOBALS['phpgw_setup']->html->setup_tpl_dir('setup');
 	$setup_tpl = CreateObject('phpgwapi.Template',$tpl_root);
@@ -124,16 +124,16 @@
 	ksort($setup_info);
 
 
-	if(get_var('submit',Array('POST')))
+	if ( phpgw::get_var('submit', 'string', 'POST') )
 	{
 		$GLOBALS['phpgw_setup']->html->show_header(lang('Application Management'),False,'config',$ConfigDomain . '(' . $phpgw_domain[$ConfigDomain]['db_type'] . ')');
 		$setup_tpl->set_var('description',lang('App install/remove/upgrade') . ':');
 		$setup_tpl->pparse('out','header');
 
-		$appname = get_var('appname',Array('POST'));
-		$remove  = get_var('remove',Array('POST'));
-		$install = get_var('install',Array('POST'));
-		$upgrade = get_var('upgrade',Array('POST'));
+		$appname = phpgw::get_var('appname', 'string', 'POST');
+		$remove  = phpgw::get_var('remove', 'string', 'POST');
+		$install = phpgw::get_var('install', 'string', 'POST');
+		$upgrade = phpgw::get_var('upgrade', 'string', 'POST');
 
 		if(!empty($remove) && is_array($remove))
 		{
@@ -143,23 +143,25 @@
 				$terror = array();
 				$terror[] = $setup_info[$appname];
 
-				if ($setup_info[$appname]['tables'])
+				if ( isset($setup_info[$appname]['tables'])
+					&& $setup_info[$appname]['tables'] )
 				{
 					$GLOBALS['phpgw_setup']->process->droptables($terror,$DEBUG);
-					echo "<li>{$setup_info[$appname]['title']} " . lang('tables dropped') . ".</li>\n";
+					echo "<li>{$setup_info[$appname]['name']} " . lang('tables dropped') . ".</li>\n";
 				}
 
 				$GLOBALS['phpgw_setup']->deregister_app($setup_info[$appname]['name']);
-				echo "<li>{$setup_info[$appname]['title']} " . lang('deregistered') . ".</li>\n";
+				echo "<li>{$setup_info[$appname]['name']} " . lang('deregistered') . ".</li>\n";
 
-				if ($setup_info[$appname]['hooks'])
+				if (isset($setup_info[$appname]['hooks'])
+					&& $setup_info[$appname]['hooks'] )
 				{
 					$GLOBALS['phpgw_setup']->deregister_hooks($setup_info[$appname]['name']);
-					echo "<li>{$setup_info[$appname]['title']} " . lang('hooks deregistered') . ".</li>\n";
+					echo "<li>{$setup_info[$appname]['name']} " . lang('hooks deregistered') . ".</li>\n";
 				}
 
 				$terror = $GLOBALS['phpgw_setup']->process->drop_langs($terror,$DEBUG);
-				echo "<li>{$setup_info[$appname]['title']} " . lang('Translations removed') . ".</li>\n</ul>\n";
+				echo "<li>{$setup_info[$appname]['name']} " . lang('Translations removed') . ".</li>\n</ul>\n";
 			}
 		}
 
@@ -241,8 +243,8 @@
 		$GLOBALS['phpgw_setup']->html->show_header(lang('Application Management'),False,'config',$ConfigDomain . '(' . $phpgw_domain[$ConfigDomain]['db_type'] . ')');
 	}
 
-	$detail = get_var('detail',Array('GET')); 
-	$resolve = get_var('resolve',Array('GET')); 
+	$detail = phpgw::get_var('detail', 'string', 'GET'); 
+	$resolve = phpgw::get_var('resolve', 'string', 'GET'); 
 	if($detail)
 	{
 		ksort($setup_info[$detail]);
@@ -269,8 +271,8 @@
 					$tblcnt = count($setup_info[$detail][$key]);
 					if(is_array($val))
 					{
-						$key = '<a href="sqltoarray.php?appname=' . $detail . '&amp;submit=True">' . $key . '(' . $tblcnt . ')</a>' . "\n";
-						$val = implode(',' . "\n",$val);
+						$key = '<br/><a href="sqltoarray.php?appname=' . $detail . '&amp;submit=True">' . $key . '(' . $tblcnt . ')</a>:<br/>';
+						$val = implode(',<br/>',$val) .'<br/>';
 					}
 				}
 				
@@ -299,14 +301,14 @@
 		$setup_tpl->pparse('out','footer');
 		exit;
 	}
-	elseif ($resolve)
+	else if ($resolve)
 	{
-		$version  = get_var('version',Array('GET'));
-		$notables = get_var('notables',Array('GET'));
+		$version  = phpgw::get_var('version', 'string', 'GET');
+		$notables = phpgw::get_var('notables', 'string', 'GET');
 		$setup_tpl->set_var('description',lang('Problem resolution'). ':');
 		$setup_tpl->pparse('out','header');
 
-		if(get_var('post',Array('GET')))
+		if ( phpgw::get_var('post', 'string', 'GET') )
 		{
 			echo '"' . $setup_info[$resolve]['name'] . '" ' . lang('may be broken') . ' ';
 			echo lang('because an application it depends upon was upgraded');
@@ -315,7 +317,7 @@
 			echo '<br />';
 			echo lang('However, the application may still work') . '.';
 		}
-		elseif(get_var('badinstall',Array('GET')))
+		else if ( phpgw::get_var('badinstall', 'string', 'GET') )
 		{
 			echo '"' . $setup_info[$resolve]['name'] . '" ' . lang('is broken') . ' ';
 			echo lang('because of a failed upgrade or install') . '.';
@@ -388,7 +390,7 @@
 		$setup_tpl->pparse('out','footer');
 		exit;
 	}
-	elseif(get_var('globals', array('GET')))
+	else if ( phpgw::get_var('globals', 'string', 'GET') )
 	{
 		$setup_tpl->set_var('description','<a href="applications.php?debug='.$DEBUG.'">' . lang('Go back') . '</a>');
 		$setup_tpl->pparse('out','header');
