@@ -5,7 +5,7 @@
 	* @copyright Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package setup
-	* @version $Id: config.php,v 1.2 2007/03/16 21:41:37 sigurdne Exp $
+	* @version $Id: config.php 18358 2007-11-27 04:43:37Z skwashd $
 	*/
 
 	if ( isset($_POST['cancel']) && $_POST['cancel'] )
@@ -15,7 +15,8 @@
 	}
 
 	$GLOBALS['phpgw_info'] = array();
-	$GLOBALS['phpgw_info']['flags'] = array(
+	$GLOBALS['phpgw_info']['flags'] = array
+	(
 		'noheader' => True,
 		'nonavbar' => True,
 		'currentapp' => 'home',
@@ -116,25 +117,24 @@
 
 
 	$setup_info = $GLOBALS['phpgw_setup']->detection->get_db_versions();
-	$newsettings = get_var('newsettings',Array('POST'));
+	$newsettings = phpgw::get_var('newsettings', 'string', 'POST');
 	
 	$files_in_docroot = (isset($newsettings['files_dir']))? in_docroot($newsettings['files_dir']) : false ;
-	if(get_var('submit',Array('POST')) && is_array($newsettings) && !$files_in_docroot)
+	if ( phpgw::get_var('submit', 'string', 'POST') && is_array($newsettings) && !$files_in_docroot)
 	{
-		$datetime = CreateObject('phpgwapi.datetimefunctions');
+		phpgw::import_class('phpgwapi.datetime');
 		switch (intval($newsettings['daytime_port']))
 		{
 			case 13:
-				$newsettings['tz_offset'] = $datetime->getntpoffset();
+				$newsettings['tz_offset'] = phpgwapi_datetime::getntpoffset();
 				break;
 			case 80:
-				$newsettings['tz_offset'] = $datetime->gethttpoffset();
+				$newsettings['tz_offset'] = phpgwapi_datetime::gethttpoffset();
 				break;
 			default:
-				$newsettings['tz_offset'] = $datetime->getbestguess();
+				$newsettings['tz_offset'] = phpgwapi_datetime::getbestguess();
 				break;
 		}
-		unset($datetime);
 
 		print_debug('TZ_OFFSET', $newsettings['tz_offset']);
 
@@ -142,10 +142,11 @@
 		// This is only temp:
 		$GLOBALS['phpgw_setup']->db->query("DELETE FROM phpgw_config WHERE config_name='useframes'");
 		$GLOBALS['phpgw_setup']->db->query("INSERT INTO phpgw_config (config_app,config_name, config_value) values ('phpgwapi','useframes','never')");
-
-		while(list($setting,$value) = @each($newsettings))
+		
+		foreach( $newsettings as $setting => $value ) 
 		{
-			/* echo '<br />Updating: ' . $setting . '=' . $value; */
+		//	echo '<br />Updating: ' . $setting . '=' . $value;
+			
 			/* Don't erase passwords, since we also do not print them below */
 			if($value || (!ereg('passwd',$setting) && !ereg('password',$setting) && !ereg('root_pw',$setting)))
 			{
@@ -157,8 +158,8 @@
 					. "','" . $GLOBALS['phpgw_setup']->db->db_addslashes($value) . "')");
 			}
 		}
-		$GLOBALS['phpgw_setup']->db->transaction_commit();
-
+		$GLOBALS['phpgw_setup']->db->transaction_commit();		
+		
 		// Add cleaning of app_sessions per skeeter, but with a check for the table being there, just in case
 		$tablenames = $GLOBALS['phpgw_setup']->db->table_names();
 		while(list($key,$val) = @each($tablenames))
@@ -172,7 +173,7 @@
 			@$GLOBALS['phpgw_setup']->db->query("DELETE FROM phpgw_app_sessions WHERE app = 'phpgwapi' and location = 'phpgw_info_cache'",__LINE__,__FILE__);
 			$GLOBALS['phpgw_setup']->db->unlock();
 		}
-
+		
 		if($newsettings['auth_type'] == 'ldap')
 		{
 			Header('Location: '.$newsettings['webserver_url'].'/setup/ldap.php');
@@ -183,6 +184,8 @@
 			Header('Location: index.php');
 			exit;
 		}
+		
+		//exit;
 	}
 
 	if(!isset($newsettings['auth_type']) || $newsettings['auth_type'] != 'ldap')
@@ -261,7 +264,6 @@
 				}
 				break;
 			case 'selected':
-
 				$configs = array();
 				$config  = '';
 				$newvals = explode(' ',$newval);
@@ -271,9 +273,9 @@
 					$configs[] = $newvals[$i];
 				}
 				$config = implode('_',$configs);
-			//	echo $config . '=' . str_replace('-','',$current_config[$config]) . '<br/>';
+				/* echo $config . '=' . $current_config[$config]; */
 				if( isset($current_config[$config])
-					&& str_replace('-','',$current_config[$config]) == $setting)
+					&& $current_config[$config] == $setting)
 				{
 					$setup_tpl->set_var($value,' selected');
 				}
