@@ -15,7 +15,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: functions.inc.php,v 1.2 2007/02/27 12:31:14 sigurdne Exp $ */
+  /* $Id: functions.inc.php 18358 2007-11-27 04:43:37Z skwashd $ */
 
 	// PHP5 compat fix
 	if (version_compare(phpversion(), '5.0') < 0)
@@ -272,9 +272,8 @@
 			//No default, we just ignore it, for now
 		}
 	}
-//	set_error_handler('phpgw_handle_error');
+	set_error_handler('phpgw_handle_error');
 
-	//error_reporting(E_ERROR | E_WARNING | E_PARSE);
 	/**
 	* Get a list of supported languages
 	*
@@ -315,7 +314,7 @@
 	*/
 	function lang_select($onChange = '')
 	{
-		$ConfigLang = get_var('ConfigLang', Array('POST','COOKIE'));
+		$ConfigLang = phpgw::get_var('ConfigLang');
 
 		$select = '<select name="ConfigLang"' . ($onChange ? ' onChange="this.form.submit();"' : '') . '>' . "\n";
 		$languages = get_langs();
