@@ -5,7 +5,7 @@
 	* @copyright Portions Copyright (C) 2000-2005 Free Software Foundation, Inc. http://www.fsf.org/
 	* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 	* @package setup
-	* @version $Id: index.php,v 1.1 2007/02/14 14:58:20 sigurdne Exp $
+	* @version $Id: index.php 18358 2007-11-27 04:43:37Z skwashd $
 	*/
 
 	/*
@@ -103,7 +103,7 @@
 	$subtitle = '';
 	$submsg = '';
 	$subaction = '';
-	switch(get_var('action',Array('POST', 'GET')))
+	switch( phpgw::get_var('action') )
 	{
 		case 'Uninstall all applications':
 			$subtitle = lang('Deleting Tables');
@@ -146,11 +146,11 @@
 	$setup_tpl->set_var('subaction', $subaction);
 
 	// Old PHP
-	if ( version_compare('4.3.0', phpversion()) === 1 )
+	if ( version_compare('5.2.0', phpversion()) === 1 )
 	{
 		$GLOBALS['phpgw_setup']->html->show_header($GLOBALS['phpgw_info']['setup']['header_msg'],True);
 		$GLOBALS['phpgw_setup']->html->show_alert_msg('Error',
-			 lang('You appear to be using PHP %1. phpGroupWare now requires PHP 4.3.0 or later', phpversion()) );
+			 lang('You appear to be using PHP %1. phpGroupWare now requires PHP 5.2.0 or later', phpversion()) );
 		$GLOBALS['phpgw_setup']->html->show_footer();
 		exit;
 	}
