@@ -10,14 +10,13 @@
 	*/
 
 	$setup_info['sms']['name']      = 'sms';
-	$setup_info['sms']['title']= 'SMS';
 	$setup_info['sms']['version']   = '0.9.17.506';
 	$setup_info['sms']['app_order'] = 8;
 	$setup_info['sms']['enable']    = 1;
 	$setup_info['sms']['app_group']	= 'office';
 	$setup_info['sms']['description'] = 'sms gateway';
 
-	$setup_info['sms']['author'][] = array
+	$setup_info['sms']['author'] = array
 	(
 		'name'	=> 'Sigurd Nes',
 		'email'	=> 'sigurdne@online.no'
@@ -71,7 +70,8 @@
 //		'help',
 		'settings',
 		'preferences',
-		'admin'
+		'admin',
+		'sidebox_menu'
 	);
 
 	/* Dependencies for this app to work */
